@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBSplineDeformableTransform.h,v $
   Language:  C++
-  Date:      $Date: 2007/01/30 23:39:50 $
-  Version:   $Revision: 1.32 $
+  Date:      $Date: 2008-04-11 16:28:11 $
+  Version:   $Revision: 1.38 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -193,6 +193,7 @@ public:
    * This function has the effect of make the following calls:
    *       transform->SetGridSpacing( spacing );
    *       transform->SetGridOrigin( origin );
+   *       transform->SetGridDirection( direction );
    *       transform->SetGridRegion( bsplineRegion );
    *
    * This function was added to allow the transform to work with the 
@@ -244,6 +245,8 @@ public:
   /** Get the array of coefficient images. */
   virtual ImagePointer * GetCoefficientImage()
     { return m_CoefficientImage; }
+  virtual const ImagePointer * GetCoefficientImage() const
+    { return m_CoefficientImage; }
 
   /** Set the array of coefficient images.
    *
@@ -265,6 +268,7 @@ public:
   typedef typename RegionType::IndexType  IndexType;
   typedef typename RegionType::SizeType   SizeType;
   typedef typename ImageType::SpacingType SpacingType;
+  typedef typename ImageType::DirectionType DirectionType;
   typedef typename ImageType::PointType   OriginType;
 
   /** This method specifies the region over which the grid resides. */
@@ -277,6 +281,11 @@ public:
   itkGetMacro( GridSpacing, SpacingType );
   itkGetConstMacro( GridSpacing, SpacingType );
 
+  /** This method specifies the grid directions . */
+  virtual void SetGridDirection( const DirectionType & spacing );
+  itkGetMacro( GridDirection, DirectionType );
+  itkGetConstMacro( GridDirection, DirectionType );
+
   /** This method specifies the grid origin. */
   virtual void SetGridOrigin( const OriginType& origin );
   itkGetMacro( GridOrigin, OriginType );
@@ -320,6 +329,12 @@ public:
                        ParameterIndexArrayType & indices, 
                        bool & inside ) const;
 
+  virtual void GetJacobian( const InputPointType & inputPoint,
+                       WeightsType & weights,
+                       ParameterIndexArrayType & indices
+                       ) const;
+
+
   /** Get number of weights. */
   unsigned long GetNumberOfWeights() const
     { return m_WeightsFunction->GetNumberOfWeights(); }
@@ -368,6 +383,8 @@ public:
    */
   virtual bool IsLinear() const { return false; }
 
+  unsigned int GetNumberOfAffectedWeights() const;
+
 protected:
   /** Print contents of an BSplineDeformableTransform. */
   void PrintSelf(std::ostream &os, Indent indent) const;
@@ -383,6 +400,10 @@ protected:
   /** Wrap flat array into images of coefficients. */
   void WrapAsImages();
 
+  /** Convert an input point to a continuous index inside the BSpline grid */
+  void TransformPointToContinuousIndex( 
+   const InputPointType & point, ContinuousIndexType & index ) const;
+
 private:
   BSplineDeformableTransform(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
@@ -393,7 +414,11 @@ private:
   /** Variables defining the coefficient grid extend. */
   RegionType    m_GridRegion;
   SpacingType   m_GridSpacing;
+  DirectionType m_GridDirection;
   OriginType    m_GridOrigin;
+
+  DirectionType m_PointToIndex;
+  DirectionType m_IndexToPoint;
   
   RegionType    m_ValidRegion;
 
