@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMacro.h,v $
   Language:  C++
-  Date:      $Date: 2006/11/29 10:10:51 $
-  Version:   $Revision: 1.69 $
+  Date:      $Date: 2007-12-28 18:28:29 $
+  Version:   $Revision: 1.83 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -131,6 +131,9 @@ namespace itk
       } \
   } 
 
+/** Macro used to redefine a type from the superclass. */
+#define itkSuperclassTraitMacro(traitnameType) \
+  typedef typename Superclass::traitnameType traitnameType;
 
 /** Get an input. This defines the Get"name"Input() method */
 #define itkGetInputMacro(name, type, number) \
@@ -145,6 +148,49 @@ namespace itk
     return static_cast<const type *>(this->ProcessObject::GetInput( number )); \
   } 
 
+/** Set a decorated input. This defines the Set"name"() method.
+ * It invokes SetInputMacro() and GetInputMacro() for the decorated object */
+#define itkSetDecoratedInputMacro(name, type, number) \
+  itkSetInputMacro(name, SimpleDataObjectDecorator<type>, number); \
+  itkGetInputMacro(name, SimpleDataObjectDecorator<type>, number); \
+  virtual void Set##name(const type &_arg) \
+  { \
+    typedef SimpleDataObjectDecorator< type > DecoratorType; \
+    itkDebugMacro("setting input " #name " to " << _arg); \
+    const DecoratorType * oldInput = \
+      static_cast< const DecoratorType * >( \
+        this->ProcessObject::GetInput(number) ); \
+    if( oldInput && oldInput->Get() == _arg ) \
+      { \
+      return; \
+      } \
+    typename DecoratorType::Pointer newInput = DecoratorType::New(); \
+    newInput->Set( _arg ); \
+    this->Set##name##Input( newInput ); \
+  }
+
+/** Set a decorated input that derives from itk::Object, but not from
+ * itk::DataObject. This defines the Set"name"() method.  It invokes
+ * SetInputMacro() and GetInputMacro() for the decorated object */
+#define itkSetDecoratedObjectInputMacro(name, type, number) \
+  itkSetInputMacro(name, DataObjectDecorator<type>, number); \
+  itkGetInputMacro(name, DataObjectDecorator<type>, number); \
+  virtual void Set##name(const type *_arg) \
+  { \
+    typedef DataObjectDecorator< type > DecoratorType; \
+    itkDebugMacro("setting input " #name " to " << _arg); \
+    const DecoratorType * oldInput = \
+      static_cast< const DecoratorType * >( \
+        this->ProcessObject::GetInput(number) ); \
+    if( oldInput && oldInput->Get() == _arg ) \
+      { \
+      return; \
+      } \
+    typename DecoratorType::Pointer newInput = DecoratorType::New(); \
+    newInput->Set( _arg ); \
+    this->Set##name##Input( newInput ); \
+  }
+
 
 /** Set built-in type.  Creates member Set"name"() (e.g., SetVisibility()); */
 #define itkSetMacro(name,type) \
@@ -186,6 +232,30 @@ namespace itk
     itkDebugMacro("returning " << #name " of " << this->m_##name ); \
     return this->m_##name; \
   }
+  
+  /** Set built-in type.  Creates member Set"name"() (e.g., SetVisibility());
+  * This should be use when the type is an enum. It is use to avoid warnings on
+  * some compilers with non specified enum types passed to itkDebugMacro.*/
+#define itkSetEnumMacro(name,type) \
+  virtual void Set##name (const type _arg) \
+  { \
+    itkDebugMacro("setting " #name " to " << static_cast<long>(_arg)); \
+    if (this->m_##name != _arg) \
+      { \
+      this->m_##name = _arg; \
+      this->Modified(); \
+      } \
+  } 
+
+/** Get built-in type.  Creates member Get"name"() (e.g., GetVisibility()); 
+  * This should be use when the type is an enum. It is use to avoid warnings on
+  * some compilers with non specified enum types passed to itkDebugMacro.*/
+#define itkGetEnumMacro(name,type) \
+  virtual type Get##name () const \
+  { \
+    itkDebugMacro("returning " << #name " of " << static_cast<long>(this->m_##name) ); \
+    return this->m_##name; \
+  }
 
 /** Set character string.  Creates member Set"name"() 
  * (e.g., SetFilename(char *)). The macro assumes that
@@ -212,12 +282,12 @@ namespace itk
 
 /** Get character string.  Creates member Get"name"() 
  * (e.g., SetFilename(char *)). The macro assumes that
- * the class member (name) is declared a type std::string. */
+ * the class member (name) is declared as a type std::string. */
 #define itkGetStringMacro(name) \
   virtual const char* Get##name () const \
   { \
     return this->m_##name.c_str(); \
-  } 
+  }
 
 /** Set built-in type where value is constrained between min/max limits.
  * Create member Set"name"() (e.q., SetRadius()). #defines are 
@@ -380,9 +450,9 @@ static Pointer New(void) \
   rawPtr->UnRegister(); \
   return smartPtr; \
 } \
-virtual LightObject::Pointer CreateAnother(void) const \
+  virtual ::itk::LightObject::Pointer CreateAnother(void) const \
 { \
-  LightObject::Pointer smartPtr; \
+  ::itk::LightObject::Pointer smartPtr;         \
   smartPtr = x::New().GetPointer(); \
   return smartPtr; \
 }
@@ -433,12 +503,12 @@ extern ITKCommon_EXPORT void OutputWindowDisplayDebugText(const char*);
 #define itkWarningMacro(x)
 #else
 #define itkWarningMacro(x) \
-{ if (itk::Object::GetGlobalWarningDisplay()) \
+{ if (::itk::Object::GetGlobalWarningDisplay()) \
     { ::itk::OStringStream itkmsg; \
       itkmsg << "WARNING: In " __FILE__ ", line " << __LINE__ << "\n" \
              << this->GetNameOfClass() << " (" << this << "): " x  \
              << "\n\n"; \
-      itk::OutputWindowDisplayWarningText(itkmsg.str().c_str());} \
+      ::itk::OutputWindowDisplayWarningText(itkmsg.str().c_str());} \
 }
 #endif
 
@@ -538,7 +608,7 @@ private:
     { ::itk::OStringStream itkmsg; \
       itkmsg << "WARNING: In " __FILE__ ", line " << __LINE__ << "\n" \
              x << "\n\n"; \
-      itk::OutputWindowDisplayGenericOutputText(itkmsg.str().c_str());} \
+      ::itk::OutputWindowDisplayGenericOutputText(itkmsg.str().c_str());} \
 }
 #endif
 
@@ -567,27 +637,45 @@ private:
 
 //----------------------------------------------------------------------------
 // Setup legacy code policy.
+//
+// CMake options ITK_LEGACY_REMOVE and ITK_LEGACY_SILENT are converted
+// to definitions (or non-defs) in itkConfigure.h and tested below.
+// They may be used to completely remove legacy code or silence the
+// warnings.  The default is to warn about their use.
+//
+// Source files that test the legacy code may define ITK_LEGACY_TEST
+// like this:
+//
+//  #define ITK_LEGACY_TEST
+//  #include "itkClassWithDeprecatedMethod.h"
+//
+// in order to silence the warnings for calling deprecated methods.
+// No other source files in ITK should call the methods since they are
+// provided only for compatibility with older user code.
 
-// Define itkLegacy macro to mark legacy methods where they are
+// Define itkLegacyMacro to mark legacy methods where they are
 // declared in their class.  Example usage:
 //
 //   // @deprecated Replaced by MyOtherMethod() as of ITK 2.0.
-//   itkLegacy(void MyMethod());
+//   itkLegacyMacro(void MyMethod());
 #if defined(ITK_LEGACY_REMOVE)
-  // Remove legacy methods completely.
-# define itkLegacy(method)
-#elif defined(ITK_LEGACY_SILENT) || defined(ITK_WRAPPING_CXX)
+// Remove legacy methods completely.  Put a bogus declaration in
+// place to avoid stray semicolons because this is an error for some
+// compilers.  Using a class forward declaration allows any number
+// of repeats in any context without generating unique names.
+# define itkLegacyMacro(method) class itkLegacyMethodRemoved /* no ';' */
+#elif defined(ITK_LEGACY_SILENT) || defined(ITK_LEGACY_TEST) || defined(CSWIG)
   // Provide legacy methods with no warnings.
-# define itkLegacy(method) method
+# define itkLegacyMacro(method) method
 #else
   // Setup compile-time warnings for uses of deprecated methods if
   // possible on this compiler.
 # if defined(__GNUC__) && !defined(__INTEL_COMPILER) && (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 1))
-#  define itkLegacy(method) method __attribute__((deprecated))
+#  define itkLegacyMacro(method) method __attribute__((deprecated))
 # elif defined(_MSC_VER) && _MSC_VER >= 1300
-#  define itkLegacy(method) __declspec(deprecated) method
+#  define itkLegacyMacro(method) __declspec(deprecated) method
 # else
-#  define itkLegacy(method) method
+#  define itkLegacyMacro(method) method
 # endif
 #endif
 
@@ -595,22 +683,22 @@ private:
 // bodies.  Example usage:
 //
 //   void itkMyClass::MyOldMethod()
-//   {
-//     itkLegacyBody(itkMyClass::MyOldMethod, 2.0);
-//   }
+//     {
+//     itkLegacyBodyMacro(itkMyClass::MyOldMethod, 2.0);
+//     }
 //
 //   void itkMyClass::MyMethod()
-//   {
-//     itkLegacyReplaceBody(itkMyClass::MyMethod, 2.0,
-//                          itkMyClass::MyOtherMethod);
-//   }
+//     {
+//     itkLegacyReplaceBodyMacro(itkMyClass::MyMethod, 2.0,
+//                               itkMyClass::MyOtherMethod);
+//     }
 #if defined(ITK_LEGACY_REMOVE) || defined(ITK_LEGACY_SILENT)
-# define itkLegacyBody(method, version)
-# define itkLegacyReplaceBody(method, version, replace)
+# define itkLegacyBodyMacro(method, version)
+# define itkLegacyReplaceBodyMacro(method, version, replace)
 #else
-# define itkLegacyBody(method, version) \
+# define itkLegacyBodyMacro(method, version) \
   itkWarningMacro(#method " was deprecated for ITK " #version " and will be removed in a future version.")
-# define itkLegacyReplaceBody(method, version, replace) \
+# define itkLegacyReplaceBodyMacro(method, version, replace) \
   itkWarningMacro(#method " was deprecated for ITK " #version " and will be removed in a future version.  Use " #replace " instead.")
 #endif
 
@@ -811,4 +899,57 @@ private:
 # define ITK_TEMPLATE_EXPLICIT 0
 #endif
 
+
+//----------------------------------------------------------------------------
+// Macro to declare that a function does not return. __attribute__((noreturn))
+//    On some compiler, functions that do not return (ex: exit(0)) must
+//    have the noreturn attribute. Otherwise, a warning is raised. Use
+//    that macro to avoid those warnings. GCC defines the attribute
+//    noreturn for versions 2.5 and higher.
+#if defined(__GNUC__)
+#  if (((__GNUC__ == 2) && (__GNUC_MINOR__ >= 5)) || (__GNUC__ >= 3))
+#    define ITK_NO_RETURN \
+       __attribute__ ((noreturn))
+#  endif
+#else
+#  define ITK_NO_RETURN
+#endif
+
+
+#ifdef ITK_USE_TEMPLATE_META_PROGRAMMING_LOOP_UNROLLING
+//--------------------------------------------------------------------------------
+//  Helper macros for Template Meta-Programming techniques of for-loops unrolling
+//--------------------------------------------------------------------------------
+
+//--------------------------------------------------------------------------------
+// Macro that generates an unrolled for loop for assigning elements of one array
+// to elements of another array The array are assumed to be of same length
+// (dimension), and this is also assumed to be the value of NumberOfIterations.
+// No verification of size is performed. Casting is perfomed as part of the
+// assignment, by using the DestinationElementType as the casting type. 
+// Source and destination array types must have defined opearator[] in their API.
+#define itkFoorLoopAssignmentMacro(DestinationType,SourceType,DestinationElementType,DestinationArray,SourceArray,NumberOfIterations) \
+    for(unsigned int i=0;i < NumberOfIterations; ++i) \
+      { \
+      DestinationArray[i] = static_cast< DestinationElementType >( SourceArray[i] ); \
+      }
+
+//--------------------------------------------------------------------------------
+// Macro that generates an unrolled for loop for rounding and assigning
+// elements of one array to elements of another array The array are assumed to
+// be of same length (dimension), and this is also assumed to be the value of
+// NumberOfIterations.  No verification of size is performed. Casting is
+// perfomed as part of the assignment, by using the DestinationElementType as
+// the casting type. 
+// Source and destination array types must have defined opearator[] in their API.
+#define itkFoorLoopRoundingAndAssignmentMacro(DestinationType,SourceType,DestinationElementType,DestinationArray,SourceArray,NumberOfIterations) \
+    for(unsigned int i=0;i < NumberOfIterations; ++i) \
+      { \
+      DestinationArray[i] = static_cast< DestinationElementType >( vnl_math_rnd( SourceArray[i] ) ); \
+      }
+
+#endif
+// end of Template Meta Programming helper macros
+
+
 #endif //end of itkMacro.h
