@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNumericTraitsVectorPixel.h,v $
   Language:  C++
-  Date:      $Date: 2006/05/22 18:57:42 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2007-09-19 22:32:47 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -27,7 +27,7 @@ namespace itk
 {
 template <> class NumericTraits<Vector<unsigned char, 2 > > {
 public:
-  typedef Vector<unsigned char, 2> ValueType;
+  typedef unsigned char ValueType;
   typedef Vector<unsigned char, 2> PrintType;
   typedef Vector<unsigned char, 2> AbsType;
   typedef Vector<unsigned short, 2> AccumulateType;
@@ -40,7 +40,7 @@ public:
 };
 template <> class NumericTraits<Vector<signed char, 2> > {
 public:
-  typedef Vector<signed char, 2> ValueType;
+  typedef signed char ValueType;
   typedef Vector<signed char, 2> PrintType;
   typedef Vector<unsigned char, 2> AbsType;
   typedef Vector<short, 2> AccumulateType;
@@ -53,7 +53,7 @@ public:
 };
 template <> class NumericTraits<Vector<char, 2> > {
 public:
-  typedef Vector<char, 2> ValueType;
+  typedef char ValueType;
   typedef Vector<char, 2> PrintType;
   typedef Vector<unsigned char, 2> AbsType;
   typedef Vector<short, 2> AccumulateType;
@@ -66,7 +66,7 @@ public:
 };
 template <> class NumericTraits<Vector<short, 2> > {
 public:
-  typedef Vector<short, 2> ValueType;
+  typedef short ValueType;
   typedef Vector<short, 2> PrintType;
   typedef Vector<unsigned short, 2> AbsType;
   typedef Vector<int, 2> AccumulateType;
@@ -79,7 +79,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned short, 2> > {
 public:
-  typedef Vector<unsigned short, 2> ValueType;
+  typedef unsigned short ValueType;
   typedef Vector<unsigned short, 2> PrintType;
   typedef Vector<unsigned short, 2> AbsType;
   typedef Vector<unsigned int, 2> AccumulateType;
@@ -92,7 +92,7 @@ public:
 };
 template <> class NumericTraits<Vector<int, 2> > {
 public:
-  typedef Vector<int, 2> ValueType;
+  typedef int ValueType;
   typedef Vector<int, 2> PrintType;
   typedef Vector<unsigned int, 2> AbsType;
   typedef Vector<long, 2> AccumulateType;
@@ -105,7 +105,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned int, 2> > {
 public:
-  typedef Vector<unsigned int, 2> ValueType;
+  typedef unsigned int ValueType;
   typedef Vector<unsigned int, 2> PrintType;
   typedef Vector<unsigned int, 2> AbsType;
   typedef Vector<unsigned long, 2> AccumulateType;
@@ -118,7 +118,7 @@ public:
 };
 template <> class NumericTraits<Vector<long, 2> > {
 public:
-  typedef Vector<long, 2> ValueType;
+  typedef long ValueType;
   typedef Vector<long, 2> PrintType;
   typedef Vector<unsigned long, 2> AbsType;
   typedef Vector<long, 2> AccumulateType;
@@ -131,7 +131,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned long, 2> > {
 public:
-  typedef Vector<unsigned long, 2> ValueType;
+  typedef unsigned long ValueType;
   typedef Vector<unsigned long, 2> PrintType;
   typedef Vector<unsigned long, 2> AbsType;
   typedef Vector<unsigned long, 2> AccumulateType;
@@ -143,7 +143,7 @@ public:
 };
 template <> class NumericTraits<Vector<float, 2> > {
 public:
-  typedef Vector<float, 2> ValueType;
+  typedef float ValueType;
   typedef Vector<float, 2> PrintType;
   typedef Vector<float, 2> AbsType;
   typedef Vector<double, 2> AccumulateType;
@@ -156,7 +156,7 @@ public:
 };
 template <> class NumericTraits<Vector<double, 2> > {
 public:
-  typedef Vector<double, 2> ValueType;
+  typedef double ValueType;
   typedef Vector<double, 2> PrintType;
   typedef Vector<double, 2> AbsType;
   typedef Vector<long double, 2> AccumulateType;
@@ -169,7 +169,7 @@ public:
 };
 template <> class NumericTraits<Vector<long double, 2> > {
 public:
-  typedef Vector<long double, 2> ValueType;
+  typedef long double ValueType;
   typedef Vector<long double, 2> PrintType;
   typedef Vector<long double, 2> AbsType;
   typedef Vector<long double, 2> AccumulateType;
@@ -183,7 +183,7 @@ public:
 
 template <> class NumericTraits<Vector<unsigned char, 3 > > {
 public:
-  typedef Vector<unsigned char, 3> ValueType;
+  typedef unsigned char ValueType;
   typedef Vector<unsigned char, 3> PrintType;
   typedef Vector<unsigned char, 3> AbsType;
   typedef Vector<unsigned short, 3> AccumulateType;
@@ -196,7 +196,7 @@ public:
 };
 template <> class NumericTraits<Vector<signed char, 3> > {
 public:
-  typedef Vector<signed char, 3> ValueType;
+  typedef signed char ValueType;
   typedef Vector<signed char, 3> PrintType;
   typedef Vector<unsigned char, 3> AbsType;
   typedef Vector<short, 3> AccumulateType;
@@ -209,7 +209,7 @@ public:
 };
 template <> class NumericTraits<Vector<char, 3> > {
 public:
-  typedef Vector<char, 3> ValueType;
+  typedef char ValueType;
   typedef Vector<char, 3> PrintType;
   typedef Vector<unsigned char, 3> AbsType;
   typedef Vector<short, 3> AccumulateType;
@@ -222,7 +222,7 @@ public:
 };
 template <> class NumericTraits<Vector<short, 3> > {
 public:
-  typedef Vector<short, 3> ValueType;
+  typedef short ValueType;
   typedef Vector<short, 3> PrintType;
   typedef Vector<unsigned short, 3> AbsType;
   typedef Vector<int, 3> AccumulateType;
@@ -235,7 +235,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned short, 3> > {
 public:
-  typedef Vector<unsigned short, 3> ValueType;
+  typedef unsigned short ValueType;
   typedef Vector<unsigned short, 3> PrintType;
   typedef Vector<unsigned short, 3> AbsType;
   typedef Vector<unsigned int, 3> AccumulateType;
@@ -248,7 +248,7 @@ public:
 };
 template <> class NumericTraits<Vector<int, 3> > {
 public:
-  typedef Vector<int, 3> ValueType;
+  typedef int ValueType;
   typedef Vector<int, 3> PrintType;
   typedef Vector<unsigned int, 3> AbsType;
   typedef Vector<long, 3> AccumulateType;
@@ -261,7 +261,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned int, 3> > {
 public:
-  typedef Vector<unsigned int, 3> ValueType;
+  typedef unsigned int ValueType;
   typedef Vector<unsigned int, 3> PrintType;
   typedef Vector<unsigned int, 3> AbsType;
   typedef Vector<unsigned long, 3> AccumulateType;
@@ -274,7 +274,7 @@ public:
 };
 template <> class NumericTraits<Vector<long, 3> > {
 public:
-  typedef Vector<long, 3> ValueType;
+  typedef long ValueType;
   typedef Vector<long, 3> PrintType;
   typedef Vector<unsigned long, 3> AbsType;
   typedef Vector<long, 3> AccumulateType;
@@ -287,7 +287,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned long, 3> > {
 public:
-  typedef Vector<unsigned long, 3> ValueType;
+  typedef unsigned long ValueType;
   typedef Vector<unsigned long, 3> PrintType;
   typedef Vector<unsigned long, 3> AbsType;
   typedef Vector<unsigned long, 3> AccumulateType;
@@ -299,7 +299,7 @@ public:
 };
 template <> class NumericTraits<Vector<float, 3> > {
 public:
-  typedef Vector<float, 3> ValueType;
+  typedef float ValueType;
   typedef Vector<float, 3> PrintType;
   typedef Vector<float, 3> AbsType;
   typedef Vector<double, 3> AccumulateType;
@@ -312,7 +312,7 @@ public:
 };
 template <> class NumericTraits<Vector<double, 3> > {
 public:
-  typedef Vector<double, 3> ValueType;
+  typedef double ValueType;
   typedef Vector<double, 3> PrintType;
   typedef Vector<double, 3> AbsType;
   typedef Vector<long double, 3> AccumulateType;
@@ -325,7 +325,7 @@ public:
 };
 template <> class NumericTraits<Vector<long double, 3> > {
 public:
-  typedef Vector<long double, 3> ValueType;
+  typedef long double ValueType;
   typedef Vector<long double, 3> PrintType;
   typedef Vector<long double, 3> AbsType;
   typedef Vector<long double, 3> AccumulateType;
@@ -339,7 +339,7 @@ public:
 
 template <> class NumericTraits<Vector<unsigned char, 4 > > {
 public:
-  typedef Vector<unsigned char, 4> ValueType;
+  typedef unsigned char ValueType;
   typedef Vector<unsigned char, 4> PrintType;
   typedef Vector<unsigned char, 4> AbsType;
   typedef Vector<unsigned short, 4> AccumulateType;
@@ -352,7 +352,7 @@ public:
 };
 template <> class NumericTraits<Vector<signed char, 4> > {
 public:
-  typedef Vector<signed char, 4> ValueType;
+  typedef signed char ValueType;
   typedef Vector<signed char, 4> PrintType;
   typedef Vector<unsigned char, 4> AbsType;
   typedef Vector<short, 4> AccumulateType;
@@ -365,7 +365,7 @@ public:
 };
 template <> class NumericTraits<Vector<char, 4> > {
 public:
-  typedef Vector<char, 4> ValueType;
+  typedef char ValueType;
   typedef Vector<char, 4> PrintType;
   typedef Vector<unsigned char, 4> AbsType;
   typedef Vector<short, 4> AccumulateType;
@@ -378,7 +378,7 @@ public:
 };
 template <> class NumericTraits<Vector<short, 4> > {
 public:
-  typedef Vector<short, 4> ValueType;
+  typedef short ValueType;
   typedef Vector<short, 4> PrintType;
   typedef Vector<unsigned short, 4> AbsType;
   typedef Vector<int, 4> AccumulateType;
@@ -391,7 +391,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned short, 4> > {
 public:
-  typedef Vector<unsigned short, 4> ValueType;
+  typedef unsigned short ValueType;
   typedef Vector<unsigned short, 4> PrintType;
   typedef Vector<unsigned short, 4> AbsType;
   typedef Vector<unsigned int, 4> AccumulateType;
@@ -404,7 +404,7 @@ public:
 };
 template <> class NumericTraits<Vector<int, 4> > {
 public:
-  typedef Vector<int, 4> ValueType;
+  typedef int ValueType;
   typedef Vector<int, 4> PrintType;
   typedef Vector<unsigned int, 4> AbsType;
   typedef Vector<long, 4> AccumulateType;
@@ -417,7 +417,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned int, 4> > {
 public:
-  typedef Vector<unsigned int, 4> ValueType;
+  typedef unsigned int ValueType;
   typedef Vector<unsigned int, 4> PrintType;
   typedef Vector<unsigned int, 4> AbsType;
   typedef Vector<unsigned long, 4> AccumulateType;
@@ -430,7 +430,7 @@ public:
 };
 template <> class NumericTraits<Vector<long, 4> > {
 public:
-  typedef Vector<long, 4> ValueType;
+  typedef long ValueType;
   typedef Vector<long, 4> PrintType;
   typedef Vector<unsigned long, 4> AbsType;
   typedef Vector<long, 4> AccumulateType;
@@ -443,7 +443,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned long, 4> > {
 public:
-  typedef Vector<unsigned long, 4> ValueType;
+  typedef unsigned long ValueType;
   typedef Vector<unsigned long, 4> PrintType;
   typedef Vector<unsigned long, 4> AbsType;
   typedef Vector<unsigned long, 4> AccumulateType;
@@ -455,7 +455,7 @@ public:
 };
 template <> class NumericTraits<Vector<float, 4> > {
 public:
-  typedef Vector<float, 4> ValueType;
+  typedef float ValueType;
   typedef Vector<float, 4> PrintType;
   typedef Vector<float, 4> AbsType;
   typedef Vector<double, 4> AccumulateType;
@@ -468,7 +468,7 @@ public:
 };
 template <> class NumericTraits<Vector<double, 4> > {
 public:
-  typedef Vector<double, 4> ValueType;
+  typedef double ValueType;
   typedef Vector<double, 4> PrintType;
   typedef Vector<double, 4> AbsType;
   typedef Vector<long double, 4> AccumulateType;
@@ -481,7 +481,7 @@ public:
 };
 template <> class NumericTraits<Vector<long double, 4> > {
 public:
-  typedef Vector<long double, 4> ValueType;
+  typedef long double ValueType;
   typedef Vector<long double, 4> PrintType;
   typedef Vector<long double, 4> AbsType;
   typedef Vector<long double, 4> AccumulateType;
@@ -495,7 +495,7 @@ public:
 
 template <> class NumericTraits<Vector<unsigned char, 5 > > {
 public:
-  typedef Vector<unsigned char, 5> ValueType;
+  typedef unsigned char ValueType;
   typedef Vector<unsigned char, 5> PrintType;
   typedef Vector<unsigned char, 5> AbsType;
   typedef Vector<unsigned short, 5> AccumulateType;
@@ -508,7 +508,7 @@ public:
 };
 template <> class NumericTraits<Vector<signed char, 5> > {
 public:
-  typedef Vector<signed char, 5> ValueType;
+  typedef signed char ValueType;
   typedef Vector<signed char, 5> PrintType;
   typedef Vector<unsigned char, 5> AbsType;
   typedef Vector<short, 5> AccumulateType;
@@ -521,7 +521,7 @@ public:
 };
 template <> class NumericTraits<Vector<char, 5> > {
 public:
-  typedef Vector<char, 5> ValueType;
+  typedef char ValueType;
   typedef Vector<char, 5> PrintType;
   typedef Vector<unsigned char, 5> AbsType;
   typedef Vector<short, 5> AccumulateType;
@@ -534,7 +534,7 @@ public:
 };
 template <> class NumericTraits<Vector<short, 5> > {
 public:
-  typedef Vector<short, 5> ValueType;
+  typedef short ValueType;
   typedef Vector<short, 5> PrintType;
   typedef Vector<unsigned short, 5> AbsType;
   typedef Vector<int, 5> AccumulateType;
@@ -547,7 +547,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned short, 5> > {
 public:
-  typedef Vector<unsigned short, 5> ValueType;
+  typedef unsigned short ValueType;
   typedef Vector<unsigned short, 5> PrintType;
   typedef Vector<unsigned short, 5> AbsType;
   typedef Vector<unsigned int, 5> AccumulateType;
@@ -560,7 +560,7 @@ public:
 };
 template <> class NumericTraits<Vector<int, 5> > {
 public:
-  typedef Vector<int, 5> ValueType;
+  typedef int ValueType;
   typedef Vector<int, 5> PrintType;
   typedef Vector<unsigned int, 5> AbsType;
   typedef Vector<long, 5> AccumulateType;
@@ -573,7 +573,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned int, 5> > {
 public:
-  typedef Vector<unsigned int, 5> ValueType;
+  typedef unsigned int ValueType;
   typedef Vector<unsigned int, 5> PrintType;
   typedef Vector<unsigned int, 5> AbsType;
   typedef Vector<unsigned long, 5> AccumulateType;
@@ -586,7 +586,7 @@ public:
 };
 template <> class NumericTraits<Vector<long, 5> > {
 public:
-  typedef Vector<long, 5> ValueType;
+  typedef long ValueType;
   typedef Vector<long, 5> PrintType;
   typedef Vector<unsigned long, 5> AbsType;
   typedef Vector<long, 5> AccumulateType;
@@ -599,7 +599,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned long, 5> > {
 public:
-  typedef Vector<unsigned long, 5> ValueType;
+  typedef unsigned long ValueType;
   typedef Vector<unsigned long, 5> PrintType;
   typedef Vector<unsigned long, 5> AbsType;
   typedef Vector<unsigned long, 5> AccumulateType;
@@ -611,7 +611,7 @@ public:
 };
 template <> class NumericTraits<Vector<float, 5> > {
 public:
-  typedef Vector<float, 5> ValueType;
+  typedef float ValueType;
   typedef Vector<float, 5> PrintType;
   typedef Vector<float, 5> AbsType;
   typedef Vector<double, 5> AccumulateType;
@@ -624,7 +624,7 @@ public:
 };
 template <> class NumericTraits<Vector<double, 5> > {
 public:
-  typedef Vector<double, 5> ValueType;
+  typedef double ValueType;
   typedef Vector<double, 5> PrintType;
   typedef Vector<double, 5> AbsType;
   typedef Vector<long double, 5> AccumulateType;
@@ -637,7 +637,7 @@ public:
 };
 template <> class NumericTraits<Vector<long double, 5> > {
 public:
-  typedef Vector<long double, 5> ValueType;
+  typedef long double ValueType;
   typedef Vector<long double, 5> PrintType;
   typedef Vector<long double, 5> AbsType;
   typedef Vector<long double, 5> AccumulateType;
@@ -651,7 +651,7 @@ public:
 
 template <> class NumericTraits<Vector<unsigned char, 6 > > {
 public:
-  typedef Vector<unsigned char, 6> ValueType;
+  typedef unsigned char ValueType;
   typedef Vector<unsigned char, 6> PrintType;
   typedef Vector<unsigned char, 6> AbsType;
   typedef Vector<unsigned short, 6> AccumulateType;
@@ -664,7 +664,7 @@ public:
 };
 template <> class NumericTraits<Vector<signed char, 6> > {
 public:
-  typedef Vector<signed char, 6> ValueType;
+  typedef signed char ValueType;
   typedef Vector<signed char, 6> PrintType;
   typedef Vector<unsigned char, 6> AbsType;
   typedef Vector<short, 6> AccumulateType;
@@ -677,7 +677,7 @@ public:
 };
 template <> class NumericTraits<Vector<char, 6> > {
 public:
-  typedef Vector<char, 6> ValueType;
+  typedef char ValueType;
   typedef Vector<char, 6> PrintType;
   typedef Vector<unsigned char, 6> AbsType;
   typedef Vector<short, 6> AccumulateType;
@@ -690,7 +690,7 @@ public:
 };
 template <> class NumericTraits<Vector<short, 6> > {
 public:
-  typedef Vector<short, 6> ValueType;
+  typedef short ValueType;
   typedef Vector<short, 6> PrintType;
   typedef Vector<unsigned short, 6> AbsType;
   typedef Vector<int, 6> AccumulateType;
@@ -703,7 +703,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned short, 6> > {
 public:
-  typedef Vector<unsigned short, 6> ValueType;
+  typedef unsigned short ValueType;
   typedef Vector<unsigned short, 6> PrintType;
   typedef Vector<unsigned short, 6> AbsType;
   typedef Vector<unsigned int, 6> AccumulateType;
@@ -716,7 +716,7 @@ public:
 };
 template <> class NumericTraits<Vector<int, 6> > {
 public:
-  typedef Vector<int, 6> ValueType;
+  typedef int ValueType;
   typedef Vector<int, 6> PrintType;
   typedef Vector<unsigned int, 6> AbsType;
   typedef Vector<long, 6> AccumulateType;
@@ -729,7 +729,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned int, 6> > {
 public:
-  typedef Vector<unsigned int, 6> ValueType;
+  typedef unsigned int ValueType;
   typedef Vector<unsigned int, 6> PrintType;
   typedef Vector<unsigned int, 6> AbsType;
   typedef Vector<unsigned long, 6> AccumulateType;
@@ -742,7 +742,7 @@ public:
 };
 template <> class NumericTraits<Vector<long, 6> > {
 public:
-  typedef Vector<long, 6> ValueType;
+  typedef long ValueType;
   typedef Vector<long, 6> PrintType;
   typedef Vector<unsigned long, 6> AbsType;
   typedef Vector<long, 6> AccumulateType;
@@ -755,7 +755,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned long, 6> > {
 public:
-  typedef Vector<unsigned long, 6> ValueType;
+  typedef unsigned long ValueType;
   typedef Vector<unsigned long, 6> PrintType;
   typedef Vector<unsigned long, 6> AbsType;
   typedef Vector<unsigned long, 6> AccumulateType;
@@ -767,7 +767,7 @@ public:
 };
 template <> class NumericTraits<Vector<float, 6> > {
 public:
-  typedef Vector<float, 6> ValueType;
+  typedef float ValueType;
   typedef Vector<float, 6> PrintType;
   typedef Vector<float, 6> AbsType;
   typedef Vector<double, 6> AccumulateType;
@@ -780,7 +780,7 @@ public:
 };
 template <> class NumericTraits<Vector<double, 6> > {
 public:
-  typedef Vector<double, 6> ValueType;
+  typedef double ValueType;
   typedef Vector<double, 6> PrintType;
   typedef Vector<double, 6> AbsType;
   typedef Vector<long double, 6> AccumulateType;
@@ -793,7 +793,7 @@ public:
 };
 template <> class NumericTraits<Vector<long double, 6> > {
 public:
-  typedef Vector<long double, 6> ValueType;
+  typedef long double ValueType;
   typedef Vector<long double, 6> PrintType;
   typedef Vector<long double, 6> AbsType;
   typedef Vector<long double, 6> AccumulateType;
@@ -807,7 +807,7 @@ public:
 
 template <> class NumericTraits<Vector<unsigned char, 7 > > {
 public:
-  typedef Vector<unsigned char, 7> ValueType;
+  typedef unsigned char ValueType;
   typedef Vector<unsigned char, 7> PrintType;
   typedef Vector<unsigned char, 7> AbsType;
   typedef Vector<unsigned short, 7> AccumulateType;
@@ -820,7 +820,7 @@ public:
 };
 template <> class NumericTraits<Vector<signed char, 7> > {
 public:
-  typedef Vector<signed char, 7> ValueType;
+  typedef signed char ValueType;
   typedef Vector<signed char, 7> PrintType;
   typedef Vector<unsigned char, 7> AbsType;
   typedef Vector<short, 7> AccumulateType;
@@ -833,7 +833,7 @@ public:
 };
 template <> class NumericTraits<Vector<char, 7> > {
 public:
-  typedef Vector<char, 7> ValueType;
+  typedef char ValueType;
   typedef Vector<char, 7> PrintType;
   typedef Vector<unsigned char, 7> AbsType;
   typedef Vector<short, 7> AccumulateType;
@@ -846,7 +846,7 @@ public:
 };
 template <> class NumericTraits<Vector<short, 7> > {
 public:
-  typedef Vector<short, 7> ValueType;
+  typedef short ValueType;
   typedef Vector<short, 7> PrintType;
   typedef Vector<unsigned short, 7> AbsType;
   typedef Vector<int, 7> AccumulateType;
@@ -859,7 +859,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned short, 7> > {
 public:
-  typedef Vector<unsigned short, 7> ValueType;
+  typedef unsigned short ValueType;
   typedef Vector<unsigned short, 7> PrintType;
   typedef Vector<unsigned short, 7> AbsType;
   typedef Vector<unsigned int, 7> AccumulateType;
@@ -872,7 +872,7 @@ public:
 };
 template <> class NumericTraits<Vector<int, 7> > {
 public:
-  typedef Vector<int, 7> ValueType;
+  typedef int ValueType;
   typedef Vector<int, 7> PrintType;
   typedef Vector<unsigned int, 7> AbsType;
   typedef Vector<long, 7> AccumulateType;
@@ -885,7 +885,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned int, 7> > {
 public:
-  typedef Vector<unsigned int, 7> ValueType;
+  typedef unsigned int ValueType;
   typedef Vector<unsigned int, 7> PrintType;
   typedef Vector<unsigned int, 7> AbsType;
   typedef Vector<unsigned long, 7> AccumulateType;
@@ -898,7 +898,7 @@ public:
 };
 template <> class NumericTraits<Vector<long, 7> > {
 public:
-  typedef Vector<long, 7> ValueType;
+  typedef long ValueType;
   typedef Vector<long, 7> PrintType;
   typedef Vector<unsigned long, 7> AbsType;
   typedef Vector<long, 7> AccumulateType;
@@ -911,7 +911,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned long, 7> > {
 public:
-  typedef Vector<unsigned long, 7> ValueType;
+  typedef unsigned long ValueType;
   typedef Vector<unsigned long, 7> PrintType;
   typedef Vector<unsigned long, 7> AbsType;
   typedef Vector<unsigned long, 7> AccumulateType;
@@ -923,7 +923,7 @@ public:
 };
 template <> class NumericTraits<Vector<float, 7> > {
 public:
-  typedef Vector<float, 7> ValueType;
+  typedef float ValueType;
   typedef Vector<float, 7> PrintType;
   typedef Vector<float, 7> AbsType;
   typedef Vector<double, 7> AccumulateType;
@@ -936,7 +936,7 @@ public:
 };
 template <> class NumericTraits<Vector<double, 7> > {
 public:
-  typedef Vector<double, 7> ValueType;
+  typedef double ValueType;
   typedef Vector<double, 7> PrintType;
   typedef Vector<double, 7> AbsType;
   typedef Vector<long double, 7> AccumulateType;
@@ -949,7 +949,7 @@ public:
 };
 template <> class NumericTraits<Vector<long double, 7> > {
 public:
-  typedef Vector<long double, 7> ValueType;
+  typedef long double ValueType;
   typedef Vector<long double, 7> PrintType;
   typedef Vector<long double, 7> AbsType;
   typedef Vector<long double, 7> AccumulateType;
@@ -963,7 +963,7 @@ public:
 
 template <> class NumericTraits<Vector<unsigned char, 8 > > {
 public:
-  typedef Vector<unsigned char, 8> ValueType;
+  typedef unsigned char ValueType;
   typedef Vector<unsigned char, 8> PrintType;
   typedef Vector<unsigned char, 8> AbsType;
   typedef Vector<unsigned short, 8> AccumulateType;
@@ -976,7 +976,7 @@ public:
 };
 template <> class NumericTraits<Vector<signed char, 8> > {
 public:
-  typedef Vector<signed char, 8> ValueType;
+  typedef signed char ValueType;
   typedef Vector<signed char, 8> PrintType;
   typedef Vector<unsigned char, 8> AbsType;
   typedef Vector<short, 8> AccumulateType;
@@ -989,7 +989,7 @@ public:
 };
 template <> class NumericTraits<Vector<char, 8> > {
 public:
-  typedef Vector<char, 8> ValueType;
+  typedef char ValueType;
   typedef Vector<char, 8> PrintType;
   typedef Vector<unsigned char, 8> AbsType;
   typedef Vector<short, 8> AccumulateType;
@@ -1002,7 +1002,7 @@ public:
 };
 template <> class NumericTraits<Vector<short, 8> > {
 public:
-  typedef Vector<short, 8> ValueType;
+  typedef short ValueType;
   typedef Vector<short, 8> PrintType;
   typedef Vector<unsigned short, 8> AbsType;
   typedef Vector<int, 8> AccumulateType;
@@ -1015,7 +1015,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned short, 8> > {
 public:
-  typedef Vector<unsigned short, 8> ValueType;
+  typedef unsigned short ValueType;
   typedef Vector<unsigned short, 8> PrintType;
   typedef Vector<unsigned short, 8> AbsType;
   typedef Vector<unsigned int, 8> AccumulateType;
@@ -1028,7 +1028,7 @@ public:
 };
 template <> class NumericTraits<Vector<int, 8> > {
 public:
-  typedef Vector<int, 8> ValueType;
+  typedef int ValueType;
   typedef Vector<int, 8> PrintType;
   typedef Vector<unsigned int, 8> AbsType;
   typedef Vector<long, 8> AccumulateType;
@@ -1041,7 +1041,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned int, 8> > {
 public:
-  typedef Vector<unsigned int, 8> ValueType;
+  typedef unsigned int ValueType;
   typedef Vector<unsigned int, 8> PrintType;
   typedef Vector<unsigned int, 8> AbsType;
   typedef Vector<unsigned long, 8> AccumulateType;
@@ -1054,7 +1054,7 @@ public:
 };
 template <> class NumericTraits<Vector<long, 8> > {
 public:
-  typedef Vector<long, 8> ValueType;
+  typedef long ValueType;
   typedef Vector<long, 8> PrintType;
   typedef Vector<unsigned long, 8> AbsType;
   typedef Vector<long, 8> AccumulateType;
@@ -1067,7 +1067,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned long, 8> > {
 public:
-  typedef Vector<unsigned long, 8> ValueType;
+  typedef unsigned long ValueType;
   typedef Vector<unsigned long, 8> PrintType;
   typedef Vector<unsigned long, 8> AbsType;
   typedef Vector<unsigned long, 8> AccumulateType;
@@ -1079,7 +1079,7 @@ public:
 };
 template <> class NumericTraits<Vector<float, 8> > {
 public:
-  typedef Vector<float, 8> ValueType;
+  typedef float ValueType;
   typedef Vector<float, 8> PrintType;
   typedef Vector<float, 8> AbsType;
   typedef Vector<double, 8> AccumulateType;
@@ -1092,7 +1092,7 @@ public:
 };
 template <> class NumericTraits<Vector<double, 8> > {
 public:
-  typedef Vector<double, 8> ValueType;
+  typedef double ValueType;
   typedef Vector<double, 8> PrintType;
   typedef Vector<double, 8> AbsType;
   typedef Vector<long double, 8> AccumulateType;
@@ -1105,7 +1105,7 @@ public:
 };
 template <> class NumericTraits<Vector<long double, 8> > {
 public:
-  typedef Vector<long double, 8> ValueType;
+  typedef long double ValueType;
   typedef Vector<long double, 8> PrintType;
   typedef Vector<long double, 8> AbsType;
   typedef Vector<long double, 8> AccumulateType;
@@ -1119,7 +1119,7 @@ public:
 
 template <> class NumericTraits<Vector<unsigned char, 9 > > {
 public:
-  typedef Vector<unsigned char, 9> ValueType;
+  typedef unsigned char ValueType;
   typedef Vector<unsigned char, 9> PrintType;
   typedef Vector<unsigned char, 9> AbsType;
   typedef Vector<unsigned short, 9> AccumulateType;
@@ -1132,7 +1132,7 @@ public:
 };
 template <> class NumericTraits<Vector<signed char, 9> > {
 public:
-  typedef Vector<signed char, 9> ValueType;
+  typedef signed char ValueType;
   typedef Vector<signed char, 9> PrintType;
   typedef Vector<unsigned char, 9> AbsType;
   typedef Vector<short, 9> AccumulateType;
@@ -1145,7 +1145,7 @@ public:
 };
 template <> class NumericTraits<Vector<char, 9> > {
 public:
-  typedef Vector<char, 9> ValueType;
+  typedef char ValueType;
   typedef Vector<char, 9> PrintType;
   typedef Vector<unsigned char, 9> AbsType;
   typedef Vector<short, 9> AccumulateType;
@@ -1158,7 +1158,7 @@ public:
 };
 template <> class NumericTraits<Vector<short, 9> > {
 public:
-  typedef Vector<short, 9> ValueType;
+  typedef short ValueType;
   typedef Vector<short, 9> PrintType;
   typedef Vector<unsigned short, 9> AbsType;
   typedef Vector<int, 9> AccumulateType;
@@ -1171,7 +1171,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned short, 9> > {
 public:
-  typedef Vector<unsigned short, 9> ValueType;
+  typedef unsigned short ValueType;
   typedef Vector<unsigned short, 9> PrintType;
   typedef Vector<unsigned short, 9> AbsType;
   typedef Vector<unsigned int, 9> AccumulateType;
@@ -1184,7 +1184,7 @@ public:
 };
 template <> class NumericTraits<Vector<int, 9> > {
 public:
-  typedef Vector<int, 9> ValueType;
+  typedef int ValueType;
   typedef Vector<int, 9> PrintType;
   typedef Vector<unsigned int, 9> AbsType;
   typedef Vector<long, 9> AccumulateType;
@@ -1197,7 +1197,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned int, 9> > {
 public:
-  typedef Vector<unsigned int, 9> ValueType;
+  typedef unsigned int ValueType;
   typedef Vector<unsigned int, 9> PrintType;
   typedef Vector<unsigned int, 9> AbsType;
   typedef Vector<unsigned long, 9> AccumulateType;
@@ -1210,7 +1210,7 @@ public:
 };
 template <> class NumericTraits<Vector<long, 9> > {
 public:
-  typedef Vector<long, 9> ValueType;
+  typedef long ValueType;
   typedef Vector<long, 9> PrintType;
   typedef Vector<unsigned long, 9> AbsType;
   typedef Vector<long, 9> AccumulateType;
@@ -1223,7 +1223,7 @@ public:
 };
 template <> class NumericTraits<Vector<unsigned long, 9> > {
 public:
-  typedef Vector<unsigned long, 9> ValueType;
+  typedef unsigned long ValueType;
   typedef Vector<unsigned long, 9> PrintType;
   typedef Vector<unsigned long, 9> AbsType;
   typedef Vector<unsigned long, 9> AccumulateType;
@@ -1235,7 +1235,7 @@ public:
 };
 template <> class NumericTraits<Vector<float, 9> > {
 public:
-  typedef Vector<float, 9> ValueType;
+  typedef float ValueType;
   typedef Vector<float, 9> PrintType;
   typedef Vector<float, 9> AbsType;
   typedef Vector<double, 9> AccumulateType;
@@ -1248,7 +1248,7 @@ public:
 };
 template <> class NumericTraits<Vector<double, 9> > {
 public:
-  typedef Vector<double, 9> ValueType;
+  typedef double ValueType;
   typedef Vector<double, 9> PrintType;
   typedef Vector<double, 9> AbsType;
   typedef Vector<long double, 9> AccumulateType;
@@ -1261,7 +1261,7 @@ public:
 };
 template <> class NumericTraits<Vector<long double, 9> > {
 public:
-  typedef Vector<long double, 9> ValueType;
+  typedef long double ValueType;
   typedef Vector<long double, 9> PrintType;
   typedef Vector<long double, 9> AbsType;
   typedef Vector<long double, 9> AccumulateType;
