@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkWindows.h,v $
   Language:  C++
-  Date:      $Date: 2006/03/18 18:06:38 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2007-10-29 00:34:16 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,6 +21,9 @@
 #ifndef NOMINMAX
 #define NOMINMAX
 #endif
+#ifdef WIN32_LEAN_AND_MEAN
+#undef WIN32_LEAN_AND_MEAN
+#endif
 #define WIN32_LEAN_AND_MEAN
 #include <windows.h>
 #include <winbase.h>
