@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBMPImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2006/12/18 19:38:22 $
-  Version:   $Revision: 1.18 $  
+  Date:      $Date: 2008-03-10 23:59:06 $
+  Version:   $Revision: 1.26 $  
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -53,7 +53,6 @@ BMPImageIO::BMPImageIO()
 /** Destructor */
 BMPImageIO::~BMPImageIO()
 {
-  m_Ifstream.close();
 }
 
 
@@ -101,7 +100,7 @@ bool BMPImageIO::CanReadFile( const char* filename )
 
   if ((magic_number1 != 'B')||(magic_number2 != 'M'))
     {
-    std::cout << "BMPImageIO : Magic Number Fails = " << magic_number1 << " : " << magic_number2 << std::endl;
+    std::cerr << "BMPImageIO : Magic Number Fails = " << magic_number1 << " : " << magic_number2 << std::endl;
     inputStream.close();
     return false;
     }
@@ -112,7 +111,7 @@ bool BMPImageIO::CanReadFile( const char* filename )
   int  itmp;       // in case we are on a 64bit machine
 
   // get the size of the file
-  int sizeLong = sizeof(long);
+  ::size_t sizeLong = sizeof(long);
   if (sizeLong == 4)
     {
     inputStream.read((char*)&tmp,4);
@@ -134,7 +133,7 @@ bool BMPImageIO::CanReadFile( const char* filename )
   if (sizeLong == 4)   // if we are on a 32 bit machine
     {
     inputStream.read((char*)&infoSize,sizeof(long));
-    ByteSwapper<long>::SwapFromSystemToLittleEndian(&infoSize);                      
+    ByteSwapper<long>::SwapFromSystemToLittleEndian(&infoSize);
     // error checking
     if ((infoSize != 40)&&(infoSize != 12))
       {
@@ -144,7 +143,7 @@ bool BMPImageIO::CanReadFile( const char* filename )
     }
   else    // else we are on a 64bit machine
     {
-    inputStream.read((char*)&iinfoSize,sizeof(int));
+    inputStream.read((char*)&iinfoSize,4);
     ByteSwapper<int>::SwapFromSystemToLittleEndian(&iinfoSize);
     infoSize = iinfoSize;
     
@@ -204,6 +203,8 @@ void BMPImageIO::Read(void* buffer)
   unsigned long step = this->GetNumberOfComponents();
   long streamRead = m_Dimensions[0]*m_Depth/8;
 
+  m_Ifstream.open( m_FileName.c_str(), std::ios::in | std::ios::binary );
+
   long paddedStreamRead = streamRead;
   if( streamRead % 4 )
     {
@@ -214,7 +215,7 @@ void BMPImageIO::Read(void* buffer)
   if (m_FileLowerLeft)
     {
     // If the file is RLE compressed
-    if(m_BMPCompression == 1 && this->GetNumberOfComponents()==3)
+    if(m_BMPCompression == 1 && this->GetNumberOfComponents() == 3)
       {
       delete [] value;
       value = new char[m_BMPDataSize+1];
@@ -255,42 +256,55 @@ void BMPImageIO::Read(void* buffer)
         }
       }
     else
-    for(unsigned int id=0;id<m_Dimensions[1];id++)
       {
-      m_Ifstream.seekg(m_BitMapOffset + paddedStreamRead*(m_Dimensions[1] - id - 1),std::ios::beg);
-      m_Ifstream.read((char *)value, paddedStreamRead);
-      for(long i=0;i<streamRead;i++)
+      for(unsigned int id=0;id<m_Dimensions[1];id++)
         {
-        if(this->GetNumberOfComponents() == 1)
+        m_Ifstream.seekg(m_BitMapOffset + paddedStreamRead*(m_Dimensions[1] - id - 1),std::ios::beg);
+        m_Ifstream.read((char *)value, paddedStreamRead);
+
+        for(long i=0;i<streamRead;i++)
           {
-          p[l++]=value[i];
-          }
-        else
-          {
-          if(m_NumberOfColors == 0)
+          if(this->GetNumberOfComponents() == 1)
             {
-            p[l++]=value[i+2];
-            p[l++]=value[i+1];
             p[l++]=value[i];
-            i += step-1;
             }
           else
             {
-            unsigned char val = value[i];       
-            RGBPixelType rbg;
-            if(val<m_ColorPalette.size())
+            if(m_NumberOfColors == 0)
               {
-              rbg = m_ColorPalette[val];
+              if(this->GetNumberOfComponents() == 3 )
+                {
+                p[l++]=value[i+2];
+                p[l++]=value[i+1];
+                p[l++]=value[i];
+                }
+              if(this->GetNumberOfComponents() == 4 )
+                {
+                p[l++]=value[i+3];
+                p[l++]=value[i+2];
+                p[l++]=value[i+1];
+                p[l++]=value[i];
+                }
+              i += step-1;
               }
             else
               {
-              rbg.SetRed(0);
-              rbg.SetGreen(0);
-              rbg.SetBlue(0);
+              unsigned char val = value[i];
+              RGBPixelType rbg;
+              if(val<m_ColorPalette.size())
+                {
+                rbg = m_ColorPalette[val];
+                }
+              else
+                {
+                rbg.SetRed(0);
+                rbg.SetGreen(0);
+                rbg.SetBlue(0);
+                }
+              p[l++]=rbg.GetBlue();
+              p[l++]=rbg.GetGreen();
+              p[l++]=rbg.GetRed();
               }
-            p[l++]=rbg.GetBlue();
-            p[l++]=rbg.GetGreen();
-            p[l++]=rbg.GetRed();
             }
           }
         }
@@ -352,13 +366,13 @@ void BMPImageIO::ReadImageInformation()
 
   if ((magic_number1 != 'B')||(magic_number2 != 'M'))
     {
-    std::cout << "BMPImageIO : Magic Number Fails = " << magic_number1 << " : " << magic_number2 << std::endl;
     m_Ifstream.close();
+    itkExceptionMacro( "BMPImageIO : Magic Number Fails = " << magic_number1 << " : " << magic_number2 );
     return;
     }
 
   // get the size of the file
-  int sizeLong = sizeof(long);
+  ::size_t sizeLong = sizeof(long);
   if (sizeLong == 4)
     {
     m_Ifstream.read((char*)&tmp,4);
@@ -383,14 +397,14 @@ void BMPImageIO::ReadImageInformation()
   // get size of header
   if (sizeLong == 4)   // if we are on a 32 bit machine
     {
-    m_Ifstream.read((char*)&infoSize,sizeof(long));
+    m_Ifstream.read((char*)&infoSize,4);
     ByteSwapper<long>::SwapFromSystemToLittleEndian(&infoSize);
                        
     // error checking
     if ((infoSize != 40)&&(infoSize != 12))
       {
       itkExceptionMacro(<<"Unknown file type! " << m_FileName.c_str() 
-                    <<" is not a Windows BMP file!");
+                        <<" is not a Windows BMP file!");
       m_Ifstream.close();
       return;
       }
@@ -399,9 +413,9 @@ void BMPImageIO::ReadImageInformation()
     if (infoSize == 40)
       {
       // now get the dimensions
-      m_Ifstream.read((char*)&xsize,sizeof(long));
+      m_Ifstream.read((char*)&xsize,4);
       ByteSwapper<int>::SwapFromSystemToLittleEndian(&xsize);
-      m_Ifstream.read((char*)&ysize,sizeof(long));
+      m_Ifstream.read((char*)&ysize,4);
       ByteSwapper<int>::SwapFromSystemToLittleEndian(&ysize);
       }
     else
@@ -425,7 +439,7 @@ void BMPImageIO::ReadImageInformation()
     if ((infoSize != 40)&&(infoSize != 12))
       {
       itkExceptionMacro(<<"Unknown file type! " << m_FileName.c_str() 
-                    <<" is not a Windows BMP file!");
+                        <<" is not a Windows BMP file!");
       m_Ifstream.close();
       return;
       }
@@ -434,18 +448,18 @@ void BMPImageIO::ReadImageInformation()
     if (infoSize == 40)
       {
       // now get the dimensions
-      m_Ifstream.read((char*)&xsize,sizeof(int));
+      m_Ifstream.read((char*)&xsize,4);
       ByteSwapper<int>::SwapFromSystemToLittleEndian(&xsize);
-      m_Ifstream.read((char*)&ysize,sizeof(int));
+      m_Ifstream.read((char*)&ysize,4);
       ByteSwapper<int>::SwapFromSystemToLittleEndian(&ysize);
       }
     else
       {
       stmp =0;
-      m_Ifstream.read((char*)&xsize,sizeof(short));
+      m_Ifstream.read((char*)&stmp,2);
       ByteSwapper<short>::SwapFromSystemToLittleEndian(&stmp);
       xsize = stmp;
-      m_Ifstream.read((char*)&xsize,sizeof(short));
+      m_Ifstream.read((char*)&stmp,2);
       ByteSwapper<short>::SwapFromSystemToLittleEndian(&stmp);
       ysize = stmp;
       }
@@ -467,87 +481,104 @@ void BMPImageIO::ReadImageInformation()
     }
     
   // ignore planes
-  m_Ifstream.read((char*)&stmp,sizeof(short));
+  m_Ifstream.read((char*)&stmp,2);
   // read depth
-  m_Ifstream.read((char*)&m_Depth,sizeof(short));
+  m_Ifstream.read((char*)&m_Depth,2);
   ByteSwapper<short>::SwapFromSystemToLittleEndian(&m_Depth);
 
-  if ((m_Depth != 8)&&(m_Depth != 24))
+  if ((m_Depth != 8)&&(m_Depth != 24)&&(m_Depth != 32))
     {
-    std::cout <<"Only BMP depths of (8,24) are supported. Not " << m_Depth << std::endl;
     m_Ifstream.close();
+    itkExceptionMacro( "Only BMP depths of (8,24,32) are supported. Not " << m_Depth );
     return;
     }
   
-  // skip over rest of info for long format
   if (infoSize == 40)
     {
-    // Compression
-    m_Ifstream.read((char*)&m_BMPCompression,4);
-    ByteSwapper<long>::SwapFromSystemToLittleEndian(&m_BMPCompression);
-    // Image Data Size
-    m_Ifstream.read((char*)&m_BMPDataSize,4);
-    ByteSwapper<unsigned long>::SwapFromSystemToLittleEndian(&m_BMPDataSize);
-    // Horizontal Resolution
-    m_Ifstream.read((char*)&tmp,4);
-    // Vertical Resolution
-    m_Ifstream.read((char*)&tmp,4);
-    // Number of colors
-    m_Ifstream.read((char*)&tmp,4);
-    m_NumberOfColors = tmp;
-    // Number of important colors
-    m_Ifstream.read((char*)&tmp,4);
+    if (sizeLong == 4)
+      {
+      // Compression
+      m_Ifstream.read((char*)&m_BMPCompression,4);
+      ByteSwapper<long>::SwapFromSystemToLittleEndian(&m_BMPCompression);
+      // Image Data Size
+      m_Ifstream.read((char*)&m_BMPDataSize,4);
+      ByteSwapper<unsigned long>::SwapFromSystemToLittleEndian(&m_BMPDataSize);
+      // Horizontal Resolution
+      m_Ifstream.read((char*)&tmp,4);
+      // Vertical Resolution
+      m_Ifstream.read((char*)&tmp,4);
+      // Number of colors
+      m_Ifstream.read((char*)&tmp,4);
+      m_NumberOfColors = tmp;
+      // Number of important colors
+      m_Ifstream.read((char*)&tmp,4);
+      }
+    else
+      {
+      // Compression
+      m_Ifstream.read((char*)&itmp,4);
+      ByteSwapper<int>::SwapFromSystemToLittleEndian(&itmp);
+      m_BMPCompression = static_cast<long>(itmp);
+      // Image Data Size
+      m_Ifstream.read((char*)&itmp,4);
+      ByteSwapper<int>::SwapFromSystemToLittleEndian(&itmp);
+      m_BMPDataSize = static_cast<unsigned long>(itmp);
+      // Horizontal Resolution
+      m_Ifstream.read((char*)&itmp,4);
+      ByteSwapper<int>::SwapFromSystemToLittleEndian(&itmp);
+      // Vertical Resolution
+      m_Ifstream.read((char*)&itmp,4);
+      ByteSwapper<int>::SwapFromSystemToLittleEndian(&itmp);
+      // Number of colors
+      m_Ifstream.read((char*)&itmp,4);
+      ByteSwapper<int>::SwapFromSystemToLittleEndian(&itmp);
+      m_NumberOfColors = static_cast<unsigned short>(itmp);
+      // Number of important colors
+      m_Ifstream.read((char*)&itmp,4);
+      }
     }
-  else
-    {
-    // Compression
-    m_Ifstream.read((char*)&tmp,sizeof(long));
-    ByteSwapper<long>::SwapFromSystemToLittleEndian(&tmp);
-    // Image Data Size
-    m_Ifstream.read((char*)&tmp,sizeof(long));
-    ByteSwapper<long>::SwapFromSystemToLittleEndian(&tmp);
-    // Horizontal Resolution
-    m_Ifstream.read((char*)&tmp,sizeof(long));
-    ByteSwapper<long>::SwapFromSystemToLittleEndian(&tmp);
-    // Vertical Resolution
-    m_Ifstream.read((char*)&tmp,sizeof(long));
-    ByteSwapper<long>::SwapFromSystemToLittleEndian(&tmp);
-    // Number of colors
-    m_Ifstream.read((char*)&tmp,sizeof(long));
-    ByteSwapper<long>::SwapFromSystemToLittleEndian(&tmp);
-    m_NumberOfColors = tmp;
-    // Number of important colors
-    m_Ifstream.read((char*)&tmp,sizeof(long));
-    ByteSwapper<long>::SwapFromSystemToLittleEndian(&tmp);
-    }
-    
+
   // Read the color palette
+  unsigned char uctmp;
   for(unsigned long i=0;i<m_NumberOfColors;i++)
     {
     RGBPixelType p;
-    m_Ifstream.read((char*)&tmp,1);
-    p.SetRed(tmp);
-    m_Ifstream.read((char*)&tmp,1);
-    p.SetGreen(tmp);
-    m_Ifstream.read((char*)&tmp,1);
-    p.SetBlue(tmp);
+    m_Ifstream.read((char*)&uctmp,1);
+    p.SetRed(uctmp);
+    m_Ifstream.read((char*)&uctmp,1);
+    p.SetGreen(uctmp);
+    m_Ifstream.read((char*)&uctmp,1);
+    p.SetBlue(uctmp);
     m_Ifstream.read((char*)&tmp,1);
     m_ColorPalette.push_back(p);
     }
 
-  if ((m_Depth == 8) && m_Allow8BitBMP)
+  switch( m_Depth )
     {
-    this->SetNumberOfComponents(1);
-    }
-  else
-    {
-    this->SetNumberOfComponents(3);
+    case 8:
+      {
+      if( m_Allow8BitBMP )
+        {
+        this->SetNumberOfComponents(1);
+        m_PixelType = SCALAR;
+        }
+      break;
+      }
+    case 24:
+      {
+      this->SetNumberOfComponents(3);
+      m_PixelType = RGB;
+      break;
+      }
+    case 32:
+      {
+      this->SetNumberOfComponents(4);
+      m_PixelType = RGBA;
+      break;
+      }
     }
 
-  if(m_NumberOfColors>0)
-    {
-    this->SetNumberOfComponents(3);
-    }
+  m_Ifstream.close();
 }
 
 
@@ -558,67 +589,93 @@ BMPImageIO
   switch(m_ComponentType)
     {
     case CHAR:
-    {
-    if ( m_ByteOrder == LittleEndian )
       {
-      ByteSwapper<char>::SwapRangeFromSystemToLittleEndian(
-        (char*)buffer, numberOfPixels );
+      if ( m_ByteOrder == LittleEndian )
+        {
+        ByteSwapper<char>::SwapRangeFromSystemToLittleEndian(
+          (char*)buffer, numberOfPixels );
+        }
+      else if ( m_ByteOrder == BigEndian )
+        {
+        ByteSwapper<char>::SwapRangeFromSystemToBigEndian(
+          (char *)buffer, numberOfPixels );
+        }
+      break;
       }
-    else if ( m_ByteOrder == BigEndian )
-      {
-      ByteSwapper<char>::SwapRangeFromSystemToBigEndian(
-        (char *)buffer, numberOfPixels );
-      }
-    break;
-    }
     case UCHAR:
-    {
-    if ( m_ByteOrder == LittleEndian )
       {
-      ByteSwapper<unsigned char>::SwapRangeFromSystemToLittleEndian(
-        (unsigned char*)buffer, numberOfPixels );
+      if ( m_ByteOrder == LittleEndian )
+        {
+        ByteSwapper<unsigned char>::SwapRangeFromSystemToLittleEndian(
+          (unsigned char*)buffer, numberOfPixels );
+        }
+      else if ( m_ByteOrder == BigEndian )
+        {
+        ByteSwapper<unsigned char>::SwapRangeFromSystemToBigEndian(
+          (unsigned char *)buffer, numberOfPixels );
+        }
+      break;
       }
-    else if ( m_ByteOrder == BigEndian )
-      {
-      ByteSwapper<unsigned char>::SwapRangeFromSystemToBigEndian(
-        (unsigned char *)buffer, numberOfPixels );
-      }
-    break;
-    }
     case SHORT:
-    {
-    if ( m_ByteOrder == LittleEndian )
       {
-      ByteSwapper<short>::SwapRangeFromSystemToLittleEndian(
-        (short*)buffer, numberOfPixels );
+      if ( m_ByteOrder == LittleEndian )
+        {
+        ByteSwapper<short>::SwapRangeFromSystemToLittleEndian(
+          (short*)buffer, numberOfPixels );
+        }
+      else if ( m_ByteOrder == BigEndian )
+        {
+        ByteSwapper<short>::SwapRangeFromSystemToBigEndian(
+          (short *)buffer, numberOfPixels );
+        }
+      break;
       }
-    else if ( m_ByteOrder == BigEndian )
-      {
-      ByteSwapper<short>::SwapRangeFromSystemToBigEndian(
-        (short *)buffer, numberOfPixels );
-      }
-    break;
-    }
     case USHORT:
-    {
-    if ( m_ByteOrder == LittleEndian )
       {
-      ByteSwapper<unsigned short>::SwapRangeFromSystemToLittleEndian(
-        (unsigned short*)buffer, numberOfPixels );
+      if ( m_ByteOrder == LittleEndian )
+        {
+        ByteSwapper<unsigned short>::SwapRangeFromSystemToLittleEndian(
+          (unsigned short*)buffer, numberOfPixels );
+        }
+      else if ( m_ByteOrder == BigEndian )
+        {
+        ByteSwapper<unsigned short>::SwapRangeFromSystemToBigEndian(
+          (unsigned short *)buffer, numberOfPixels );
+        }
+      break; 
       }
-    else if ( m_ByteOrder == BigEndian )
-      {
-      ByteSwapper<unsigned short>::SwapRangeFromSystemToBigEndian(
-        (unsigned short *)buffer, numberOfPixels );
-      }
-    break; 
-    }
     default:
       itkExceptionMacro(<< "Pixel Type Unknown");
     }
 }
 
 
+void 
+BMPImageIO
+::Write32BitsInteger( unsigned int value )
+{
+  char tmp;
+  tmp = value%256;
+  m_Ofstream.write(&tmp,sizeof(char));
+  tmp = (value%65536L)/256;
+  m_Ofstream.write(&tmp,sizeof(char));
+  tmp = (value/65536L)%256;
+  m_Ofstream.write(&tmp,sizeof(char));
+  tmp = (value/65536L)/256;
+  m_Ofstream.write(&tmp,sizeof(char));
+}
+
+void 
+BMPImageIO
+::Write16BitsInteger( unsigned short value )
+{
+  char tmp;
+  tmp = value%256;
+  m_Ofstream.write(&tmp,sizeof(char));
+  tmp = (value%65536L)/256;
+  m_Ofstream.write(&tmp,sizeof(char));
+}
+
 void 
 BMPImageIO
 ::WriteImageInformation(void)
@@ -626,7 +683,6 @@ BMPImageIO
   
 }
 
-
 /** The write function is not implemented */
 void 
 BMPImageIO
@@ -644,16 +700,18 @@ BMPImageIO
     {
     itkExceptionMacro(<<"BMPImageIO supports unsigned char only");
     }
-  if( (this->m_NumberOfComponents != 1) && (this->m_NumberOfComponents !=3) )
+  if( (this->m_NumberOfComponents != 1) && 
+      (this->m_NumberOfComponents != 3) && 
+      (this->m_NumberOfComponents != 4) )
     {
-    itkExceptionMacro(<<"BMPImageIO supports 1 or 3 components only");
+    itkExceptionMacro(<<"BMPImageIO supports 1,3 or 4 components only");
     }
   
 
 #ifdef __sgi
   // Create the file. This is required on some older sgi's
   std::ofstream tFile(m_FileName.c_str(),std::ios::out);
-  tFile.close();                    
+  tFile.close();
 #endif
 
   m_Ofstream.open(m_FileName.c_str(), std::ios::binary | std::ios::out);
@@ -665,126 +723,160 @@ BMPImageIO
                       << itksys::SystemTools::GetLastSystemError());
     }
 
-  // Write the header  
-  // spit out the BMP header
+  //
+  //
+  // A BMP file has four sections:
+  //
+  // * BMP Header                         14 bytes
+  // * Bitmap Information (DIB header)    40 bytes (Windows V3) 
+  // * Color Palette
+  // * Bitmap Data
+  //
+  // For more details:
+  //
+  //             http://en.wikipedia.org/wiki/BMP_file_format
+  //
+  //
+  
+  // Write the BMP header
+  //
   // Header structure is represented by first a 14 byte field, then the bitmap 
   // info header. 
   // 
   // The 14 byte field:
-  // first 2 bytes contain the string, "BM", and whose next 4 bytes contain
-  // the length of the entire file.  The next 4 bytes must be 0. The final
-  // 4 bytes provides an offset from the start of the file to the first byte
-  // of image sample data. If the bit_count is 1, 4 or 8, the structure must 
-  // be followed by a colour lookup table, with 4 bytes per entry, the first 
-  // 3 of which identify the blue, green and red intensities, respectively.
+  // 
+  // Offset Length Description
+  // 
+  //   0      2    Contain the string, "BM", (Hex: 42 4D)
+  //   2      4    The length of the entire file.  
+  //   6      2    Reserved for application data. Usually zero.
+  //   8      2    Reserved for application data. Usually zero.
+  //  10      4    Provides an offset from the start of the file 
+  //               to the first byte of image sample data. This 
+  //               is normally 54 bytes (Hex: 36)
   //
   char tmp = 66;
   m_Ofstream.write(&tmp,sizeof(char));
   tmp = 77;
   m_Ofstream.write(&tmp,sizeof(char));
 
-  unsigned int bpp = this->GetNumberOfComponents(); 
+  const unsigned int bpp = this->GetNumberOfComponents(); 
   long bytesPerRow = m_Dimensions[0]*bpp;  
   if ( bytesPerRow % 4 )
     {
     bytesPerRow = ( ( bytesPerRow / 4 ) + 1 ) * 4;
     }
-  unsigned long paddedBytes = bytesPerRow - (m_Dimensions[0]*bpp);
+  const unsigned long paddedBytes = bytesPerRow - (m_Dimensions[0]*bpp);
 
-  long temp = (long)( bytesPerRow * m_Dimensions[1]) + 54L;
+  const unsigned int rawImageDataSize = ( bytesPerRow * m_Dimensions[1]);
+  unsigned int fileSize = ( rawImageDataSize ) + 54;
   if( bpp == 1 ) 
     {
-    temp += 1024; // need colour LUT
+    fileSize += 1024; // need colour LUT
     }
+  this->Write32BitsInteger( fileSize );
 
-  tmp = temp%256;
-  m_Ofstream.write(&tmp,sizeof(char));
-  tmp = (temp%65536L)/256;
-  m_Ofstream.write(&tmp,sizeof(char));
-  tmp = temp/65536L;
-  m_Ofstream.write(&tmp,sizeof(char));
-  tmp =0;
+  const unsigned short applicationReservedValue = 0;
+  this->Write16BitsInteger( applicationReservedValue );
+  this->Write16BitsInteger( applicationReservedValue );
 
-  int row;
-  for(row = 0; row < 5; row++)
+  unsigned int offsetToBinaryDataStart = 54;
+  if( bpp == 1 ) // more space is needed for the LUT
     {
-    m_Ofstream.write(&tmp,sizeof(char));
+    offsetToBinaryDataStart += 1024;
     }
-
-  tmp=54;
-  m_Ofstream.write(&tmp,sizeof(char));
-  if( bpp == 1 ) 
-    {
-    tmp=4;
-    m_Ofstream.write(&tmp,sizeof(char));
-    }
-  else if(bpp==3)
-    {
-    tmp=0;
-    m_Ofstream.write(&tmp,sizeof(char));
-    }
-  tmp =0;
-  m_Ofstream.write(&tmp,sizeof(char));
-  m_Ofstream.write(&tmp,sizeof(char));
+  this->Write32BitsInteger( offsetToBinaryDataStart );
+  //  
+  // End of BMP header, 14 bytes written so far
+  //
   
-  // info header, 14 bytes written so far
-  tmp = 40;  // bitmap header size
-  m_Ofstream.write(&tmp,sizeof(char));
-  tmp =0; 
-  m_Ofstream.write(&tmp,sizeof(char));
-  m_Ofstream.write(&tmp,sizeof(char));
-  m_Ofstream.write(&tmp,sizeof(char));
+ 
+  //
+  // Write the DIB header
+  //
+  // Offset Length Description
+  // 
+  //  14      4    Size of the header (40 bytes)(Hex: 28)
+  //
+  //
+  //  Color Palette
+  //
+  //  If the bit_count is 1, 4 or 8, the structure must be followed by a colour
+  //  lookup table, with 4 bytes per entry, the first 3 of which identify the
+  //  blue, green and red intensities, respectively.
+  //
+  //  Finally the pixel data
+  //
+  const unsigned int bitmapHeaderSize = 40;
+  this->Write32BitsInteger( bitmapHeaderSize );
   
   // image width
-  tmp = m_Dimensions[0]%256;
-  m_Ofstream.write(&tmp,sizeof(char));
-  tmp = m_Dimensions[0]/256;
-  m_Ofstream.write(&tmp,sizeof(char));
-  tmp =0;
-  m_Ofstream.write(&tmp,sizeof(char));
-  m_Ofstream.write(&tmp,sizeof(char));
+  this->Write32BitsInteger( m_Dimensions[0] );
   
   // image height -ve means top to bottom
-  tmp = m_Dimensions[1]%256;
-  m_Ofstream.write(&tmp,sizeof(char));
-  tmp = m_Dimensions[1]/256;
-  m_Ofstream.write(&tmp,sizeof(char));
-  tmp =0;
-  m_Ofstream.write(&tmp,sizeof(char));
-  m_Ofstream.write(&tmp,sizeof(char));
+  this->Write32BitsInteger( m_Dimensions[1] );
   
   // Set `planes'=1 (mandatory)
-  tmp =1;
-  m_Ofstream.write(&tmp,sizeof(char));
-  tmp =0;
-  m_Ofstream.write(&tmp,sizeof(char));
+  const unsigned short numberOfColorPlanes = 1;
+  this->Write16BitsInteger( numberOfColorPlanes );
 
-  // Set bits per pel.  
-  if( bpp == 3 ) 
+  // Set bits per pixel.  
+  unsigned short numberOfBitsPerPixel = 0;
+  switch( bpp )
     {
-    tmp=24;
-    }
-  else if( bpp == 1)
-    {
-    tmp=8;
-    }
-  else
-    {
-    itkExceptionMacro(<< "Number of components not supported.") ;
-    }
-  m_Ofstream.write(&tmp,sizeof(char));
-  tmp =0;
-  for(row = 0; row < 25; row++)
-    {
-    m_Ofstream.write(&tmp,sizeof(char));
+    case 4:
+      numberOfBitsPerPixel = 32;
+      break;
+    case 3:
+      numberOfBitsPerPixel = 24;
+      break;
+    case 1:
+      numberOfBitsPerPixel = 8;
+      break;
+    default:
+      itkExceptionMacro(<< "Number of components not supported.");
     }
+  this->Write16BitsInteger( numberOfBitsPerPixel );
 
-  // spit out colour LUT
+  const unsigned int compressionMethod = 0;
+  this->Write32BitsInteger( compressionMethod );
+  this->Write32BitsInteger( rawImageDataSize );
+
+  // Assuming spacing is in millimeters, 
+  // the resolution is set here in pixel per meter.
+  // The specification calls for a signed integer, but
+  // here we force it to be an unsigned integer to avoid
+  // dealing with directions in a subterraneous way.
+  const unsigned int horizontalResolution = 
+    static_cast<unsigned int>( vnl_math_rnd( 1000.0 / m_Spacing[0] ) );
+  const unsigned int verticalResolution =
+    static_cast<unsigned int>( vnl_math_rnd( 1000.0 / m_Spacing[1] ) );
+
+  this->Write32BitsInteger( horizontalResolution );
+  this->Write32BitsInteger( verticalResolution );
+
+  // zero here defaults to 2^n colors in the palette
+  const unsigned int numberOfColorsInPalette = 0;
+  this->Write32BitsInteger( numberOfColorsInPalette );
+
+  // zero here indicates that all colors in the palette are important.
+  const unsigned int numberOfImportantColorsInPalette = 0; 
+  this->Write32BitsInteger( numberOfImportantColorsInPalette );
+  //  
+  // End of DIB header, 54 bytes written so far
+  //
+  
+
+  //
+  // Write down colour LUT
+  //
+  // only when using 1 byte per pixel
+  //
   if (bpp == 1)
     {
     for (unsigned int n=0; n < 256; n++)
       { 
-      char tmp2 = static_cast< char >( n );
+      char tmp2 = static_cast< unsigned char >( n );
       m_Ofstream.write(&tmp2,sizeof(char));
       m_Ofstream.write(&tmp2,sizeof(char));
       m_Ofstream.write(&tmp2,sizeof(char));
@@ -792,59 +884,65 @@ BMPImageIO
       }
     }
 
+
+  //
+  // Write down the raw binary pixel data
+  //
   unsigned int i;
   for (unsigned int h = 0; h < m_Dimensions[1]; h++)
     {  
-      const char paddingValue = 0;
-      const char * ptr = static_cast<const char*>(buffer);
-      ptr += (m_Dimensions[1]-(h+1))*m_Dimensions[0]*bpp;
-      if (bpp == 1)
+    const char paddingValue = 0;
+    const char * ptr = static_cast<const char*>(buffer);
+    ptr += (m_Dimensions[1]-(h+1))*m_Dimensions[0]*bpp;
+    if (bpp == 1)
+      {
+      for (i = 0; i < m_Dimensions[0]; i++)
         {
-        for (i = 0; i < m_Dimensions[0]; i++)
-          {
-          m_Ofstream.write(ptr,sizeof(char));
-          ptr++;
-          }
-        for (i = 0; i < paddedBytes; i++)
-          {
-          m_Ofstream.write(&paddingValue,sizeof(char));
-          }
+        m_Ofstream.write(ptr,sizeof(char));
+        ptr++;
         }
-      if (bpp == 3)
+      for (i = 0; i < paddedBytes; i++)
         {
-        for (i = 0; i < m_Dimensions[0]; i++)
-          {
-           ptr+=2;
-           m_Ofstream.write(ptr,sizeof(char));
-           ptr--;
-           m_Ofstream.write(ptr,sizeof(char));
-           ptr--;
-           m_Ofstream.write(ptr,sizeof(char));
-           ptr+=3;
-          }
-        for (i = 0; i < paddedBytes; i++)
-          {
-          m_Ofstream.write(&paddingValue,sizeof(char));
-          }
-        }
-      if (bpp == 4)
-        {
-        for (i = 0; i < m_Dimensions[0]; i++)
-          {
-           ptr+=2;
-           m_Ofstream.write(ptr,sizeof(char));
-           ptr--;
-           m_Ofstream.write(ptr,sizeof(char));
-           ptr--;
-           m_Ofstream.write(ptr,sizeof(char));
-           ptr+=4;
-          }
-        for (i = 0; i < paddedBytes; i++)
-          {
-          m_Ofstream.write(&paddingValue,sizeof(char));
-          }
+        m_Ofstream.write(&paddingValue,sizeof(char));
         }
       }
+    if (bpp == 3)
+      {
+      for (i = 0; i < m_Dimensions[0]; i++)
+        {
+        ptr += 2;
+        m_Ofstream.write(ptr,sizeof(char));
+        ptr--;
+        m_Ofstream.write(ptr,sizeof(char));
+        ptr--;
+        m_Ofstream.write(ptr,sizeof(char));
+        ptr += 3;
+        }
+      for (i = 0; i < paddedBytes; i++)
+        {
+        m_Ofstream.write(&paddingValue,sizeof(char));
+        }
+      }
+    if (bpp == 4)
+      {
+      for (i = 0; i < m_Dimensions[0]; i++)
+        {
+        ptr += 3;
+        m_Ofstream.write(ptr,sizeof(char));
+        ptr--;
+        m_Ofstream.write(ptr,sizeof(char));
+        ptr--;
+        m_Ofstream.write(ptr,sizeof(char));
+        ptr--;
+        m_Ofstream.write(ptr,sizeof(char));
+        ptr += 4;
+        }
+      for (i = 0; i < paddedBytes; i++)
+        {
+        m_Ofstream.write(&paddingValue,sizeof(char));
+        }
+      }
+    }
 }
 
 /** Print Self Method */
@@ -866,6 +964,4 @@ void BMPImageIO::PrintSelf(std::ostream& os, Indent indent) const
   os << indent << "DataSize = " << m_BMPDataSize << "\n";
 }
 
-
-
 } // end namespace itk
