@@ -1,17 +1,17 @@
 /*=========================================================================
 
-Program:   Insight Segmentation & Registration Toolkit
-Module:    $RCSfile: itkGEAdwImageIO.h,v $
-Language:  C++
-Date:      $Date: 2005/09/28 15:41:54 $
-Version:   $Revision: 1.7 $
+  Program:   Insight Segmentation & Registration Toolkit
+  Module:    $RCSfile: itkGEAdwImageIO.h,v $
+  Language:  C++
+  Date:      $Date: 2007-12-03 13:13:09 $
+  Version:   $Revision: 1.10 $
 
-Copyright (c) Insight Software Consortium. All rights reserved.
-See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
+  Copyright (c) Insight Software Consortium. All rights reserved.
+  See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-This software is distributed WITHOUT ANY WARRANTY; without even
-the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-PURPOSE.  See the above copyright notices for more information.
+     This software is distributed WITHOUT ANY WARRANTY; without even 
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
 
@@ -35,27 +35,23 @@ PURPOSE.  See the above copyright notices for more information.
 #pragma warning ( disable : 4786 )
 #endif
 
-#include <fstream>
-#include "itkImageIOBase.h"
 #include "itkIPLCommonImageIO.h"
-#include "itkGEImageHeader.h"
-//#include "idbm_hdr_def.h"
 
 namespace itk
 {
- /** \class GEAdwImageIO
-  *
-  * \author Hans J. Johnson
-  * \brief Class that defines how to read GEAdw file format.
-  *
-  * \ingroup IOFilters
-  */
+/** \class GEAdwImageIO
+ *
+ * \author Hans J. Johnson
+ * \brief Class that defines how to read GEAdw file format.
+ *
+ * \ingroup IOFilters
+ */
 class ITK_EXPORT GEAdwImageIO : public IPLCommonImageIO
 {
 public:
   /** Standard class typedefs. */
-  typedef GEAdwImageIO            Self;
-  typedef IPLCommonImageIO  Superclass;
+  typedef GEAdwImageIO        Self;
+  typedef IPLCommonImageIO    Superclass;
   typedef SmartPointer<Self>  Pointer;
 
   /** Method for creation through the object factory. */
@@ -72,7 +68,7 @@ public:
        * \post Sets classes ImageIOBase::m_FileName variable to be FileNameToWrite
        * \return Returns true if this ImageIO can read the file specified.
        */
-  virtual bool CanReadFile(const char* FileNameToRead) ;
+  virtual bool CanReadFile(const char* FileNameToRead);
 
   /** Set the spacing and dimension information for the set filename. */
   // Implemented in superclass
@@ -116,7 +112,7 @@ protected:
   ~GEAdwImageIO();
   // Implemented in superclass
   //      void PrintSelf(std::ostream& os, Indent indent) const;
-  virtual struct GEImageHeader *ReadHeader(const char *FileNameToRead);
+  virtual GEImageHeader *ReadHeader(const char *FileNameToRead);
 private:
   GEAdwImageIO(const Self&); //purposely not implemented
   void operator=(const Self&); //purposely not implemented
