@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkGiplImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2006/09/28 13:11:06 $
-  Version:   $Revision: 1.20 $  
+  Date:      $Date: 2008-01-25 00:00:06 $
+  Version:   $Revision: 1.26 $  
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,13 +26,11 @@
 namespace itk
 {
 
-  class GiplImageIOInternals 
-    {
-    public:
-     gzFile          m_GzFile;
-    };
-
-
+class GiplImageIOInternals 
+{
+public:
+  gzFile          m_GzFile;
+};
 
 /*  IMAGE TYPE DEFINITIONS  */
 
@@ -132,7 +130,7 @@ bool GiplImageIO::CanReadFile( const char* filename )
   
     inputStream.seekg(252);
     unsigned int magic_number;
-    inputStream.read((char*)&magic_number,sizeof(unsigned int));
+    inputStream.read((char*)&magic_number,static_cast<std::streamsize>( sizeof(unsigned int) ));
   
     if(m_ByteOrder == BigEndian)
       {
@@ -161,7 +159,7 @@ bool GiplImageIO::CanReadFile( const char* filename )
     
     ::gzseek( m_Internal->m_GzFile, 252, SEEK_SET );
     unsigned int magic_number;
-    ::gzread( m_Internal->m_GzFile, (char*)&magic_number,sizeof(unsigned int));    
+    ::gzread( m_Internal->m_GzFile, (char*)&magic_number,static_cast<unsigned int>( sizeof(unsigned int)));
 
     if(m_ByteOrder == BigEndian)
       {
@@ -176,7 +174,7 @@ bool GiplImageIO::CanReadFile( const char* filename )
       {
       gzclose( m_Internal->m_GzFile );
       m_Internal->m_GzFile = NULL;
-       return true;
+      return true;
       }
     gzclose( m_Internal->m_GzFile );
     m_Internal->m_GzFile = NULL;
@@ -224,11 +222,11 @@ void GiplImageIO::Read(void* buffer)
   char * p = static_cast<char *>(buffer);
   if (m_IsCompressed)
     {
-    ::gzread( m_Internal->m_GzFile, p,this->GetImageSizeInBytes() );   
+    ::gzread( m_Internal->m_GzFile, p, static_cast< unsigned int >( this->GetImageSizeInBytes() ) );
     }
   else
     {
-    m_Ifstream.read( p, this->GetImageSizeInBytes() );
+    m_Ifstream.read( p, static_cast< std::streamsize >( this->GetImageSizeInBytes() ) );
     }
 
   bool success;
@@ -278,11 +276,11 @@ void GiplImageIO::ReadImageInformation()
   if (m_IsCompressed)
     {
     m_Internal->m_GzFile = ::gzopen( m_FileName.c_str(), "rb" );
-     if( m_Internal->m_GzFile == NULL )
-       {
-        ExceptionObject exception(__FILE__, __LINE__);
-        exception.SetDescription("File cannot be read");
-        throw exception;
+    if( m_Internal->m_GzFile == NULL )
+      {
+      ExceptionObject exception(__FILE__, __LINE__);
+      exception.SetDescription("File cannot be read");
+      throw exception;
       }
     }
   else
@@ -308,7 +306,7 @@ void GiplImageIO::ReadImageInformation()
     {
     if (m_IsCompressed)
       {
-        ::gzread( m_Internal->m_GzFile,(char*)&dims[i],sizeof(unsigned short));   
+        ::gzread( m_Internal->m_GzFile,(char*)&dims[i],static_cast<unsigned int>( sizeof(unsigned short) ) );
       }
     else
       {
@@ -385,7 +383,7 @@ void GiplImageIO::ReadImageInformation()
       }
     else
       {
-     m_Ifstream.read((char*)&pixdim[i],sizeof(float));
+      m_Ifstream.read((char*)&pixdim[i],sizeof(float));
       }
     if(m_ByteOrder == BigEndian)
       {
@@ -399,7 +397,7 @@ void GiplImageIO::ReadImageInformation()
     if(i<numberofdimension)
       {
       m_Spacing[i]=pixdim[i];
-      }    
+      }
     }
       
   char    line1[80];         /*   26   80  Patient / Text field        */
@@ -407,7 +405,7 @@ void GiplImageIO::ReadImageInformation()
     {
      if (m_IsCompressed)
       {
-        ::gzread( m_Internal->m_GzFile,(char*)&line1[i],sizeof(char));   
+        ::gzread( m_Internal->m_GzFile,(char*)&line1[i],static_cast<unsigned int>( sizeof(char) ) );   
       }
       else
       {
@@ -421,7 +419,7 @@ void GiplImageIO::ReadImageInformation()
     {
      if (m_IsCompressed)
       {
-        ::gzread( m_Internal->m_GzFile,(char*)&matrix[i],sizeof(float));   
+        ::gzread( m_Internal->m_GzFile,(char*)&matrix[i],static_cast<unsigned int>( sizeof(float) ) );   
       }
       else
       {
@@ -440,14 +438,14 @@ void GiplImageIO::ReadImageInformation()
 
   char    flag1;             /*  186    1  Orientation flag (below)    */
   if (m_IsCompressed)
-      {
-      ::gzread( m_Internal->m_GzFile,(char*)&flag1,sizeof(char));   
-      }
-    else
-      {
-      m_Ifstream.read((char*)&flag1,sizeof(char));
-      }
-
+    {
+    ::gzread( m_Internal->m_GzFile,(char*)&flag1,static_cast<unsigned int>( sizeof(char) ) );   
+    }
+  else
+    {
+    m_Ifstream.read((char*)&flag1,sizeof(char));
+    }
+  
   if(m_ByteOrder == BigEndian)
     {
     ByteSwapper<char>::SwapFromSystemToBigEndian(&flag1);
@@ -460,13 +458,12 @@ void GiplImageIO::ReadImageInformation()
   char    flag2;             /*  187    1                              */
   if (m_IsCompressed)
     {
-    ::gzread( m_Internal->m_GzFile,(char*)&flag2,sizeof(char));   
+    ::gzread( m_Internal->m_GzFile,(char*)&flag2,static_cast<unsigned int>( sizeof(char) ) );   
     }
   else
     {
     m_Ifstream.read((char*)&flag2,sizeof(char));
     }
-
   
   if(m_ByteOrder == BigEndian)
     {
@@ -480,7 +477,7 @@ void GiplImageIO::ReadImageInformation()
   double  min;               /*  188    8  Minimum voxel value         */   
   if (m_IsCompressed)
     {
-    ::gzread( m_Internal->m_GzFile,(char*)&min,sizeof(double));   
+    ::gzread( m_Internal->m_GzFile,(char*)&min,static_cast<unsigned int>( sizeof(double) ) );   
     }
   else
     {
@@ -490,7 +487,7 @@ void GiplImageIO::ReadImageInformation()
   double  max;               /*  196    8  Maximum voxel value         */
   if (m_IsCompressed)
     {
-    ::gzread( m_Internal->m_GzFile,(char*)&max,sizeof(double));   
+    ::gzread( m_Internal->m_GzFile,(char*)&max,static_cast<unsigned int>( sizeof(double) ) );   
     }
   else
     {
@@ -502,32 +499,32 @@ void GiplImageIO::ReadImageInformation()
     {
     if (m_IsCompressed)
       {
-        ::gzread( m_Internal->m_GzFile,(char*)&origin[i],sizeof(double));   
+      ::gzread( m_Internal->m_GzFile,(char*)&origin[i],static_cast<unsigned int>( sizeof(double) ) );   
       }
     else
       {
-        m_Ifstream.read((char*)&origin[i],sizeof(double));
+      m_Ifstream.read((char*)&origin[i],sizeof(double));
       }
     
     if(m_ByteOrder == BigEndian)
       {
-       ByteSwapper<double>::SwapFromSystemToBigEndian(&origin[i]);
+      ByteSwapper<double>::SwapFromSystemToBigEndian(&origin[i]);
       }
     else if (m_ByteOrder == LittleEndian)
       {
-       ByteSwapper<double>::SwapFromSystemToLittleEndian(&origin[i]);
+      ByteSwapper<double>::SwapFromSystemToLittleEndian(&origin[i]);
       }
       
     if(i<numberofdimension)
       {
-       m_Origin[i]=origin[i];
-      }    
+      m_Origin[i]=origin[i];
+      }
     }
 
   float   pixval_offset;     /*  236    4                              */
   if (m_IsCompressed)
     {
-    ::gzread( m_Internal->m_GzFile,(char*)&pixval_offset,sizeof(float));   
+    ::gzread( m_Internal->m_GzFile,(char*)&pixval_offset,static_cast<unsigned int>( sizeof(float) ) );   
     }
   else
     {
@@ -546,7 +543,7 @@ void GiplImageIO::ReadImageInformation()
   float   pixval_cal;        /*  240    4                              */
   if (m_IsCompressed)
     {
-    ::gzread( m_Internal->m_GzFile,(char*)&pixval_cal,sizeof(float));   
+    ::gzread( m_Internal->m_GzFile,(char*)&pixval_cal,static_cast<unsigned int>( sizeof(float) ) );   
     }
   else
     {
@@ -565,7 +562,7 @@ void GiplImageIO::ReadImageInformation()
   float   user_def1;         /*  244    4  Inter-slice Gap             */
   if (m_IsCompressed)
     {
-    ::gzread( m_Internal->m_GzFile,(char*)&user_def1,sizeof(float));   
+    ::gzread( m_Internal->m_GzFile,(char*)&user_def1,static_cast<unsigned int>( sizeof(float) ) );   
     }
   else
     {
@@ -585,7 +582,7 @@ void GiplImageIO::ReadImageInformation()
   float   user_def2;         /*  248    4  User defined field          */
   if (m_IsCompressed)
     {
-    ::gzread( m_Internal->m_GzFile,(char*)&user_def2,sizeof(float));   
+    ::gzread( m_Internal->m_GzFile,(char*)&user_def2,static_cast<unsigned int>( sizeof(float) ) );   
     }
   else
     {
@@ -604,7 +601,7 @@ void GiplImageIO::ReadImageInformation()
   unsigned int magic_number; /*  252    4 Magic Number                 */
   if (m_IsCompressed)
     {
-    ::gzread( m_Internal->m_GzFile,(char*)&magic_number,sizeof(unsigned int));   
+    ::gzread( m_Internal->m_GzFile,(char*)&magic_number, static_cast< unsigned int >( sizeof(unsigned int) ));   
     }
   else
     {
@@ -629,61 +626,89 @@ GiplImageIO
   switch(m_ComponentType)
     {
     case CHAR:
-    {
-    if ( m_ByteOrder == LittleEndian )
       {
-      ByteSwapper<char>::SwapRangeFromSystemToLittleEndian(
-        (char*)buffer, numberOfPixels );
+      if ( m_ByteOrder == LittleEndian )
+        {
+        ByteSwapper<char>::SwapRangeFromSystemToLittleEndian(
+          (char*)buffer, numberOfPixels );
+        }
+      else if ( m_ByteOrder == BigEndian )
+        {
+        ByteSwapper<char>::SwapRangeFromSystemToBigEndian(
+          (char *)buffer, numberOfPixels );
+        }
+      break;
       }
-    else if ( m_ByteOrder == BigEndian )
-      {
-      ByteSwapper<char>::SwapRangeFromSystemToBigEndian(
-        (char *)buffer, numberOfPixels );
-      }
-    break;
-    }
     case UCHAR:
-    {
-    if ( m_ByteOrder == LittleEndian )
       {
-      ByteSwapper<unsigned char>::SwapRangeFromSystemToLittleEndian(
-        (unsigned char*)buffer, numberOfPixels );
+      if ( m_ByteOrder == LittleEndian )
+        {
+        ByteSwapper<unsigned char>::SwapRangeFromSystemToLittleEndian(
+          (unsigned char*)buffer, numberOfPixels );
+        }
+      else if ( m_ByteOrder == BigEndian )
+        {
+        ByteSwapper<unsigned char>::SwapRangeFromSystemToBigEndian(
+          (unsigned char *)buffer, numberOfPixels );
+        }
+      break;
       }
-    else if ( m_ByteOrder == BigEndian )
-      {
-      ByteSwapper<unsigned char>::SwapRangeFromSystemToBigEndian(
-        (unsigned char *)buffer, numberOfPixels );
-      }
-    break;
-    }
     case SHORT:
-    {
-    if ( m_ByteOrder == LittleEndian )
       {
-      ByteSwapper<short>::SwapRangeFromSystemToLittleEndian(
-        (short*)buffer, numberOfPixels );
+      if ( m_ByteOrder == LittleEndian )
+        {
+        ByteSwapper<short>::SwapRangeFromSystemToLittleEndian(
+          (short*)buffer, numberOfPixels );
+        }
+      else if ( m_ByteOrder == BigEndian )
+        {
+        ByteSwapper<short>::SwapRangeFromSystemToBigEndian(
+          (short *)buffer, numberOfPixels );
+        }
+      break;
       }
-    else if ( m_ByteOrder == BigEndian )
-      {
-      ByteSwapper<short>::SwapRangeFromSystemToBigEndian(
-        (short *)buffer, numberOfPixels );
-      }
-    break;
-    }
     case USHORT:
-    {
-    if ( m_ByteOrder == LittleEndian )
       {
-      ByteSwapper<unsigned short>::SwapRangeFromSystemToLittleEndian(
-        (unsigned short*)buffer, numberOfPixels );
+      if ( m_ByteOrder == LittleEndian )
+        {
+        ByteSwapper<unsigned short>::SwapRangeFromSystemToLittleEndian(
+          (unsigned short*)buffer, numberOfPixels );
+        }
+      else if ( m_ByteOrder == BigEndian )
+        {
+        ByteSwapper<unsigned short>::SwapRangeFromSystemToBigEndian(
+          (unsigned short *)buffer, numberOfPixels );
+        }
+      break; 
       }
-    else if ( m_ByteOrder == BigEndian )
+    case FLOAT:
       {
-      ByteSwapper<unsigned short>::SwapRangeFromSystemToBigEndian(
-        (unsigned short *)buffer, numberOfPixels );
+      if ( m_ByteOrder == LittleEndian )
+        {
+        ByteSwapper<float>::SwapRangeFromSystemToLittleEndian(
+          (float*)buffer, numberOfPixels );
+        }
+      else if ( m_ByteOrder == BigEndian )
+        {
+        ByteSwapper<float>::SwapRangeFromSystemToBigEndian(
+          (float *)buffer, numberOfPixels );
+        }
+      break; 
+      }
+    case DOUBLE:
+      {
+      if ( m_ByteOrder == LittleEndian )
+        {
+        ByteSwapper<double>::SwapRangeFromSystemToLittleEndian(
+          (double*)buffer, numberOfPixels );
+        }
+      else if ( m_ByteOrder == BigEndian )
+        {
+        ByteSwapper<double>::SwapRangeFromSystemToBigEndian(
+          (double *)buffer, numberOfPixels );
+        }
+      break; 
       }
-    break; 
-    }
     default:
       ExceptionObject exception(__FILE__, __LINE__);
       exception.SetDescription("Pixel Type Unknown");
@@ -691,7 +716,6 @@ GiplImageIO
     }
 }
 
-
 void 
 GiplImageIO
 ::WriteImageInformation(void)
@@ -699,8 +723,6 @@ GiplImageIO
   //not possible to write a Gipl file  
 }
 
-
-
 /** The write function is not implemented */
 void 
 GiplImageIO
@@ -713,17 +735,17 @@ GiplImageIO
 #ifdef __sgi
   // Create the file. This is required on some older sgi's
   std::ofstream tFile(m_FileName.c_str(),std::ios::out);
-  tFile.close();                    
+  tFile.close();
 #endif
 
   if (m_IsCompressed)
     {
     m_Internal->m_GzFile = ::gzopen( m_FileName.c_str(), "wb" );
     if( m_Internal->m_GzFile == NULL )
-       {
-       ExceptionObject exception(__FILE__, __LINE__);
-       exception.SetDescription("File cannot be write");
-       throw exception;
+      {
+      ExceptionObject exception(__FILE__, __LINE__);
+      exception.SetDescription("File cannot be write");
+      throw exception;
       }
     }
   else
@@ -736,7 +758,6 @@ GiplImageIO
       throw exception;
       }
     }
- 
 
   unsigned int i;
   for(i=0;i<4;i++)
@@ -756,7 +777,7 @@ GiplImageIO
  
       if (m_IsCompressed)
         {
-       ::gzwrite( m_Internal->m_GzFile,(char*)&(value),sizeof(unsigned short));
+       ::gzwrite( m_Internal->m_GzFile,(char*)&(value),static_cast<unsigned int>( sizeof(unsigned short) ));
         }
       else
         {
@@ -765,7 +786,7 @@ GiplImageIO
       }
     else
       {
-      value = 0;
+      value = 1;
       if(m_ByteOrder == BigEndian)
         {
         ByteSwapper<unsigned short>::SwapFromSystemToBigEndian(&value);
@@ -774,18 +795,17 @@ GiplImageIO
         {
         ByteSwapper<unsigned short>::SwapFromSystemToLittleEndian(&value);
         }
-       if (m_IsCompressed)
+      if (m_IsCompressed)
         {
-        ::gzwrite( m_Internal->m_GzFile,(char*)&(value),sizeof(unsigned short));
+        ::gzwrite( m_Internal->m_GzFile,(char*)&(value),static_cast<unsigned int>( sizeof(unsigned short) ));
         }
       else
         {
-        m_Ofstream.write((char*)&value,sizeof(unsigned short));;
+        m_Ofstream.write((char*)&value,sizeof(unsigned short));
         }
       }
     }
 
-
   unsigned short   image_type;
   switch(m_ComponentType)
     {
@@ -812,7 +832,7 @@ GiplImageIO
  
   if (m_IsCompressed)
     {
-   ::gzwrite( m_Internal->m_GzFile,(char*)&image_type,sizeof(unsigned short));
+   ::gzwrite( m_Internal->m_GzFile,(char*)&image_type,static_cast<unsigned int>( sizeof(unsigned short) ));
     }
   else
     {
@@ -824,7 +844,7 @@ GiplImageIO
     {
     if(i<nDims)
       {
-      float value = m_Spacing[i];
+      float value = static_cast<float>( m_Spacing[i] );
       if(m_ByteOrder == BigEndian)
         {
         ByteSwapper<float>::SwapFromSystemToBigEndian((float *)&value);
@@ -835,7 +855,7 @@ GiplImageIO
         }
       if (m_IsCompressed)
         {
-        ::gzwrite( m_Internal->m_GzFile,(char*)&value,sizeof(float));
+        ::gzwrite( m_Internal->m_GzFile,(char*)&value,static_cast<unsigned int>( sizeof(float) ));
         }
       else
         {
@@ -844,7 +864,7 @@ GiplImageIO
       }
     else
       {
-      float value = 0;
+      float value = 1.0f;
       if(m_ByteOrder == BigEndian)
         {
         ByteSwapper<float>::SwapFromSystemToBigEndian((float*)&value);
@@ -855,7 +875,7 @@ GiplImageIO
         }
       if (m_IsCompressed)
         {
-        ::gzwrite( m_Internal->m_GzFile,(char*)&value,sizeof(float));
+        ::gzwrite( m_Internal->m_GzFile,(char*)&value,static_cast<unsigned int>( sizeof(float) ));
         }
       else
         {
@@ -876,7 +896,7 @@ GiplImageIO
     {
     if (m_IsCompressed)
       {
-      ::gzwrite( m_Internal->m_GzFile,(char*)&line1[i],sizeof(char));
+      ::gzwrite( m_Internal->m_GzFile,(char*)&line1[i],static_cast<unsigned int>( sizeof(char) ));
       }
     else
       {
@@ -890,7 +910,7 @@ GiplImageIO
     matrix[i]=0; //write zeros
     if (m_IsCompressed)
       {
-      ::gzwrite( m_Internal->m_GzFile,(char*)&matrix[i],sizeof(float));
+      ::gzwrite( m_Internal->m_GzFile,(char*)&matrix[i],static_cast<unsigned int>( sizeof(float) ));
       }
     else
       {
@@ -901,7 +921,7 @@ GiplImageIO
   char    flag1=0;             /*  186    1  Orientation flag (below)    */
   if (m_IsCompressed)
     {
-    ::gzwrite( m_Internal->m_GzFile,(char*)&flag1,sizeof(char));
+    ::gzwrite( m_Internal->m_GzFile,(char*)&flag1,static_cast<unsigned int>( sizeof(char) ));
     }
   else
     {
@@ -911,7 +931,7 @@ GiplImageIO
   char    flag2=0;             /*  187    1                              */
   if (m_IsCompressed)
     {
-   ::gzwrite( m_Internal->m_GzFile,(char*)&flag2,sizeof(char));
+   ::gzwrite( m_Internal->m_GzFile,(char*)&flag2,static_cast<unsigned int>( sizeof(char) ));
     }
   else
     {
@@ -921,7 +941,7 @@ GiplImageIO
   double  min=0;               /*  188    8  Minimum voxel value         */
   if (m_IsCompressed)
     {
-    ::gzwrite( m_Internal->m_GzFile,(char*)&min,sizeof(double));
+    ::gzwrite( m_Internal->m_GzFile,(char*)&min,static_cast<unsigned int>( sizeof(double) ));
     }
   else
     {
@@ -931,7 +951,7 @@ GiplImageIO
   double  max=0;               /*  196    8  Maximum voxel value         */
   if (m_IsCompressed)
     {
-    ::gzwrite( m_Internal->m_GzFile,(char*)&max,sizeof(double));
+    ::gzwrite( m_Internal->m_GzFile,(char*)&max,static_cast<unsigned int>( sizeof(double) ));
     }
   else
     {
@@ -964,7 +984,7 @@ GiplImageIO
     
     if (m_IsCompressed)
       {
-      ::gzwrite( m_Internal->m_GzFile,(char*)&origin[i],sizeof(double));
+      ::gzwrite( m_Internal->m_GzFile,(char*)&origin[i],static_cast<unsigned int>( sizeof(double) ));
       }
     else
       {
@@ -975,7 +995,7 @@ GiplImageIO
   float   pixval_offset=0;     /*  236    4                            */
   if (m_IsCompressed)
     {
-    ::gzwrite( m_Internal->m_GzFile,(char*)&pixval_offset,sizeof(float));
+    ::gzwrite( m_Internal->m_GzFile,(char*)&pixval_offset,static_cast<unsigned int>( sizeof(float) ));
     }
   else
     {
@@ -985,7 +1005,7 @@ GiplImageIO
   float   pixval_cal=0;        /*  240    4                              */
   if (m_IsCompressed)
     {
-    ::gzwrite( m_Internal->m_GzFile,(char*)&pixval_cal,sizeof(float));
+    ::gzwrite( m_Internal->m_GzFile,(char*)&pixval_cal,static_cast<unsigned int>( sizeof(float) ));
     }
   else
     {
@@ -995,7 +1015,7 @@ GiplImageIO
   float   user_def1=0;         /*  244    4  Inter-slice Gap             */
   if (m_IsCompressed)
     {
-    ::gzwrite( m_Internal->m_GzFile,(char*)&user_def1,sizeof(float));
+    ::gzwrite( m_Internal->m_GzFile,(char*)&user_def1,static_cast<unsigned int>( sizeof(float) ));
     }
   else
     {
@@ -1005,7 +1025,7 @@ GiplImageIO
   float   user_def2=0;         /*  248    4  User defined field          */
   if (m_IsCompressed)
     {
-    ::gzwrite( m_Internal->m_GzFile,(char*)&user_def2,sizeof(float));
+    ::gzwrite( m_Internal->m_GzFile,(char*)&user_def2,static_cast<unsigned int>( sizeof(float) ));
     }
   else
     {
@@ -1024,7 +1044,7 @@ GiplImageIO
 
   if (m_IsCompressed)
     {
-    ::gzwrite( m_Internal->m_GzFile,(char*)&magic_number,sizeof(unsigned int));
+    ::gzwrite( m_Internal->m_GzFile,(char*)&magic_number,static_cast<unsigned int>( sizeof(unsigned int) ));
     }
   else
     {
@@ -1042,8 +1062,8 @@ GiplImageIO
     }
   else //binary
     {
-    const unsigned long numberOfBytes      = this->GetImageSizeInBytes();
-    const unsigned long numberOfComponents = this->GetImageSizeInComponents();
+    const unsigned long numberOfBytes      = static_cast<unsigned long>( this->GetImageSizeInBytes() );
+    const unsigned long numberOfComponents = static_cast<unsigned long>( this->GetImageSizeInComponents() );
 
     // Swap bytes if necessary
     if ( m_ByteOrder == LittleEndian )
@@ -1084,7 +1104,7 @@ GiplImageIO
         }
       else
         {
-         m_Ofstream.write(static_cast<const char*>(buffer), numberOfBytes );
+        m_Ofstream.write(static_cast<const char*>(buffer), numberOfBytes );
         }
       }
     }
@@ -1112,10 +1132,10 @@ bool GiplImageIO::CheckExtension(const char* filename)
 {
   std::string fname = filename;
   if ( fname == "" )
-  {
+    {
     itkDebugMacro(<< "No filename specified.");
     return false;
-  }
+    }
 
   bool extensionFound = false;
   m_IsCompressed = false;
@@ -1124,7 +1144,7 @@ bool GiplImageIO::CheckExtension(const char* filename)
   if ((giplPos != std::string::npos)
       && (giplPos == fname.length() - 5))
     {
-      extensionFound = true;
+    extensionFound = true;
     }
 
   giplPos = fname.rfind(".gipl.gz");
@@ -1138,6 +1158,4 @@ bool GiplImageIO::CheckExtension(const char* filename)
   return extensionFound;
 }
 
-
-
 } // end namespace itk
