@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageIOBase.cxx,v $
   Language:  C++
-  Date:      $Date: 2007/01/09 17:38:55 $
-  Version:   $Revision: 1.62 $
+  Date:      $Date: 2008-02-06 21:23:04 $
+  Version:   $Revision: 1.75 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -54,6 +54,8 @@ void ImageIOBase::Reset(const bool)
     }
   m_NumberOfDimensions = 0;
   m_UseCompression = false;
+  m_UseStreamedReading = false;
+  m_UseStreamedWriting = false;
 }
 
 ImageIOBase::~ImageIOBase()
@@ -76,35 +78,35 @@ void ImageIOBase::Resize(const unsigned int numDimensions,
 
 void ImageIOBase::SetDimensions(unsigned int i, unsigned int dim)
 {
-  if ( i > m_Dimensions.size() ) {return;}
+  if ( i >= m_Dimensions.size() ) {return;}
   this->Modified();
   m_Dimensions[i] = dim;
 }
 
 void ImageIOBase::SetOrigin(unsigned int i, double origin)
 {
-  if ( i > m_Origin.size() ) {return;}
+  if ( i >= m_Origin.size() ) {return;}
   this->Modified();
   m_Origin[i] = origin;
 }
 
 void ImageIOBase::SetSpacing(unsigned int i, double spacing)
 {
-  if (i > m_Spacing.size() ) {return;}
+  if (i >= m_Spacing.size() ) {return;}
   this->Modified();
   m_Spacing[i] = spacing;
 }
 
 void ImageIOBase::SetDirection(unsigned int i, std::vector<double> &direction)
 {
-  if (i > m_Direction.size() ) {return;}
+  if (i >= m_Direction.size() ) {return;}
   this->Modified();
   m_Direction[i] = direction;
 }
 
 void ImageIOBase::SetDirection(unsigned int i, vnl_vector<double> &direction)
 {
-  if (i > m_Direction.size() ) {return;}
+  if (i >= m_Direction.size() ) {return;}
   this->Modified();
   std::vector<double> v;
   v.resize(m_Direction.size());
@@ -153,9 +155,9 @@ const std::type_info& ImageIOBase::GetComponentTypeInfo() const
 template <typename T>
 bool
 itkSetPixelType(ImageIOBase *This,
-              const std::type_info &ptype,
-              ImageIOBase::IOComponentType ntype, 
-              T itkNotUsed( dummy ) )
+                const std::type_info &ptype,
+                ImageIOBase::IOComponentType ntype, 
+                T itkNotUsed( dummy ) )
 {
   if( ptype == typeid(T) )
     {
@@ -269,6 +271,20 @@ itkSetPixelType(ImageIOBase *This,
     This->SetComponentType(ntype);
     return true;
     }
+  else if ( ptype == typeid(FixedArray<T,3>) )
+    {
+    This->SetNumberOfComponents(3);
+    This->SetPixelType(ImageIOBase::FIXEDARRAY);
+    This->SetComponentType(ntype);
+    return true;
+    }
+  else if ( ptype == typeid(FixedArray<T,4>) )
+    {
+    This->SetNumberOfComponents(4);
+    This->SetPixelType(ImageIOBase::FIXEDARRAY);
+    This->SetComponentType(ntype);
+    return true;
+    }
   else if ( ptype == typeid(SymmetricSecondRankTensor<T,3>) )
     {
     This->SetNumberOfComponents(6);
@@ -304,6 +320,27 @@ itkSetPixelType(ImageIOBase *This,
     This->SetPixelType(ImageIOBase::DIFFUSIONTENSOR3D);
     return true;
     }
+  else if ( ptype == typeid(Matrix<T,2,2>) )
+    {
+    This->SetNumberOfComponents(4);
+    This->SetComponentType(ntype);
+    This->SetPixelType(ImageIOBase::MATRIX);
+    return true;
+    }
+  else if ( ptype == typeid(Matrix<T,3,3>) )
+    {
+    This->SetNumberOfComponents(9);
+    This->SetComponentType(ntype);
+    This->SetPixelType(ImageIOBase::MATRIX);
+    return true;
+    }
+  else if ( ptype == typeid(Matrix<T,4,4>) )
+    {
+    This->SetNumberOfComponents(16);
+    This->SetComponentType(ntype);
+    This->SetPixelType(ImageIOBase::MATRIX);
+    return true;
+    }
   else if ( ptype == typeid(std::complex<T>) )
     {
     This->SetNumberOfComponents(2);
@@ -357,7 +394,7 @@ bool ImageIOBase::SetPixelTypeInfo(const std::type_info& ptype)
 
     }
 
-  if( this->GetPixelType()     == ImageIOBase::UNKNOWNPIXELTYPE )
+  if( this->GetPixelType() == ImageIOBase::UNKNOWNPIXELTYPE )
     {
     itkExceptionMacro("Pixel type currently not supported. typeid.name = " << ptype.name() );
     return false;
@@ -386,10 +423,12 @@ void ImageIOBase::ComputeStrides()
 }
 
 // Calculates the image size in PIXELS
-unsigned int ImageIOBase::GetImageSizeInPixels() const
+ImageIOBase::SizeType 
+ImageIOBase
+::GetImageSizeInPixels() const
 {
   unsigned int i;
-  unsigned int numPixels = 1;
+  SizeType numPixels = 1;
 
   for (i = 0; i < m_NumberOfDimensions; i++)
     {
@@ -399,32 +438,44 @@ unsigned int ImageIOBase::GetImageSizeInPixels() const
   return numPixels;
 }
 
-unsigned int ImageIOBase::GetImageSizeInComponents() const
+ImageIOBase::SizeType 
+ImageIOBase
+::GetImageSizeInComponents() const
 {
   return (this->GetImageSizeInPixels() * m_NumberOfComponents);
 }
 
-unsigned int ImageIOBase::GetImageSizeInBytes () const
+ImageIOBase::SizeType 
+ImageIOBase
+::GetImageSizeInBytes () const
 {
   return (this->GetImageSizeInComponents() * this->GetComponentSize());
 }
 
-unsigned int ImageIOBase::GetComponentStride() const
+ImageIOBase::SizeType 
+ImageIOBase
+::GetComponentStride() const
 {
   return m_Strides[0];
 }
 
-unsigned int ImageIOBase::GetPixelStride () const
+ImageIOBase::SizeType 
+ImageIOBase
+::GetPixelStride () const
 {
   return m_Strides[1];
 }
 
-unsigned int ImageIOBase::GetRowStride () const
+ImageIOBase::SizeType 
+ImageIOBase
+::GetRowStride () const
 {
   return m_Strides[2];
 }
 
-unsigned int ImageIOBase::GetSliceStride () const
+ImageIOBase::SizeType 
+ImageIOBase
+::GetSliceStride () const
 {
   return m_Strides[3];
 }
@@ -460,27 +511,26 @@ void ImageIOBase::SetNumberOfDimensions(unsigned int dim)
     }
 }
 
-
-
 bool 
-ImageIOBase ::ReadBufferAsBinary(std::istream& is, void *buffer, unsigned int num)
+ImageIOBase
+::ReadBufferAsBinary(std::istream& is, void *buffer, ImageIOBase::SizeType num)
 {
 
-  const unsigned int numberOfBytesToBeRead = num;
+  const SizeType numberOfBytesToBeRead = num;
 
   is.read( static_cast<char *>( buffer ), numberOfBytesToBeRead );
 
-  const unsigned int numberOfBytesRead = is.gcount();
+  const SizeType numberOfBytesRead = is.gcount();
 
 #ifdef __APPLE_CC__
   // fail() is broken in the Mac. It returns true when reaches eof().
   if ( numberOfBytesRead != numberOfBytesToBeRead )
 #else
-    if ( ( numberOfBytesRead != numberOfBytesToBeRead )  || is.fail() )
+  if ( ( numberOfBytesRead != numberOfBytesToBeRead )  || is.fail() )
 #endif
-      {
-      return false; // read failed
-      }
+    {
+    return false; // read failed
+    }
 
   return true;
 
@@ -633,10 +683,10 @@ std::string ImageIOBase::GetPixelTypeAsString(IOPixelType t) const
 
 namespace {
 template <class TComponent>
-void WriteBuffer(std::ostream& os, const TComponent *buffer, unsigned int num)
+void WriteBuffer(std::ostream& os, const TComponent *buffer, ImageIOBase::SizeType num)
 {
   const TComponent *ptr = buffer;
-  for (unsigned int i=0; i < num; i++)
+  for (ImageIOBase::SizeType i=0; i < num; i++)
     {
     if ( !(i%6) && i ) os << "\n";
     os << *ptr++ << " ";
@@ -645,101 +695,101 @@ void WriteBuffer(std::ostream& os, const TComponent *buffer, unsigned int num)
 }
 void ImageIOBase::WriteBufferAsASCII(std::ostream& os, const void *buffer, 
                                      IOComponentType ctype,
-                                     unsigned int numComp)
+                                     ImageIOBase::SizeType numComp)
 {
   switch (ctype)
     {
     case UCHAR:
-    {
-    typedef const unsigned char * Type;
-    Type buf = reinterpret_cast<Type>(buffer);
-    WriteBuffer(os, buf, numComp);
-    }
-    break;
+      {
+      typedef const unsigned char * Type;
+      Type buf = reinterpret_cast<Type>(buffer);
+      WriteBuffer(os, buf, numComp);
+      }
+      break;
     case CHAR:
-    {
-    typedef const char * Type;
-    Type buf = reinterpret_cast<Type>(buffer);
-    WriteBuffer(os, buf, numComp);
-    }
-    break;
+      {
+      typedef const char * Type;
+      Type buf = reinterpret_cast<Type>(buffer);
+      WriteBuffer(os, buf, numComp);
+      }
+      break;
 
     case USHORT:
-    {
-    typedef const unsigned short * Type;
-    Type buf = reinterpret_cast<Type>(buffer);
-    WriteBuffer(os, buf, numComp);
-    }
-    break;
-
+      {
+      typedef const unsigned short * Type;
+      Type buf = reinterpret_cast<Type>(buffer);
+      WriteBuffer(os, buf, numComp);
+      }
+      break;
+      
     case SHORT:
-    {
-    typedef const short * Type;
-    Type buf = reinterpret_cast<Type>(buffer);
-    WriteBuffer(os, buf, numComp);
-    }
-    break;
+      {
+      typedef const short * Type;
+      Type buf = reinterpret_cast<Type>(buffer);
+      WriteBuffer(os, buf, numComp);
+      }
+      break;
 
     case UINT:
-    {
-    typedef const unsigned int * Type;
-    Type buf = reinterpret_cast<Type>(buffer);
-    WriteBuffer(os, buf, numComp);
-    }
-    break;
+      {
+      typedef const unsigned int * Type;
+      Type buf = reinterpret_cast<Type>(buffer);
+      WriteBuffer(os, buf, numComp);
+      }
+      break;
 
     case INT:
-    {
-    typedef const int * Type;
-    Type buf = reinterpret_cast<Type>(buffer);
-    WriteBuffer(os, buf, numComp);
-    }
-    break;
+      {
+      typedef const int * Type;
+      Type buf = reinterpret_cast<Type>(buffer);
+      WriteBuffer(os, buf, numComp);
+      }
+      break;
 
     case ULONG:
-    {
-    typedef const unsigned long * Type;
-    Type buf = reinterpret_cast<Type>(buffer);
-    WriteBuffer(os, buf, numComp);
-    }
-    break;
+      {
+      typedef const unsigned long * Type;
+      Type buf = reinterpret_cast<Type>(buffer);
+      WriteBuffer(os, buf, numComp);
+      }
+      break;
 
     case LONG:
-    {
-    typedef const long * Type;
-    Type buf = reinterpret_cast<Type>(buffer);
-    WriteBuffer(os, buf, numComp);
-    }
-    break;
+      {
+      typedef const long * Type;
+      Type buf = reinterpret_cast<Type>(buffer);
+      WriteBuffer(os, buf, numComp);
+      }
+      break;
 
     case FLOAT:
-    {
-    typedef const float * Type;
-    Type buf = reinterpret_cast<Type>(buffer);
-    WriteBuffer(os, buf, numComp);
-    }
-    break;
+      {
+      typedef const float * Type;
+      Type buf = reinterpret_cast<Type>(buffer);
+      WriteBuffer(os, buf, numComp);
+      }
+      break;
 
     case DOUBLE:
-    {
-    typedef const double * Type;
-    Type buf = reinterpret_cast<Type>(buffer);
-    WriteBuffer(os, buf, numComp);
-    }
-    break;
+      {
+      typedef const double * Type;
+      Type buf = reinterpret_cast<Type>(buffer);
+      WriteBuffer(os, buf, numComp);
+      }
+      break;
 
     default:
-      ;
+      break;
     }
 
 }
 
 
 template <class TComponent>
-void ReadBuffer(std::istream& is, TComponent *buffer, unsigned int num)
+void ReadBuffer(std::istream& is, TComponent *buffer, ImageIOBase::SizeType num)
 {
   TComponent *ptr = buffer;
-  for (unsigned int i=0; i < num; i++, ptr++)
+  for( ImageIOBase::SizeType i=0; i < num; i++, ptr++ )
     {
     is >> *ptr;
     }
@@ -747,85 +797,130 @@ void ReadBuffer(std::istream& is, TComponent *buffer, unsigned int num)
 
 void ImageIOBase::ReadBufferAsASCII(std::istream& is, void *buffer, 
                                     IOComponentType ctype,
-                                    unsigned int numComp)
+                                    ImageIOBase::SizeType numComp)
 {
   switch (ctype)
     {
     case UCHAR:
-    {
-    unsigned char *buf = reinterpret_cast<unsigned char*>(buffer);
-    ReadBuffer(is, buf, numComp);
-    }
-    break;
+      {
+      unsigned char *buf = reinterpret_cast<unsigned char*>(buffer);
+      ReadBuffer(is, buf, numComp);
+      }
+      break;
     case CHAR:
-    {
-    char *buf = reinterpret_cast<char*>(buffer);
-    ReadBuffer(is, buf, numComp);
-    }
-    break;
+      {
+      char *buf = reinterpret_cast<char*>(buffer);
+      ReadBuffer(is, buf, numComp);
+      }
+      break;
 
     case USHORT:
-    {
-    unsigned short *buf = reinterpret_cast<unsigned short*>(buffer);
-    ReadBuffer(is, buf, numComp);
-    }
-    break;
+      {
+      unsigned short *buf = reinterpret_cast<unsigned short*>(buffer);
+      ReadBuffer(is, buf, numComp);
+      }
+      break;
 
     case SHORT:
-    {
-    short *buf = reinterpret_cast<short*>(buffer);
-    ReadBuffer(is, buf, numComp);
-    }
-    break;
-
+      {
+      short *buf = reinterpret_cast<short*>(buffer);
+      ReadBuffer(is, buf, numComp);
+      }
+      break;
+    
     case UINT:
-    {
-    unsigned int *buf = reinterpret_cast<unsigned int*>(buffer);
-    ReadBuffer(is, buf, numComp);
-    }
-    break;
+      {
+      unsigned int *buf = reinterpret_cast<unsigned int*>(buffer);
+      ReadBuffer(is, buf, numComp);
+      }
+      break;
 
     case INT:
-    {
-    int *buf = reinterpret_cast<int*>(buffer);
-    ReadBuffer(is, buf, numComp);
-    }
-    break;
+      {
+      int *buf = reinterpret_cast<int*>(buffer);
+      ReadBuffer(is, buf, numComp);
+      }
+      break;
 
     case ULONG:
-    {
-    unsigned long *buf = reinterpret_cast<unsigned long*>(buffer);
-    ReadBuffer(is, buf, numComp);
-    }
-    break;
+      {
+      unsigned long *buf = reinterpret_cast<unsigned long*>(buffer);
+      ReadBuffer(is, buf, numComp);
+      }
+      break;
 
     case LONG:
-    {
-    long *buf = reinterpret_cast<long*>(buffer);
-    ReadBuffer(is, buf, numComp);
-    }
-    break;
+      {
+      long *buf = reinterpret_cast<long*>(buffer);
+      ReadBuffer(is, buf, numComp);
+      }
+      break;
 
     case FLOAT:
-    {
-    float *buf = reinterpret_cast<float*>(buffer);
-    ReadBuffer(is, buf, numComp);
-    }
-    break;
-
+      {
+      float *buf = reinterpret_cast<float*>(buffer);
+      ReadBuffer(is, buf, numComp);
+      }
+      break;
+    
     case DOUBLE:
-    {
-    double *buf = reinterpret_cast<double*>(buffer);
-    ReadBuffer(is, buf, numComp);
-    }
-    break;
+      {
+      double *buf = reinterpret_cast<double*>(buffer);
+      ReadBuffer(is, buf, numComp);
+      }
+      break;
 
     default:
-      ;
+      break;
     }
 
 }
 
+
+/** Given a requested region, determine what could be the region that we can
+ * read from the file. This is called the streamable region, which will be
+ * smaller than the LargestPossibleRegion and greater or equal to the
+ * RequestedRegion */
+ImageIORegion 
+ImageIOBase
+::GenerateStreamableReadRegionFromRequestedRegion( 
+    const ImageIORegion & requested ) const
+{
+  //
+  // The default implementations determines that the streamable region is
+  // equal to the largest possible region of the image.
+  //
+  
+  // Since the image in the file may have a dimension lower
+  // than the image type over which the ImageFileReader/Writer is
+  // being instantiated, we must fill in the co-dimensions in a
+  // consistent way.
+
+  // First: allocate with the image IO number of dimensions
+  ImageIORegion streamableRegion( requested.GetImageDimension() );
+
+  // Second: copy only the number of dimension that the image has.
+  unsigned int maxDimensionToCopy =
+    this->m_NumberOfDimensions > requested.GetImageDimension() ?
+    requested.GetImageDimension() : this->m_NumberOfDimensions;
+  for( unsigned int i=0; i < maxDimensionToCopy; i++ )
+    {
+    streamableRegion.SetSize( i, this->m_Dimensions[i] );
+    streamableRegion.SetIndex( i, 0 );
+    }
+
+  // Third: set the rest to the default : start = 0, size = 1
+  for( unsigned int j=maxDimensionToCopy; j<requested.GetImageDimension(); j++ )
+    {
+    streamableRegion.SetSize( j, 1 );
+    streamableRegion.SetIndex( j, 0 );
+    }
+
+  // Finally: return the streamable region
+  return streamableRegion;
+}
+
+
 void ImageIOBase::PrintSelf(std::ostream& os, Indent indent) const
 {
   Superclass::PrintSelf(os, indent);
@@ -854,7 +949,22 @@ void ImageIOBase::PrintSelf(std::ostream& os, Indent indent) const
     {
     os << indent << "UseCompression: Off" << std::endl;
     }
-
+  if (m_UseStreamedReading)
+    {
+    os << indent << "UseStreamedReading: On" << std::endl;
+    }
+  else
+    {
+    os << indent << "UseStreamedReading: Off" << std::endl;
+    }
+  if (m_UseStreamedWriting)
+    {
+    os << indent << "UseStreamedWriting: On" << std::endl;
+    }
+  else
+    {
+    os << indent << "UseStreamedWriting: Off" << std::endl;
+    }
 }
 
 } //namespace itk
