@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMetaImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2007/02/14 17:51:19 $
-  Version:   $Revision: 1.66 $
+  Date:      $Date: 2008-02-19 17:38:49 $
+  Version:   $Revision: 1.85 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -32,24 +32,26 @@ namespace itk
 MetaImageIO::MetaImageIO()
 {
   m_FileType = Binary;
+  m_SubSamplingFactor = 1;
   if(MET_SystemByteOrderMSB())
+    {
     m_ByteOrder = BigEndian;
+    }
   else
+    {
     m_ByteOrder = LittleEndian;
+    }
 } 
 
-
-
 MetaImageIO::~MetaImageIO()
 {
 }
 
-
-
 void MetaImageIO::PrintSelf(std::ostream& os, Indent indent) const
 {
   Superclass::PrintSelf(os, indent);
   m_MetaImage.PrintInfo();
+  os << indent << "SubSamplingFactor: " << m_SubSamplingFactor << "\n";
 }
 
 
@@ -58,13 +60,11 @@ void MetaImageIO::SetDataFileName( const char* filename )
   m_MetaImage.ElementDataFileName( filename );
 }
 
- 
 // This method will only test if the header looks like a
 // MetaImage.  Some code is redundant with ReadImageInformation
 // a StateMachine could provide a better implementation
 bool MetaImageIO::CanReadFile( const char* filename ) 
 { 
-
   // First check the extension
   std::string fname = filename;
   if(  fname == "" )
@@ -73,96 +73,7 @@ bool MetaImageIO::CanReadFile( const char* filename )
     return false;
     }
 
-  bool extensionFound = false;
-  std::string::size_type mhaPos = fname.rfind(".mha");
-  if ((mhaPos != std::string::npos)
-      && (mhaPos == fname.length() - 4))
-    {
-    extensionFound = true;
-    }
-
-  std::string::size_type mhdPos = fname.rfind(".mhd");
-  if ((mhdPos != std::string::npos)
-      && (mhdPos == fname.length() - 4))
-    {
-    extensionFound = true;
-    }
-  
-  if( !extensionFound )
-    {
-    itkDebugMacro(<<"The filename extension is not recognized");
-    return false;
-    }
-
-  // Now check the file content
-  std::ifstream inputStream;
-
-  inputStream.open( filename, std::ios::in | std::ios::binary );
-
-  if( inputStream.fail() )
-    {
-    return false;
-    }
-
-  char key[8000];
-
-  inputStream >> key;
-
-  if( inputStream.eof() )
-    {
-    inputStream.close();
-    return false;
-    }
-
-  if( strcmp(key,"NDims")==0 ) 
-    {
-    inputStream.close();
-    return true;
-    }
-  if( strcmp(key,"ObjectType")==0 ) 
-    {
-    inputStream.close();
-    return true;
-    }
-  if( strcmp(key,"TransformType")==0 ) 
-    {
-    inputStream.close();
-    return true;
-    }
-  if( strcmp(key,"ID")==0 ) 
-    {
-    inputStream.close();
-    return true;
-    }
-  if( strcmp(key,"ParentID")==0 ) 
-    {
-    inputStream.close();
-    return true;
-    }
-  if( strcmp(key,"BinaryData")==0 ) 
-    {
-    inputStream.close();
-    return true;
-    }
-  if( strcmp(key,"Comment")==0 ) 
-    {
-    inputStream.close();
-    return true;
-    }
-  if( strcmp(key,"AcquisitionDate")==0 ) 
-    {
-    inputStream.close();
-    return true;
-    }
-  if( strcmp(key,"Modality")==0 ) 
-    {
-    inputStream.close();
-    return true;
-    }
-
-  inputStream.close();
-  return false;
-
+  return m_MetaImage.CanRead(filename);
 }
   
 
@@ -437,11 +348,11 @@ void MetaImageIO::ReadImageInformation()
   
   this->SetNumberOfDimensions(m_MetaImage.NDims());
 
-  int i;
-  for(i=0; i<(int)m_NumberOfDimensions; i++)
+  unsigned int i;
+  for(i=0; i<m_NumberOfDimensions; i++)
     {
-    this->SetDimensions(i, m_MetaImage.DimSize(i));
-    this->SetSpacing(i, m_MetaImage.ElementSpacing(i));
+    this->SetDimensions(i,m_MetaImage.DimSize(i)/m_SubSamplingFactor);
+    this->SetSpacing(i, m_MetaImage.ElementSpacing(i)*m_SubSamplingFactor);
     this->SetOrigin(i, m_MetaImage.Position(i));
     } 
 
@@ -781,7 +692,7 @@ void MetaImageIO::ReadImageInformation()
               }
             break;
             }
-           case MET_ORIENTATION_PA:
+          case MET_ORIENTATION_PA:
             {
             if(m_MetaImage.AnatomicalOrientation(2) == MET_ORIENTATION_RL)
               {
@@ -890,25 +801,47 @@ void MetaImageIO::ReadImageInformation()
           (thisMetaDict, ITK_CoordinateOrientation, coordOrient);
       }
 #endif
-    // Read direction cosines if the dimension of the image is 3.
-    //
-    const double *transformMatrix = m_MetaImage.TransformMatrix();
-    vnl_vector< double > directionAxis( this->GetNumberOfDimensions() );
-    for( unsigned int i=0; i < this->GetNumberOfDimensions(); i++)
+    }
+
+  //
+  // Read direction cosines 
+  //
+  const double *transformMatrix = m_MetaImage.TransformMatrix();
+  vnl_vector< double > directionAxis( this->GetNumberOfDimensions() );
+  for( unsigned int ii=0; ii < this->GetNumberOfDimensions(); ii++)
+    {
+    for( unsigned int jj=0; jj < this->GetNumberOfDimensions(); jj++)
       {
-      for( unsigned int j=0; j < this->GetNumberOfDimensions(); j++)
-        {
-        directionAxis[j] = transformMatrix[i*this->GetNumberOfDimensions() + j];
-        }
-      this->SetDirection( i, directionAxis );
+      directionAxis[jj] = transformMatrix[ii*this->GetNumberOfDimensions() + jj];
       }
+    this->SetDirection( ii, directionAxis );
     }
 } 
 
 
 void MetaImageIO::Read(void* buffer)
 { 
-  if(!m_MetaImage.Read(m_FileName.c_str(), true, buffer))
+  // Pass the IO region to the MetaImage library
+  unsigned int nDims = this->GetNumberOfDimensions();
+
+  if(m_UseStreamedReading)
+    {
+    int* indexMin = new int[nDims];
+    int* indexMax = new int[nDims];
+    for(unsigned int i=0;i<nDims;i++)
+      {
+      indexMin[i] = m_IORegion.GetIndex()[i];
+      indexMax[i] = indexMin[i] + m_IORegion.GetSize()[i] -1;
+      }
+
+    m_MetaImage.ReadROI(indexMin, indexMax, 
+                        m_FileName.c_str(), true, buffer,
+                        m_SubSamplingFactor);
+ 
+    delete [] indexMin;
+    delete [] indexMax;
+    }
+  else if(!m_MetaImage.Read(m_FileName.c_str(), true, buffer))
     {
     ExceptionObject exception(__FILE__, __LINE__);
     exception.SetDescription("File cannot be read");
@@ -964,7 +897,7 @@ void
 MetaImageIO
 ::Write( const void* buffer) 
 {
-  int nDims = this->GetNumberOfDimensions();
+  unsigned int nDims = this->GetNumberOfDimensions();
 
   bool binaryData = true;
   if(this->GetFileType() == ASCII)
@@ -995,48 +928,76 @@ MetaImageIO
       break;
     case LONG:
       if(sizeof(long) == MET_ValueTypeSize[MET_LONG])
+        {
         eType = MET_LONG;
+        }
       else if(sizeof(long) == MET_ValueTypeSize[MET_INT])
+        {
         eType = MET_INT;
+        }
       else if(sizeof(long) == MET_ValueTypeSize[MET_LONG_LONG])
+        {
         eType = MET_LONG_LONG;
+        }
       break;
     case ULONG:
       if(sizeof(long) == MET_ValueTypeSize[MET_LONG])
+        {
         eType = MET_ULONG;
+        }
       else if(sizeof(long) == MET_ValueTypeSize[MET_INT])
+        {
         eType = MET_UINT;
+        }
       else if(sizeof(long) == MET_ValueTypeSize[MET_LONG_LONG])
+        {
         eType = MET_ULONG_LONG;
+        }
       break;
     case INT:
       eType = MET_INT;
       if(sizeof(int) == MET_ValueTypeSize[MET_INT])
+        {
         eType = MET_INT;
+        }
       else if(sizeof(int) == MET_ValueTypeSize[MET_LONG])
+        {
         eType = MET_LONG;
+        }
       break;
     case UINT:
       if(sizeof(int) == MET_ValueTypeSize[MET_INT])
+        {
         eType = MET_UINT;
+        }
       else if(sizeof(int) == MET_ValueTypeSize[MET_LONG])
+        {
         eType = MET_ULONG;
+        }
       break;
     case FLOAT:
       if(sizeof(float) == MET_ValueTypeSize[MET_FLOAT])
+        {
         eType = MET_FLOAT;
+        }
       else if(sizeof(float) == MET_ValueTypeSize[MET_DOUBLE])
+        {
         eType = MET_DOUBLE;
+        }
       break;
     case DOUBLE:
       if(sizeof(double) == MET_ValueTypeSize[MET_DOUBLE])
+        {
         eType = MET_DOUBLE;
+        }
       else if(sizeof(double) == MET_ValueTypeSize[MET_FLOAT])
+        {
         eType = MET_FLOAT;
+        }
       break;
     }
   
-  int i;
+  unsigned int i;
   int * dSize = new int[nDims];
   float * eSpacing = new float[nDims];
   double * eOrigin = new double[nDims];
@@ -1049,7 +1010,7 @@ MetaImageIO
   ImageIORegion::IndexType indx = this->GetIORegion().GetIndex();
   for(i=0; i<nDims; i++)
     {
-    int j;
+    unsigned int j;
     for(j=0; j<nDims; j++)
       {
       eOrigin[i] += indx[j] * eSpacing[j] * this->GetDirection(j)[i];
@@ -1079,11 +1040,11 @@ MetaImageIO
       dirx = this->GetDirection(0);
       diry = this->GetDirection(1);
       dirz = this->GetDirection(2);
-      for(unsigned i = 0; i < 3; i++)
+      for(unsigned ii = 0; ii < 3; ii++)
         {
-        dir[i][0] = dirx[0];
-        dir[i][1] = diry[0];
-        dir[i][2] = dirz[0];
+        dir[ii][0] = dirx[ii];
+        dir[ii][1] = diry[ii];
+        dir[ii][2] = dirz[ii];
         }
       coordOrient = itk::SpatialOrientationAdapter().FromDirectionCosines(dir);
 #if defined(ITKIO_DEPRECATED_METADATA_ORIENTATION)
@@ -1319,33 +1280,83 @@ MetaImageIO
         }
       }
 
-    // Propagage direction cosine information .
-    double *transformMatrix = 
-    static_cast< double *>(malloc(this->GetNumberOfDimensions() * 
-                    this->GetNumberOfDimensions() * sizeof(double)));
-    for( unsigned int i=0; i < this->GetNumberOfDimensions(); i++)
-      {
-      for( unsigned int j=0; j < this->GetNumberOfDimensions(); j++)
-        {
-        transformMatrix[i*this->GetNumberOfDimensions() +j ] =
-                                           this->GetDirection(i)[j];
-        }
-      }
-    m_MetaImage.TransformMatrix( transformMatrix );      
-    free(transformMatrix);
     }
 
+  // Propagage direction cosine information .
+  double *transformMatrix = 
+  static_cast< double *>(malloc(this->GetNumberOfDimensions() * 
+                  this->GetNumberOfDimensions() * sizeof(double)));
+  for( unsigned int ii=0; ii < this->GetNumberOfDimensions(); ii++)
+    {
+    for( unsigned int jj=0; jj < this->GetNumberOfDimensions(); jj++)
+      {
+      transformMatrix[ii*this->GetNumberOfDimensions() +jj ] =
+                                         this->GetDirection(ii)[jj];
+      }
+    }
+  m_MetaImage.TransformMatrix( transformMatrix );
+  free(transformMatrix);
   
   m_MetaImage.CompressedData(m_UseCompression);
-  m_MetaImage.Write(m_FileName.c_str());
+
+  if(m_UseCompression && m_UseStreamedWriting)
+    {
+    std::cout << "Cannot use compression while stream reading" << std::endl;
+    }
+  else if(m_UseStreamedWriting)
+    {
+    int* indexMin = new int[nDims];
+    int* indexMax = new int[nDims];
+    for(unsigned int k=0;k<nDims;k++)
+      {
+      indexMin[k] = m_IORegion.GetIndex()[k];
+      indexMax[k] = m_IORegion.GetIndex()[k]+m_IORegion.GetSize()[k];
+      }
+      
+    m_MetaImage.WriteROI(indexMin,indexMax,m_FileName.c_str());
+    
+    delete [] indexMin;
+    delete [] indexMax;
+    }
+  else
+    {
+    m_MetaImage.Write(m_FileName.c_str());
+    }
 
   delete []dSize;
   delete []eSpacing;
   delete []eOrigin;
 }
 
+/** Given a requested region, determine what could be the region that we can
+ * read from the file. This is called the streamable region, which will be
+ * smaller than the LargestPossibleRegion and greater or equal to the 
+ * RequestedRegion */
+ImageIORegion 
+MetaImageIO
+::GenerateStreamableReadRegionFromRequestedRegion( const ImageIORegion & requestedRegion  ) const
+{
+  //
+  // The default implementations determines that the streamable region is
+  // equal to the largest possible region of the image.
+  //
+  ImageIORegion streamableRegion(this->m_NumberOfDimensions);
+  if(!m_UseStreamedReading)
+    { 
+    for( unsigned int i=0; i < this->m_NumberOfDimensions; i++ )
+      {
+      streamableRegion.SetSize( i, this->m_Dimensions[i] );
+      streamableRegion.SetIndex( i, 0 );
+      }
+    }
+  else
+    {
+    streamableRegion = requestedRegion;
+    }
 
-
+  return streamableRegion;
+}
+ 
 
 
 } // end namespace itk
