@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: DeformableRegistration6.cxx,v $
   Language:  C++
-  Date:      $Date: 2006/05/14 12:16:22 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2008-04-11 16:01:02 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -82,7 +82,7 @@ int main( int argc, char *argv[] )
     std::cerr << " fixedImageFile  movingImageFile outputImagefile  ";
     std::cerr << " [differenceOutputfile] [differenceBeforeRegistration] ";
     std::cerr << " [deformationField] ";
-    return 1;
+    return EXIT_FAILURE;
     }
   
   const    unsigned int    ImageDimension = 2;
@@ -225,14 +225,15 @@ int main( int argc, char *argv[] )
 
   for(unsigned int r=0; r<ImageDimension; r++)
     {
-    spacingLow[r] *= floor( static_cast<double>(fixedImageSize[r] - 1)  / 
-                            static_cast<double>(gridLowSizeOnImage[r] - 1) );
+    spacingLow[r] *= static_cast<double>(fixedImageSize[r] - 1)  / 
+                     static_cast<double>(gridLowSizeOnImage[r] - 1);
     originLow[r]  -=  spacingLow[r]; 
     }
 
   transformLow->SetGridSpacing( spacingLow );
   transformLow->SetGridOrigin( originLow );
   transformLow->SetGridRegion( bsplineRegion );
+  transformLow->SetGridDirection( fixedImage->GetDirection() );
 
   typedef TransformType::ParametersType     ParametersType;
 
@@ -276,7 +277,7 @@ int main( int argc, char *argv[] )
     { 
     std::cerr << "ExceptionObject caught !" << std::endl; 
     std::cerr << err << std::endl; 
-    return -1;
+    return EXIT_FAILURE;
     } 
   // Software Guide : EndCodeSnippet
   
@@ -302,14 +303,15 @@ int main( int argc, char *argv[] )
 
   for(unsigned int rh=0; rh<ImageDimension; rh++)
     {
-    spacingHigh[rh] *= floor( static_cast<double>(fixedImageSize[rh] - 1)  / 
-                            static_cast<double>(gridHighSizeOnImage[rh] - 1) );
+    spacingHigh[rh] *= static_cast<double>(fixedImageSize[rh] - 1)  / 
+                       static_cast<double>(gridHighSizeOnImage[rh] - 1);
     originHigh[rh]  -=  spacingHigh[rh]; 
     }
 
   transformHigh->SetGridSpacing( spacingHigh );
   transformHigh->SetGridOrigin( originHigh );
   transformHigh->SetGridRegion( bsplineRegion );
+  transformHigh->SetGridDirection( fixedImage->GetDirection() );
 
   ParametersType parametersHigh( transformHigh->GetNumberOfParameters() );
   parametersHigh.Fill( 0.0 );
@@ -399,7 +401,7 @@ int main( int argc, char *argv[] )
     { 
     std::cerr << "ExceptionObject caught !" << std::endl; 
     std::cerr << err << std::endl; 
-    return -1;
+    return EXIT_FAILURE;
     } 
   // Software Guide : EndCodeSnippet
 
@@ -421,6 +423,7 @@ int main( int argc, char *argv[] )
   resample->SetSize(    fixedImage->GetLargestPossibleRegion().GetSize() );
   resample->SetOutputOrigin(  fixedImage->GetOrigin() );
   resample->SetOutputSpacing( fixedImage->GetSpacing() );
+  resample->SetOutputDirection( fixedImage->GetDirection() );
   resample->SetDefaultPixelValue( 100 );
   
   typedef  unsigned char  OutputPixelType;
@@ -453,7 +456,7 @@ int main( int argc, char *argv[] )
     { 
     std::cerr << "ExceptionObject caught !" << std::endl; 
     std::cerr << err << std::endl; 
-    return -1;
+    return EXIT_FAILURE;
     } 
  
 
@@ -484,7 +487,7 @@ int main( int argc, char *argv[] )
       { 
       std::cerr << "ExceptionObject caught !" << std::endl; 
       std::cerr << err << std::endl; 
-      return -1;
+      return EXIT_FAILURE;
       } 
     }
 
@@ -504,7 +507,7 @@ int main( int argc, char *argv[] )
       { 
       std::cerr << "ExceptionObject caught !" << std::endl; 
       std::cerr << err << std::endl; 
-      return -1;
+      return EXIT_FAILURE;
       } 
     }
 
@@ -566,6 +569,6 @@ int main( int argc, char *argv[] )
       }
     }
 
-  return 0;
+  return EXIT_SUCCESS;
 }
 
