@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ImageRegistration10.cxx,v $
   Language:  C++
-  Date:      $Date: 2005/11/20 13:27:53 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date: 2007-11-22 00:30:16 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -96,7 +96,7 @@ int main( int argc, char *argv[] )
     std::cerr << " fixedImageFile  movingImageFile ";
     std::cerr << " outputImagefile [differenceImage]" << std::endl;
     std::cerr << " [initialTx] [initialTy]" << std::endl;
-    return 1;
+    return EXIT_FAILURE;
     }
 
   itk::FileOutputWindow::Pointer fow = itk::FileOutputWindow::New();
@@ -358,7 +358,7 @@ int main( int argc, char *argv[] )
     { 
     std::cout << "ExceptionObject caught !" << std::endl; 
     std::cout << err << std::endl; 
-    return -1;
+    return EXIT_FAILURE;
     } 
 
   // In a real application, you may attempt to recover from the error in the
@@ -445,6 +445,7 @@ int main( int argc, char *argv[] )
   resample->SetSize( fixedImage->GetLargestPossibleRegion().GetSize() );
   resample->SetOutputOrigin(  fixedImage->GetOrigin() );
   resample->SetOutputSpacing( fixedImage->GetSpacing() );
+  resample->SetOutputDirection( fixedImage->GetDirection() );
   resample->SetDefaultPixelValue( 0 );
   resample->SetInterpolator( interpolator );
 
@@ -505,7 +506,7 @@ int main( int argc, char *argv[] )
     }
 
 
-  return 0;
+  return EXIT_SUCCESS;
 }
 
 // SoftwareGuide : BeginLatex
