@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ImageRegistration2o.cxx,v $
   Language:  C++
-  Date:      $Date: 2005/10/06 17:27:41 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2007-11-22 00:30:16 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -132,13 +132,13 @@ public:
 
 int main( int argc, char *argv[] )
 {
-  if( argc < 3 )
+  if( argc < 4 )
     {
     std::cerr << "Missing Parameters " << std::endl;
     std::cerr << "Usage: " << argv[0];
     std::cerr << " fixedImageFile  movingImageFile ";
     std::cerr << "outputImagefile [differenceImage]" << std::endl;
-    return 1;
+    return EXIT_FAILURE;
     }
   
   // Software Guide : BeginLatex
@@ -250,7 +250,6 @@ int main( int argc, char *argv[] )
   // Software Guide : BeginCodeSnippet
   metric->SetFixedImageStandardDeviation(  0.4 );
   metric->SetMovingImageStandardDeviation( 0.4 );
-  metric->SetNumberOfSpatialSamples( 50 );
   // Software Guide : EndCodeSnippet
 
   typedef itk::ImageFileReader< FixedImageType  > FixedImageReaderType;
@@ -331,8 +330,9 @@ int main( int argc, char *argv[] )
 
 
   fixedNormalizer->Update();
-  registration->SetFixedImageRegion( 
-       fixedNormalizer->GetOutput()->GetBufferedRegion() );
+  FixedImageType::RegionType fixedImageRegion =
+       fixedNormalizer->GetOutput()->GetBufferedRegion();
+  registration->SetFixedImageRegion( fixedImageRegion );
 
   typedef RegistrationType::ParametersType ParametersType;
   ParametersType initialParameters( transform->GetNumberOfParameters() );
@@ -342,6 +342,15 @@ int main( int argc, char *argv[] )
   
   registration->SetInitialTransformParameters( initialParameters );
 
+  // Software Guide : BeginCodeSnippet
+  const unsigned int numberOfPixels = fixedImageRegion.GetNumberOfPixels();
+  
+  const unsigned int numberOfSamples = 
+                        static_cast< unsigned int >( numberOfPixels * 0.01 );
+
+  metric->SetNumberOfSpatialSamples( numberOfSamples );
+  // Software Guide : EndCodeSnippet
+
 
   //  Software Guide : BeginLatex
   //  
@@ -360,7 +369,7 @@ int main( int argc, char *argv[] )
 
 
   // Software Guide : BeginCodeSnippet
-  optimizer->SetLearningRate( 20.0 );
+  optimizer->SetLearningRate( 15.0 );
   optimizer->SetNumberOfIterations( 200 );
   optimizer->MaximizeOn();
   // Software Guide : EndCodeSnippet
@@ -380,7 +389,7 @@ int main( int argc, char *argv[] )
     { 
     std::cout << "ExceptionObject caught !" << std::endl; 
     std::cout << err << std::endl; 
-    return -1;
+    return EXIT_FAILURE;
     } 
 
   ParametersType finalParameters = registration->GetLastTransformParameters();
@@ -455,6 +464,7 @@ int main( int argc, char *argv[] )
   resample->SetSize(    fixedImage->GetLargestPossibleRegion().GetSize() );
   resample->SetOutputOrigin(  fixedImage->GetOrigin() );
   resample->SetOutputSpacing( fixedImage->GetSpacing() );
+  resample->SetOutputDirection( fixedImage->GetDirection() );
   resample->SetDefaultPixelValue( 100 );
 
 
@@ -561,6 +571,6 @@ int main( int argc, char *argv[] )
   //
   //  Software Guide : EndLatex 
 
-  return 0;
+  return EXIT_SUCCESS;
 }
 
