@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ImageRegistration7.cxx,v $
   Language:  C++
-  Date:      $Date: 2006/05/14 12:16:23 $
-  Version:   $Revision: 1.31 $
+  Date:      $Date: 2007-11-22 00:30:16 $
+  Version:   $Revision: 1.33 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -141,7 +141,7 @@ int main( int argc, char *argv[] )
     std::cerr << " [steplength] ";
     std::cerr << " [initialScaling] [initialAngle] ";
     std::cerr << std::endl;
-    return 1;
+    return EXIT_FAILURE;
     }
   
   const    unsigned int    Dimension = 2;
@@ -357,7 +357,7 @@ int main( int argc, char *argv[] )
     { 
     std::cerr << "ExceptionObject caught !" << std::endl; 
     std::cerr << err << std::endl; 
-    return -1;
+    return EXIT_FAILURE;
     } 
   
   OptimizerType::ParametersType finalParameters = 
@@ -494,6 +494,7 @@ int main( int argc, char *argv[] )
   resampler->SetSize(    fixedImage->GetLargestPossibleRegion().GetSize() );
   resampler->SetOutputOrigin(  fixedImage->GetOrigin() );
   resampler->SetOutputSpacing( fixedImage->GetSpacing() );
+  resampler->SetOutputDirection( fixedImage->GetDirection() );
   resampler->SetDefaultPixelValue( 100 );
   
   typedef  unsigned char  OutputPixelType;
@@ -567,6 +568,6 @@ int main( int argc, char *argv[] )
     }
 
 
-  return 0;
+  return EXIT_SUCCESS;
 }
 
