@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBSplineInterpolateImageFunctionTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003/09/10 14:30:05 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2007-08-10 14:34:01 $
+  Version:   $Revision: 1.10 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -600,10 +600,10 @@ itkBSplineInterpolateImageFunctionTest(
   if (flag != 0) {
     std::cout << "*** " << flag << " tests failed" << std::endl;
   
-    return 1; }
+    return EXIT_FAILURE; }
   else {
     std::cout << "All tests successfully passed" << std::endl;
-    return 0; }
+    return EXIT_SUCCESS; }
 
 }
 
