@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBSplineResampleImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005/08/14 02:54:24 $
-  Version:   $Revision: 1.15 $
+  Date:      $Date: 2007-08-10 14:34:01 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -359,7 +359,7 @@ int test2D_Standard_L2_NthOrderSpline_filter(unsigned int splineOrder)
   ImageTypePtr2D outImage2 = upSampler->GetOutput();
   PrintImageData(outImage2);
 
-  bool sameResults;
+  bool sameResults = false;
   if( splineOrder == 5 ) 
     {
     sameResults = VerifyResultsHigherOrderSpline(outImage2, ExpectedResults);
@@ -426,7 +426,7 @@ int test2D_Centered_l2_NthOrderSpline_filter(unsigned int splineOrder)
     upSampler->Update();
   ImageTypePtr2D outImage2 = upSampler->GetOutput();
   PrintImageData(outImage2);
-  bool sameResults;
+  bool sameResults = false;
   if( splineOrder == 4 ) 
     {
     sameResults = VerifyResultsHigherOrderSpline(outImage2, ExpectedResults);
@@ -557,7 +557,7 @@ int test2D_Centered_L2_NthOrderSpline_filter(unsigned int splineOrder)
   ImageTypePtr2D outImage2 = upSampler->GetOutput();
   PrintImageData(outImage2);
 
-  bool sameResults;
+  bool sameResults = false;
   if( splineOrder == 4 ) 
     {
     sameResults = VerifyResultsHigherOrderSpline(outImage2, ExpectedResults);
@@ -700,10 +700,10 @@ itkBSplineResampleImageFilterTest(
   if (flag != 0) {
     std::cout << "*** " << flag << " tests failed" << std::endl;
   
-    return 1; }
+    return EXIT_FAILURE; }
   else {
     std::cout << "All tests successfully passed" << std::endl;
-    return 0; }
+    return EXIT_SUCCESS; }
 
 }
 
