@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkOrientImageFilterTest2.cxx,v $
   Language:  C++
-  Date:      $Date: 2005/04/23 12:36:48 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2007-08-10 14:34:02 $
+  Version:   $Revision: 1.2 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -467,5 +467,5 @@ int itkOrientImageFilterTest2(int,char *[])
   orienter->Update();
   std::cout << orienter->GetOutput()->GetDirection() << std::endl;
 
-  return 0;
+  return EXIT_SUCCESS;
 }
