@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkReadWriteSpatialObjectTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006/08/31 22:55:34 $
-  Version:   $Revision: 1.22 $
+  Date:      $Date: 2008-01-27 19:48:47 $
+  Version:   $Revision: 1.24 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -25,6 +25,7 @@
 #include "itkGroupSpatialObject.h"
 #include "itkSpatialObjectWriter.h"
 #include "itkSpatialObjectReader.h"
+#include "itkImageMaskSpatialObject.h"
 
 int itkReadWriteSpatialObjectTest(int argc, char* argv[])
 {
@@ -49,6 +50,7 @@ int itkReadWriteSpatialObjectTest(int argc, char* argv[])
 
 
   typedef itk::ImageSpatialObject<3,unsigned short>  ImageType;
+  typedef itk::ImageMaskSpatialObject<3>             ImageMaskType;
 
   typedef itk::SpatialObjectWriter<3,unsigned short> WriterType;
   typedef itk::SpatialObjectReader<3,unsigned short> ReaderType;
@@ -277,19 +279,41 @@ int itkReadWriteSpatialObjectTest(int argc, char* argv[])
   itkImage->SetSpacing(spacing);
   itkImage->Allocate();
 
-  itk::ImageRegionIteratorWithIndex< itkImageType > it(itkImage, region);
-  for(unsigned int i = 0; !it.IsAtEnd(); i++, ++it)
+  itk::ImageRegionIteratorWithIndex< itkImageType > sit(itkImage, region);
+  for(unsigned int i = 0; !sit.IsAtEnd(); i++, ++sit)
     {
-    it.Set(i);
+    sit.Set(i);
     }
 
-
   ImageType::Pointer image = ImageType::New();
   image->GetProperty()->SetName("Image 1");
   image->SetImage(itkImage);
 
   tubeN2->AddSpatialObject( image );
 
+  // Create Mask Image
+  typedef ImageMaskType::ImageType   itkImageMaskType;
+  typedef itkImageMaskType::Pointer  ImageMaskPointer;
+
+  ImageMaskPointer itkImageMask = itkImageMaskType::New();
+
+  itkImageMask->SetLargestPossibleRegion(region);
+  itkImageMask->SetBufferedRegion(region);
+  itkImageMask->SetRequestedRegion(region);
+  itkImageMask->SetSpacing(spacing);
+  itkImageMask->Allocate();
+
+  itk::ImageRegionIteratorWithIndex< itkImageMaskType > itM(itkImageMask, region);
+  for(unsigned int i = 0; !itM.IsAtEnd(); i++, ++itM)
+    {
+    itM.Set(i);
+    }
+
+  ImageMaskType::Pointer maskImage = ImageMaskType::New();
+  maskImage->GetProperty()->SetName("Mask Image 1");
+  maskImage->SetImage(itkImageMask);
+
+  tubeN2->AddSpatialObject( maskImage );
 
   // Define a contour
   ContourType::Pointer contour = ContourType::New();
@@ -662,9 +686,9 @@ int itkReadWriteSpatialObjectTest(int argc, char* argv[])
     {
     if(!strcmp((*obj)->GetTypeName(),"EllipseSpatialObject"))
       {
-      for(unsigned int j=0;j<3;j++)
+      for(unsigned int jj=0;jj<3;jj++)
         {
-        if (dynamic_cast<EllipseType*>((*obj).GetPointer())->GetRadius()[j] != 9)
+        if (dynamic_cast<EllipseType*>((*obj).GetPointer())->GetRadius()[jj] != 9)
           {
           std::cout<<" [FAILED]"<<std::endl; 
           return EXIT_FAILURE;
@@ -688,8 +712,8 @@ int itkReadWriteSpatialObjectTest(int argc, char* argv[])
     {
     if(!strcmp((*obj)->GetTypeName(),"ImageSpatialObject"))
       {
-      itkImageType::ConstPointer image = dynamic_cast<const ImageType*>((*obj).GetPointer())->GetImage();
-      itk::ImageRegionConstIteratorWithIndex< itkImageType > it(image, image->GetLargestPossibleRegion());
+      itkImageType::ConstPointer constImage = dynamic_cast<const ImageType*>((*obj).GetPointer())->GetImage();
+      itk::ImageRegionConstIteratorWithIndex< itkImageType > it(constImage, constImage->GetLargestPossibleRegion());
       for(unsigned int i = 0; !it.IsAtEnd(); i++, ++it)
         {
         if(it.Get() != i)
@@ -704,47 +728,78 @@ int itkReadWriteSpatialObjectTest(int argc, char* argv[])
 
   std::cout<<" [PASSED]"<<std::endl; 
 
+  std::cout<<"Testing Image Mask validity:";
+
+  bool maskFound = false;
+  for(obj = mySceneChildren->begin(); obj != mySceneChildren->end(); obj++)
+    {
+    if(!strcmp((*obj)->GetTypeName(),"ImageMaskSpatialObject"))
+      {
+      maskFound = true;
+      itkImageMaskType::ConstPointer constImage = dynamic_cast<const ImageMaskType*>((*obj).GetPointer())->GetImage();
+      itk::ImageRegionConstIteratorWithIndex< itkImageMaskType > it(constImage, constImage->GetLargestPossibleRegion());
+      for(unsigned char i = 0; !it.IsAtEnd(); i++, ++it)
+        {
+        if(it.Get() != i)
+          {
+          std::cout << "Expected " << i << " , found " << it.Get() << std::endl;
+          std::cout<<" [FAILED]"<<std::endl; 
+          return EXIT_FAILURE;
+          }
+        }
+      }
+    }
+
+  if(!maskFound)
+    {
+    std::cout << "No Mask!" << std::endl;
+    std::cout<<" [FAILED]"<<std::endl; 
+    return EXIT_FAILURE;
+    }
+
+  std::cout<<" [PASSED]"<<std::endl; 
+
   std::cout<<"Testing Blob validity:";
 
   for(obj = mySceneChildren->begin(); obj != mySceneChildren->end(); obj++)
     {
-    BlobType::PointListType::const_iterator j;
+    BlobType::PointListType::const_iterator pit;
     if(!strcmp((*obj)->GetTypeName(),"BlobSpatialObject"))
       {
       unsigned int value = 0;
-      for(j = dynamic_cast<BlobType*>((*obj).GetPointer())->GetPoints().begin(); 
-          j != dynamic_cast<BlobType*>((*obj).GetPointer())->GetPoints().end(); 
-          j++)
+      for(pit = dynamic_cast<BlobType*>((*obj).GetPointer())->GetPoints().begin(); 
+          pit != dynamic_cast<BlobType*>((*obj).GetPointer())->GetPoints().end(); 
+          pit++)
         {
         for(unsigned int d=0;d<3;d++)
           {
-          if((*j).GetPosition()[d]!=value)
+          if((*pit).GetPosition()[d]!=value)
             {
             std::cout<<" [FAILED]"<<std::endl;
             return EXIT_FAILURE;
             }
           // Testing the color of the tube points
-          if( (*j).GetRed() != value)
+          if( (*pit).GetRed() != value)
             {
-            std::cout<<" [FAILED] : Red : found " << (*j).GetRed() << " instead of " << value <<std::endl;
+            std::cout<<" [FAILED] : Red : found " << (*pit).GetRed() << " instead of " << value <<std::endl;
             return EXIT_FAILURE;
             }
       
-          if((*j).GetGreen()!=value+1)
+          if((*pit).GetGreen()!=value+1)
             {
-            std::cout<<" [FAILED] : Green : found " << (*j).GetGreen() << " instead of " << value+1 <<std::endl;
+            std::cout<<" [FAILED] : Green : found " << (*pit).GetGreen() << " instead of " << value+1 <<std::endl;
             return EXIT_FAILURE;
             }
           
-          if((*j).GetBlue()!=value+2)
+          if((*pit).GetBlue()!=value+2)
             {
-            std::cout<<" [FAILED] : Blue : found " << (*j).GetBlue() << " instead of " << value+2 <<std::endl;
+            std::cout<<" [FAILED] : Blue : found " << (*pit).GetBlue() << " instead of " << value+2 <<std::endl;
             return EXIT_FAILURE;
             }
           
-          if((*j).GetAlpha()!=value+3)
+          if((*pit).GetAlpha()!=value+3)
             {
-            std::cout<<" [FAILED] : Alpha : found " << (*j).GetAlpha() << " instead of " << value+3 <<std::endl;
+            std::cout<<" [FAILED] : Alpha : found " << (*pit).GetAlpha() << " instead of " << value+3 <<std::endl;
             return EXIT_FAILURE;
             }
           }
@@ -760,52 +815,52 @@ int itkReadWriteSpatialObjectTest(int argc, char* argv[])
 
   for(obj = mySceneChildren->begin(); obj != mySceneChildren->end(); obj++)
     {
-    SurfaceType::PointListType::const_iterator j;
+    SurfaceType::PointListType::const_iterator pit;
     if(!strcmp((*obj)->GetTypeName(),"SurfaceSpatialObject"))
       {
       unsigned int value = 0;
-      for(j = dynamic_cast<SurfaceType*>((*obj).GetPointer())->GetPoints().begin(); 
-          j != dynamic_cast<SurfaceType*>((*obj).GetPointer())->GetPoints().end(); 
-          j++)
+      for(pit = dynamic_cast<SurfaceType*>((*obj).GetPointer())->GetPoints().begin(); 
+          pit != dynamic_cast<SurfaceType*>((*obj).GetPointer())->GetPoints().end(); 
+          pit++)
         {
         for(unsigned int d=0;d<3;d++)
           {
-          if((*j).GetPosition()[d]!=value)
+          if((*pit).GetPosition()[d]!=value)
             {
-            std::cout << (*j).GetPosition()[d] << "!=" << value << std::endl;
+            std::cout << (*pit).GetPosition()[d] << "!=" << value << std::endl;
             std::cout<<" [FAILED]"<<std::endl;
             return EXIT_FAILURE;
             }
 
-          if((*j).GetNormal()[d]!= d)
+          if((*pit).GetNormal()[d]!= d)
             {
-            std::cout << "Normal : " << (*j).GetNormal()[d] << std::endl;
+            std::cout << "Normal : " << (*pit).GetNormal()[d] << std::endl;
             std::cout<<" [FAILED]"<<std::endl;
             return EXIT_FAILURE;
             }
 
           // Testing the color of the tube points
-          if( (*j).GetRed() != value)
+          if( (*pit).GetRed() != value)
             {
-            std::cout<<" [FAILED] : Red : found " << ( *j).GetRed() << " instead of " << value <<std::endl;
+            std::cout<<" [FAILED] : Red : found " << ( *pit).GetRed() << " instead of " << value <<std::endl;
             return EXIT_FAILURE;
             }
           
-          if((*j).GetGreen()!=value+1)
+          if((*pit).GetGreen()!=value+1)
             {
-            std::cout<<" [FAILED] : Green : found " << ( *j).GetGreen() << " instead of " << value+1 <<std::endl;
+            std::cout<<" [FAILED] : Green : found " << ( *pit).GetGreen() << " instead of " << value+1 <<std::endl;
             return EXIT_FAILURE;
             }
       
-          if((*j).GetBlue()!=value+2)
+          if((*pit).GetBlue()!=value+2)
             {
-            std::cout<<" [FAILED] : Blue : found " << ( *j).GetBlue() << " instead of " << value+2 <<std::endl;
+            std::cout<<" [FAILED] : Blue : found " << ( *pit).GetBlue() << " instead of " << value+2 <<std::endl;
             return EXIT_FAILURE;
             }
     
-          if((*j).GetAlpha()!=value+3)
+          if((*pit).GetAlpha()!=value+3)
             {
-            std::cout<<" [FAILED] : Alpha : found " << ( *j).GetAlpha() << " instead of " << value+3 <<std::endl;
+            std::cout<<" [FAILED] : Alpha : found " << ( *pit).GetAlpha() << " instead of " << value+3 <<std::endl;
             return EXIT_FAILURE;
             }
           }
@@ -820,56 +875,56 @@ int itkReadWriteSpatialObjectTest(int argc, char* argv[])
 
   for(obj = mySceneChildren->begin(); obj != mySceneChildren->end(); obj++)
     {
-    LineType::PointListType::const_iterator j;
+    LineType::PointListType::const_iterator pit;
     if(!strcmp((*obj)->GetTypeName(),"LineSpatialObject"))
       {
       unsigned int value = 0;
-      for(j = dynamic_cast<LineType*>((*obj).GetPointer())->GetPoints().begin(); 
-          j != dynamic_cast<LineType*>((*obj).GetPointer())->GetPoints().end(); 
-          j++)
+      for(pit = dynamic_cast<LineType*>((*obj).GetPointer())->GetPoints().begin(); 
+          pit != dynamic_cast<LineType*>((*obj).GetPointer())->GetPoints().end(); 
+          pit++)
         {
         for(unsigned int d=0;d<3;d++)
           {
-          if((*j).GetPosition()[d]!=value)
+          if((*pit).GetPosition()[d]!=value)
             {
             std::cout<<" [FAILED]"<<std::endl;
             return EXIT_FAILURE;
             }
 
-          if(((*j).GetNormal(0))[d]!= d)
+          if(((*pit).GetNormal(0))[d]!= d)
             {
             std::cout<<" [FAILED]"<<std::endl;
             return EXIT_FAILURE;
             }
 
-          if(((*j).GetNormal(1))[d]!= 2*d)
+          if(((*pit).GetNormal(1))[d]!= 2*d)
             {
             std::cout<<" [FAILED]"<<std::endl;
             return EXIT_FAILURE;
             }
 
           // Testing the color of the tube points
-          if( (*j).GetRed() != value)
+          if( (*pit).GetRed() != value)
             {
-            std::cout<<" [FAILED] : Red : found " << ( *j).GetRed() << " instead of " << value <<std::endl;
+            std::cout<<" [FAILED] : Red : found " << ( *pit).GetRed() << " instead of " << value <<std::endl;
             return EXIT_FAILURE;
             }
           
-          if((*j).GetGreen()!=value+1)
+          if((*pit).GetGreen()!=value+1)
             {
-            std::cout<<" [FAILED] : Green : found " << ( *j).GetGreen() << " instead of " << value+1 <<std::endl;
+            std::cout<<" [FAILED] : Green : found " << ( *pit).GetGreen() << " instead of " << value+1 <<std::endl;
             return EXIT_FAILURE;
             }
       
-          if((*j).GetBlue()!=value+2)
+          if((*pit).GetBlue()!=value+2)
             {
-            std::cout<<" [FAILED] : Blue : found " << ( *j).GetBlue() << " instead of " << value+2 <<std::endl;
+            std::cout<<" [FAILED] : Blue : found " << ( *pit).GetBlue() << " instead of " << value+2 <<std::endl;
             return EXIT_FAILURE;
             }
     
-          if((*j).GetAlpha()!=value+3)
+          if((*pit).GetAlpha()!=value+3)
             {
-            std::cout<<" [FAILED] : Alpha : found " << ( *j).GetAlpha() << " instead of " << value+3 <<std::endl;
+            std::cout<<" [FAILED] : Alpha : found " << ( *pit).GetAlpha() << " instead of " << value+3 <<std::endl;
             return EXIT_FAILURE;
             }
           }
@@ -884,17 +939,17 @@ int itkReadWriteSpatialObjectTest(int argc, char* argv[])
 
   for(obj = mySceneChildren->begin(); obj != mySceneChildren->end(); obj++)
     {
-    LandmarkType::PointListType::const_iterator j;
+    LandmarkType::PointListType::const_iterator pit;
     if(!strcmp((*obj)->GetTypeName(),"LandmarkSpatialObject"))
       {
       unsigned int value = 0;
-      for(j = dynamic_cast<LandmarkType*>((*obj).GetPointer())->GetPoints().begin(); 
-          j != dynamic_cast<LandmarkType*>((*obj).GetPointer())->GetPoints().end(); 
-          j++)
+      for(pit = dynamic_cast<LandmarkType*>((*obj).GetPointer())->GetPoints().begin(); 
+          pit != dynamic_cast<LandmarkType*>((*obj).GetPointer())->GetPoints().end(); 
+          pit++)
         {
         for(unsigned int d=0;d<3;d++)
           {
-          if((*j).GetPosition()[d]!=value)
+          if((*pit).GetPosition()[d]!=value)
             {
             std::cout<<" [FAILED]"<<std::endl;
             return EXIT_FAILURE;
