@@ -3,8 +3,8 @@
   Program:   DICOMParser
   Module:    $RCSfile: DICOMAppHelper.h,v $
   Language:  C++
-  Date:      $Date: 2005/05/06 18:53:40 $
-  Version:   $Revision: 1.28 $
+  Date:      $Date: 2007-08-20 14:01:50 $
+  Version:   $Revision: 1.30 $
 
   Copyright (c) 2003 Matt Turek
   All rights reserved.
@@ -38,6 +38,7 @@ class DICOMParser;
 // Function object for sorting strings
 struct ltstdstr
 {
+  ltstdstr() {}
   bool operator()(const dicom_stl::string s1, const dicom_stl::string s2) const
   {
     return s1 < s2;
@@ -63,16 +64,16 @@ public:
     {
       // Default values to something "valid"
       SliceNumber = -1;
-      SliceLocation = 0.0;
-      ImagePositionPatient[0] = 0.0;
-      ImagePositionPatient[1] = 0.0;
-      ImagePositionPatient[2] = 0.0;
-      ImageOrientationPatient[0] = 1.0;
-      ImageOrientationPatient[1] = 0.0;
-      ImageOrientationPatient[2] = 0.0;
-      ImageOrientationPatient[3] = 0.0;
-      ImageOrientationPatient[4] = 1.0;
-      ImageOrientationPatient[5] = 0.0;
+      SliceLocation = 0.0f;
+      ImagePositionPatient[0] = 0.0f;
+      ImagePositionPatient[1] = 0.0f;
+      ImagePositionPatient[2] = 0.0f;
+      ImageOrientationPatient[0] = 1.0f;
+      ImageOrientationPatient[1] = 0.0f;
+      ImageOrientationPatient[2] = 0.0f;
+      ImageOrientationPatient[3] = 0.0f;
+      ImageOrientationPatient[4] = 1.0f;
+      ImageOrientationPatient[5] = 0.0f;
     }
       
   int SliceNumber;
