@@ -3,8 +3,8 @@
   Program:   MetaIO
   Module:    $RCSfile: metaForm.cxx,v $
   Language:  C++
-  Date:      $Date: 2006/10/27 22:12:43 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2008-04-09 01:44:28 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,6 +21,10 @@
 #include <string.h>
 #include <math.h>
 
+#if defined (__BORLANDC__) && (__BORLANDC__ >= 0x0580)
+#include <mem.h>
+#endif
+
 #if (METAIO_USE_NAMESPACE)
 namespace METAIO_NAMESPACE {
 #endif
@@ -614,10 +618,14 @@ Read(const char *_fileName)
     }
 
   METAIO_STREAM::ifstream * tmpReadStream = new METAIO_STREAM::ifstream;
+#ifdef __sgi
+  tmpReadStream->open(m_FileName, METAIO_STREAM::ios::in);
+#else
   tmpReadStream->open(m_FileName, METAIO_STREAM::ios::binary |
                                   METAIO_STREAM::ios::in);
+#endif
 
-  if(!tmpReadStream->is_open())
+  if(!tmpReadStream->rdbuf()->is_open())
     {
     METAIO_STREAM::cout << "MetaForm: Read: Cannot open file" 
                         << METAIO_STREAM::endl;
@@ -700,11 +708,13 @@ Write(const char *_fileName)
   METAIO_STREAM::ofstream tFile(m_FileName, METAIO_STREAM::ios::out);
   tFile.close();                    
   }
-#endif
-
+  tmpWriteStream->open(_fileName, METAIO_STREAM::ios::out);
+#else
   tmpWriteStream->open(_fileName, METAIO_STREAM::ios::binary |
                                   METAIO_STREAM::ios::out);
-  if(!tmpWriteStream->is_open())
+#endif
+
+  if(!tmpWriteStream->rdbuf()->is_open())
     {
     delete tmpWriteStream;
     return false;
