@@ -3,8 +3,8 @@
   Program:   MetaIO
   Module:    $RCSfile: metaObject.cxx,v $
   Language:  C++
-  Date:      $Date: 2006/10/27 12:25:53 $
-  Version:   $Revision: 1.48 $
+  Date:      $Date: 2008-04-09 09:54:25 $
+  Version:   $Revision: 1.52 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,6 +21,10 @@
 #include <string.h>
 #include <math.h>
 
+#if defined (__BORLANDC__) && (__BORLANDC__ >= 0x0580)
+#include <mem.h>
+#endif
+
 #if (METAIO_USE_NAMESPACE)
 namespace METAIO_NAMESPACE {
 #endif
@@ -231,6 +235,7 @@ CopyInfo(const MetaObject * _object)
   ID(_object->ID());
   Color(_object->Color());
   ParentID(_object->ParentID());
+  AcquisitionDate(_object->AcquisitionDate());
   Name(_object->Name());
   BinaryData(_object->BinaryData());
   BinaryDataByteOrderMSB(_object->BinaryDataByteOrderMSB());
@@ -252,10 +257,14 @@ Read(const char *_fileName)
 
   METAIO_STREAM::ifstream * tmpReadStream = new METAIO_STREAM::ifstream;
 
+#ifdef __sgi
+  tmpReadStream->open(m_FileName, METAIO_STREAM::ios::in);
+#else
   tmpReadStream->open(m_FileName, METAIO_STREAM::ios::binary |
                                   METAIO_STREAM::ios::in);
+#endif
 
-  if(!tmpReadStream->is_open())
+  if(!tmpReadStream->rdbuf()->is_open())
     {
     delete tmpReadStream;
     return false;
@@ -331,13 +340,15 @@ Write(const char *_fileName)
  
 #ifdef __sgi
   // Create the file. This is required on some older sgi's
-  METAIO_STREAM::ofstream tFile(m_FileName,METAIO_STREAM::ios::out);
+  METAIO_STREAM::ofstream tFile(m_FileName, METAIO_STREAM::ios::out);
   tFile.close();                    
-#endif
-
+  m_WriteStream->open(m_FileName, METAIO_STREAM::ios::out);
+#else
   m_WriteStream->open(m_FileName, METAIO_STREAM::ios::binary |
                                   METAIO_STREAM::ios::out);
-  if(!m_WriteStream->is_open())
+#endif
+
+  if(!m_WriteStream->rdbuf()->is_open())
     {
     return false;
     }
@@ -370,6 +381,7 @@ PrintInfo(void) const
   METAIO_STREAM::cout << "Name = " << m_Name << METAIO_STREAM::endl;
   METAIO_STREAM::cout << "ID = " << m_ID << METAIO_STREAM::endl;
   METAIO_STREAM::cout << "ParentID = " << m_ParentID << METAIO_STREAM::endl;
+  METAIO_STREAM::cout << "AcquisitionDate = " << m_AcquisitionDate << METAIO_STREAM::endl;
   if(m_CompressedData)
     {
     METAIO_STREAM::cout << "CompressedData = True" << METAIO_STREAM::endl;
@@ -968,6 +980,20 @@ int   MetaObject::ParentID(void) const
   return m_ParentID;
   }
 
+void  MetaObject::
+AcquisitionDate(const char * _acquisitionDate)
+  {
+  for(size_t i=0; i<strlen( _acquisitionDate ); i++)
+    {
+    m_AcquisitionDate[i] = _acquisitionDate[i];
+    }
+  }
+      
+const char * MetaObject::AcquisitionDate(void) const
+  {
+  return m_AcquisitionDate;
+  }
+
 void MetaObject::CompressedData(bool _compressedData)
   {
   m_CompressedData = _compressedData;
@@ -1023,6 +1049,7 @@ Clear(void)
   m_Color[2]=1.0;
   m_Color[3]=1.0; // white by default
   m_ParentID = -1;
+  strcpy(m_AcquisitionDate, "");
   m_BinaryData = false;
   m_BinaryDataByteOrderMSB = MET_SystemByteOrderMSB();
   m_CompressedDataSize = 0;
@@ -1116,7 +1143,7 @@ M_SetupReadFields(void)
   MET_InitReadField(mF, "Comment", MET_STRING, false);
   m_Fields.push_back(mF);
 
-  mF = new MET_FieldRecordType;  // Set but not used
+  mF = new MET_FieldRecordType; 
   MET_InitReadField(mF, "AcquisitionDate", MET_STRING, false);
   m_Fields.push_back(mF);
 
@@ -1147,6 +1174,10 @@ M_SetupReadFields(void)
   MET_InitReadField(mF, "ParentID", MET_INT, false);
   m_Fields.push_back(mF);
  
+  mF = new MET_FieldRecordType; 
+  MET_InitReadField(mF, "AcquisitionDate", MET_STRING, false);
+  m_Fields.push_back(mF);
+
   mF = new MET_FieldRecordType;
   MET_InitReadField(mF, "CompressedData", MET_STRING, false);
   m_Fields.push_back(mF);
@@ -1298,6 +1329,13 @@ M_SetupWriteFields(void)
     m_Fields.push_back(mF);
     }
 
+  if(strlen(m_AcquisitionDate) > 0)
+    {
+    mF = new MET_FieldRecordType;
+    MET_InitWriteField(mF, "AcquisitionDate", MET_STRING,
+                       strlen(m_AcquisitionDate), m_AcquisitionDate);
+    }
+
   bool valSet = false;
   int i;
   for(i=0; i<4; i++)
@@ -1489,6 +1527,15 @@ M_Read(void)
     m_ParentID = (int)mF->value[0];
     }
 
+  mF = MET_GetFieldRecord("AcquisitionDate", &m_Fields);
+  if(mF && mF->defined)
+    {
+    for(size_t i=0; i<strlen((char *)mF->value); i++)
+      {
+      m_AcquisitionDate[i] = ((char *)mF->value)[i];
+      }
+    }
+
   mF = MET_GetFieldRecord("CompressedData",  &m_Fields);
   if(mF && mF->defined)
     {
@@ -1737,25 +1784,26 @@ bool MetaObject
     m_WriteStream = new METAIO_STREAM::ofstream;
     }
 
-#ifndef __sgi
-  m_WriteStream->open(m_FileName,
-                      METAIO_STREAM::ios::binary | METAIO_STREAM::ios::out | METAIO_STREAM::ios::app);
-  if(!m_WriteStream->is_open())
-    {
-    delete m_WriteStream;
-    m_WriteStream = 0;
-    return false;
-    }
-#else
-  m_WriteStream->open(m_FileName,
-                      METAIO_STREAM::ios::binary | METAIO_STREAM::ios::out | METAIO_STREAM::ios::in);
-  if(!m_WriteStream->is_open())
+#ifdef __sgi
+  m_WriteStream->open(m_FileName, METAIO_STREAM::ios::out 
+                                  | METAIO_STREAM::ios::in);
+  if(!m_WriteStream->rdbuf()->is_open())
     {
     delete m_WriteStream;
     m_WriteStream = 0;
     return false;
     }
   m_WriteStream->seekp(0,METAIO_STREAM::ios::end);
+#else
+  m_WriteStream->open(m_FileName, METAIO_STREAM::ios::binary 
+                                  | METAIO_STREAM::ios::out 
+                                  | METAIO_STREAM::ios::app);
+  if(!m_WriteStream->rdbuf()->is_open())
+    {
+    delete m_WriteStream;
+    m_WriteStream = 0;
+    return false;
+    }
 #endif
 
   M_Write();
@@ -1830,7 +1878,7 @@ void MetaObject::M_PrepareNewReadStream()
 {
   if(m_ReadStream)
     {
-    if(m_ReadStream->is_open())
+    if(m_ReadStream->rdbuf()->is_open())
       {
       m_ReadStream->close();
       }
