@@ -3,17 +3,21 @@
   Program:   MetaIO
   Module:    $RCSfile: metaUtils.cxx,v $
   Language:  C++
-  Date:      $Date: 2006/11/02 20:36:53 $
-  Version:   $Revision: 1.35 $
+  Date:      $Date: 2008-04-09 17:44:27 $
+  Version:   $Revision: 1.54 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
+#ifdef _MSC_VER
+#pragma warning(disable:4702)
+#endif
+
 #include "metaUtils.h"
 
 #include <stdio.h>
@@ -22,14 +26,21 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 
-#ifndef _WIN32
+#if defined(_WIN32) && !defined(__CYGWIN__)
+#include <winsock2.h>
+#else
 #include <unistd.h>
 #include <arpa/inet.h>
 #endif
 
 #include <stdlib.h>
+#include <string.h>
 #include <string>
 
+#if defined (__BORLANDC__) && (__BORLANDC__ >= 0x0580)
+#include <mem.h>
+#endif
+
 #if (METAIO_USE_NAMESPACE)
 namespace METAIO_NAMESPACE {
 #endif
@@ -38,7 +49,7 @@ int META_DEBUG = 0;
 
 char MET_SeperatorChar = '=';
 
-MET_FieldRecordType * 
+MET_FieldRecordType *
 MET_GetFieldRecord(const char * _fieldName,
                    METAIO_STL::vector<MET_FieldRecordType *> * _fields)
   {
@@ -130,7 +141,7 @@ METAIO_STL::string MET_ReadForm(METAIO_STREAM::istream &_fp)
     delete mF;
     return value;
     }
-    
+
   value[0] = '\0';
   delete mF;
   return value;
@@ -160,7 +171,7 @@ METAIO_STL::string MET_ReadType(METAIO_STREAM::istream &_fp)
     delete mF;
     return value;
     }
-    
+
   value[0] = '\0';
   delete mF;
   return value;
@@ -173,7 +184,7 @@ char* MET_ReadSubType(METAIO_STREAM::istream &_fp)
   {
   unsigned int pos = _fp.tellg();
   METAIO_STL::vector<MET_FieldRecordType *> fields;
-  MET_FieldRecordType* mF;  
+  MET_FieldRecordType* mF;
   mF = new MET_FieldRecordType;
   MET_InitReadField(mF, "ObjectType", MET_STRING, false);
   mF->required = false;
@@ -185,8 +196,8 @@ char* MET_ReadSubType(METAIO_STREAM::istream &_fp)
   char s[1024];
   _fp.getline( s, 500 );
   METAIO_STL::string value = s;
-  int position = value.find("=");
-  if(position!=-1)
+  size_t position = value.find("=");
+  if(position!=METAIO_STL::string::npos)
     {
     value = value.substr(position+2,value.size()-position);
     }
@@ -214,8 +225,8 @@ bool MET_StringToType(const char *_s, MET_ValueEnumType *_vType)
       return true;
       }
     }
-    
-  *_vType = MET_OTHER;  
+
+  *_vType = MET_OTHER;
   return false;
   }
 
@@ -226,10 +237,10 @@ bool MET_TypeToString(MET_ValueEnumType _vType, char *_s)
   {
   if(_vType>=0 && _vType<=MET_NUM_VALUE_TYPES)
     {
-    sprintf(_s, MET_ValueTypeName[_vType]);
+    strcpy(_s, MET_ValueTypeName[_vType]);
     return true;
     }
-  
+
   return false;
   }
 
@@ -238,7 +249,8 @@ bool MET_TypeToString(MET_ValueEnumType _vType, char *_s)
 //
 // Value to Double
 //
-bool MET_ValueToDouble(MET_ValueEnumType _type, const void *_data, int _index,
+bool MET_ValueToDouble(MET_ValueEnumType _type, const void *_data, 
+                       METAIO_STL::streamsize _index,
                        double *_value)
   {
   switch(_type)
@@ -282,8 +294,10 @@ bool MET_ValueToDouble(MET_ValueEnumType _type, const void *_data, int _index,
       return true;
     case MET_ULONG_LONG:
     case MET_ULONG_LONG_ARRAY:
-#if defined(_MSC_VER) // NOTE: you cannot use __int64 in an ostream in MSV6
-      *_value = (double)((MET_LONG_LONG_TYPE)((((const MET_ULONG_LONG_TYPE *)_data)[_index])));
+#if defined(_MSC_VER) || defined(__HP_aCC)
+      // NOTE: you cannot use __int64 in an ostream in MSV6 or HPUX
+      *_value = (double)((MET_LONG_LONG_TYPE)
+                         ((((const MET_ULONG_LONG_TYPE *)_data)[_index])));
 #else
       *_value = (double)((((const MET_ULONG_LONG_TYPE *)_data)[_index]));
 #endif
@@ -306,7 +320,10 @@ bool MET_ValueToDouble(MET_ValueEnumType _type, const void *_data, int _index,
     }
   }
 
-bool MET_DoubleToValue(double _value, MET_ValueEnumType _type, void *_data, int _index)
+bool MET_DoubleToValue(double _value,
+                       MET_ValueEnumType _type,
+                       void *_data,
+                       METAIO_STL::streamsize _index)
   {
   switch(_type)
     {
@@ -369,7 +386,7 @@ bool MET_DoubleToValue(double _value, MET_ValueEnumType _type, void *_data, int
   }
 
 bool MET_ValueToValue(MET_ValueEnumType _fromType, const void *_fromData,
-                      int _index,
+                      METAIO_STL::streamsize _index,
                       MET_ValueEnumType _toType, void *_toData,
                       double _fromMin, double _fromMax,
                       double _toMin, double _toMax)
@@ -448,11 +465,213 @@ bool MET_ValueToValue(MET_ValueEnumType _fromType, const void *_fromData,
     }
   }
 
+// Uncompress a stream given an uncompressedSeekPosition
+METAIO_EXPORT
+long MET_UncompressStream(METAIO_STREAM::ifstream * stream,
+                          METAIO_STL::streamsize uncompressedSeekPosition,
+                          unsigned char * uncompressedData,
+                          METAIO_STL::streamsize uncompressedDataSize,
+                          METAIO_STL::streamsize compressedDataSize,
+                          MET_CompressionTableType * compressionTable
+                          )
+{
+  // Keep the currentpos of the string
+  METAIO_STL::streamsize currentPos = stream->tellg();
+  if(currentPos == -1)
+    {
+    METAIO_STREAM::cout << "MET_UncompressStream: ERROR Stream is not valid!" << METAIO_STREAM::endl;
+    return -1;
+    }
+
+  long read = 0;
+
+  //METAIO_STREAM::cout << "Wanted Seek = " << uncompressedSeekPosition << METAIO_STREAM::endl;
+  //METAIO_STREAM::cout << "Wanted size = " << uncompressedDataSize << METAIO_STREAM::endl;
+
+  // Size of the output buffer
+  unsigned long buffersize = 1000;
+
+  // We try to guess the compression rate
+  // Note that sometime the size of the input buffer
+  // has to be bigger than the output buffer (bad compression)
+  // We assume that they are equal
+  double compressionRate = 1;
+
+  long zseekpos = 0;
+  long seekpos = 0;
+  bool firstchunk = true;
+
+  // Allocate the stream if necessary
+  z_stream* d_stream = compressionTable->compressedStream;
+  if(compressionTable->compressedStream == NULL)
+    {
+    d_stream = new z_stream;
+    d_stream->zalloc = (alloc_func)0;
+    d_stream->zfree = (free_func)0;
+    d_stream->opaque = (voidpf)0;
+    inflateInit(d_stream);
+    compressionTable->compressedStream = d_stream;
+    compressionTable->buffer = new char[1001];
+    compressionTable->bufferSize = 0;
+    }
+
+
+  // Try to find the current seek position in the compressed
+  // and uncompressed stream from the compressionTable
+  // The table is stored in order
+  if(compressionTable->offsetList.size()>0)
+    {
+    MET_CompressionOffsetListType::const_iterator it = compressionTable->offsetList.end();
+    it--;
+
+    if(uncompressedSeekPosition < (*it).uncompressedOffset)
+      {
+      if((*it).uncompressedOffset-uncompressedSeekPosition > compressionTable->bufferSize)
+        {
+        METAIO_STREAM::cout << "ERROR: Cannot go backward by more than the buffer size (1000)"
+                  << METAIO_STREAM::endl;
+        return 0;
+        }
+
+      char* buffer = compressionTable->buffer;
+      unsigned long start = uncompressedSeekPosition-((*it).uncompressedOffset-compressionTable->bufferSize);
+      buffer += start;
+
+      unsigned long readSize = uncompressedDataSize;
+      unsigned long sizeInBuffer = compressionTable->bufferSize-start;
+      if(readSize>sizeInBuffer)
+        {
+        memcpy(uncompressedData,buffer,sizeInBuffer);
+        uncompressedData += sizeInBuffer;
+        zseekpos = (*it).compressedOffset;
+        seekpos = (*it).uncompressedOffset;
+        uncompressedSeekPosition += sizeInBuffer;
+        uncompressedDataSize -= sizeInBuffer;
+        }
+      else // read from buffer and return
+        {
+        memcpy(uncompressedData,buffer,readSize);
+        return uncompressedDataSize;
+        }
+      }
+    else
+      {
+      zseekpos = (*it).compressedOffset;
+      seekpos = (*it).uncompressedOffset;
+      }
+    }
+
+  //METAIO_STREAM::cout << "Using = " << seekpos << " : " << zseekpos << METAIO_STREAM::endl;
+
+  while(seekpos < (long)uncompressedSeekPosition+uncompressedDataSize)
+    {
+    // If we are reading the current buffer we read everything
+    if(seekpos >= (long)uncompressedSeekPosition)
+      {
+      buffersize = uncompressedSeekPosition+uncompressedDataSize-seekpos;
+      firstchunk = false;
+      }
+
+    unsigned char* outdata = new unsigned char[buffersize];
+
+    d_stream->avail_out = buffersize;
+
+    // How many byte from compressed streamed should we read
+    unsigned long inputBufferSize = (unsigned long)(buffersize/compressionRate);
+    if(inputBufferSize == 0)
+      {
+      inputBufferSize = 1;
+      }
+    if((long)(currentPos+zseekpos+inputBufferSize) > compressedDataSize)
+      {
+      inputBufferSize = compressedDataSize-zseekpos;
+      }
+
+    unsigned char* inputBuffer = new unsigned char[inputBufferSize];
+    stream->seekg(currentPos+zseekpos,METAIO_STREAM::ios::beg);
+    stream->read((char *)inputBuffer, inputBufferSize);
+
+    d_stream->next_in  = inputBuffer;
+    d_stream->avail_in = stream->gcount();
+    d_stream->next_out = outdata;
+
+    inflate(d_stream, Z_NO_FLUSH);
+
+    unsigned long previousSeekpos = seekpos;
+
+    seekpos += buffersize-d_stream->avail_out;
+    zseekpos += stream->gcount()-d_stream->avail_in;
+
+    // Store the last buffer into memory in case we need it
+    // in the near future.
+    long previousBufferSize = seekpos-previousSeekpos;
+    if(previousBufferSize>1000)
+      {
+      // WARNING: We probably need to offset outdata at some point...
+      previousBufferSize = 1000;
+      }
+
+    memcpy(compressionTable->buffer,outdata,previousBufferSize);
+    compressionTable->bufferSize = previousBufferSize;
+
+    //METAIO_STREAM::cout << "Current pos = " << seekpos << " : " << zseekpos << METAIO_STREAM::endl;
+
+    // If go further than the uncompressedSeekPosition we start writing the stream
+    if(seekpos >= (long)uncompressedSeekPosition)
+      {
+      if(firstchunk)
+        {
+        outdata += uncompressedSeekPosition-previousSeekpos;
+        METAIO_STL::streamsize writeSize = seekpos-uncompressedSeekPosition;
+
+        if(writeSize > uncompressedDataSize)
+          {
+          writeSize = uncompressedDataSize;
+          }
+
+        memcpy(uncompressedData,outdata,writeSize);
+
+        // Restore the position of the buffer
+        outdata -= uncompressedSeekPosition-previousSeekpos;
+
+        uncompressedData += writeSize;
+        read += writeSize;
+
+        firstchunk = false;
+        }
+      else // read everything
+        {
+        METAIO_STL::streamsize writeSize = seekpos-previousSeekpos;
+        memcpy(uncompressedData,outdata,writeSize);
+        if(writeSize > uncompressedDataSize)
+          {
+          writeSize = uncompressedDataSize;
+          }
+        uncompressedData += writeSize;
+        read += writeSize;
+        }
+      }
+    delete [] outdata;
+    delete [] inputBuffer;
+    }
+
+  // Save the state of the compression for later use
+  MET_CompressionOffsetType offset;
+  offset.compressedOffset = zseekpos; // compressed
+  offset.uncompressedOffset = seekpos; // uncompressed
+  compressionTable->offsetList.push_back(offset);
+
+  // Seek to the current position
+  stream->seekg(currentPos,METAIO_STREAM::ios::beg);
+  return read;
+}
+
+
 //
 //
 //
 unsigned char * MET_PerformCompression(const unsigned char * source,
-                                       int sourceSize,
+                                       METAIO_STL::streamsize sourceSize,
                                        unsigned int * compressedDataSize)
   {
   unsigned char * compressedData;
@@ -466,7 +685,7 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
   // Choices are Z_BEST_SPEED,Z_BEST_COMPRESSION,Z_DEFAULT_COMPRESSION
   int compression_rate = Z_DEFAULT_COMPRESSION;
 
-  int             buffer_size     = sourceSize;
+  METAIO_STL::streamsize             buffer_size     = sourceSize;
   unsigned char * input_buffer    = const_cast<unsigned char *>(source);
   unsigned char * output_buffer   = new unsigned char[buffer_size];
 
@@ -478,17 +697,17 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
   z.next_in    = input_buffer;
   z.next_out   = output_buffer;
   z.avail_out  = buffer_size;
-   
-  int count;
-  unsigned long j=0;
-  // Perform the compression 
-  for ( ; ; ) 
+
+  METAIO_STL::streamsize count;
+  METAIO_STL::streamsize j=0;
+  // Perform the compression
+  for ( ; ; )
     {
-    if ( z.avail_in == 0 ) 
+    if ( z.avail_in == 0 )
       {
       deflate( &z, Z_FINISH );
       count = buffer_size - z.avail_out;
-      if ( count ) 
+      if ( count )
         {
         memcpy((char*)compressedData+j, (char *)output_buffer, count);
         }
@@ -497,7 +716,7 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
 
     deflate( &z, Z_NO_FLUSH );
     count = buffer_size - z.avail_out;
-    if ( count ) 
+    if ( count )
       {
       memcpy((char*)compressedData+j, (char*)output_buffer, count);
       }
@@ -506,8 +725,8 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
     z.next_out = output_buffer;
     z.avail_out = buffer_size;
     }
-    
-  delete output_buffer;
+
+  delete [] output_buffer;
 
   *compressedDataSize = z.total_out;
 
@@ -521,23 +740,23 @@ unsigned char * MET_PerformCompression(const unsigned char * source,
 //
 //
 bool MET_PerformUncompression(const unsigned char * sourceCompressed,
-                              int sourceCompressedSize,
+                              METAIO_STL::streamsize sourceCompressedSize,
                               unsigned char * uncompressedData,
-                              int uncompressedDataSize)
+                              METAIO_STL::streamsize uncompressedDataSize)
   {
   z_stream d_stream;
- 
+
   d_stream.zalloc = (alloc_func)0;
   d_stream.zfree = (free_func)0;
   d_stream.opaque = (voidpf)0;
-  
+
   inflateInit(&d_stream);
   d_stream.next_in  = const_cast<unsigned char *>(sourceCompressed);
   d_stream.avail_in = sourceCompressedSize;
- 
-  for (;;) 
+
+  for (;;)
     {
-    d_stream.next_out = (unsigned char *)uncompressedData; 
+    d_stream.next_out = (unsigned char *)uncompressedData;
     d_stream.avail_out = uncompressedDataSize;
     int err = inflate(&d_stream, Z_NO_FLUSH);
     if((err == Z_STREAM_END))
@@ -563,7 +782,7 @@ bool MET_StringToWordArray(const char *s, int *n, char ***val)
     {
     p++;
     }
-  
+
   *n = 0;
   int pp = p;
   bool space = false;
@@ -581,7 +800,7 @@ bool MET_StringToWordArray(const char *s, int *n, char ***val)
     pp++;
     }
   pp=l-1;
-  if(s[pp] == ' ')   
+  if(s[pp] == ' ')
     {
     while(pp>=0 && s[pp] == ' ')
       {
@@ -593,17 +812,17 @@ bool MET_StringToWordArray(const char *s, int *n, char ***val)
     {
     (*n)++;
     }
-  
+
   *val = new char *[*n];
-  
+
   long i, j;
-  for(i=0; i<*n; i++) 
+  for(i=0; i<*n; i++)
     {
     if(p == l)
       {
       return false;
       }
-    
+
     (*val)[i] = new char [80];
     while(p<l && s[p] == ' ')
       {
@@ -616,7 +835,7 @@ bool MET_StringToWordArray(const char *s, int *n, char ***val)
       }
     (*val)[i][j] = '\0';
     }
-  
+
   return true;
 }
 
@@ -626,13 +845,13 @@ bool MET_StringToWordArray(const char *s, int *n, char ***val)
 bool MET_GetFilePath(const char *_fName, char *_fPath)
   {
   long i;
-  
+
   long l = static_cast<long>( strlen(_fName) );
-  
+
   for(i=l-1; i>=0; i--)
     if(_fName[i] == '\\' || _fName[i] == '/')
       break;
-    
+
     if(i >= 0 && (_fName[i] == '/' || _fName[i] == '\\'))
       {
       strcpy(_fPath, _fName);
@@ -698,9 +917,9 @@ bool MET_SetFileSuffix(char *_fName, const char *_suf)
 //
 //
 //
-bool MET_InitWriteField(MET_FieldRecordType * _mf, 
-                        const char *_name, 
-                        MET_ValueEnumType _type, 
+bool MET_InitWriteField(MET_FieldRecordType * _mf,
+                        const char *_name,
+                        MET_ValueEnumType _type,
                         double _v)
   {
   strcpy(_mf->name, _name);
@@ -714,12 +933,12 @@ bool MET_InitWriteField(MET_FieldRecordType * _mf,
   return true;
   }
 
-bool MET_InitReadField(MET_FieldRecordType * _mf, 
-                                  const char *_name, 
-                                  MET_ValueEnumType _type, 
+bool MET_InitReadField(MET_FieldRecordType * _mf,
+                                  const char *_name,
+                                  MET_ValueEnumType _type,
                                   bool _required,
-                                  int _dependsOn, 
-                                  int _length)
+                                  int _dependsOn,
+                                  size_t _length)
   {
   strcpy(_mf->name, _name);
   _mf->type = _type;
@@ -742,7 +961,7 @@ bool MET_SkipToVal(METAIO_STREAM::istream &fp)
     {
     return false;
     }
-  
+
   c = fp.get();
 
   while( c != MET_SeperatorChar && c != ':' && !fp.eof() )
@@ -754,13 +973,14 @@ bool MET_SkipToVal(METAIO_STREAM::istream &fp)
     {
     c = fp.get();
     }
-  
+
   if( fp.eof() )
     {
-    METAIO_STREAM::cerr << "Incomplete file record definition" << METAIO_STREAM::endl;
+    METAIO_STREAM::cerr << "Incomplete file record definition"
+                        << METAIO_STREAM::endl;
     return false;
     }
-  
+
   fp.putback(c);
 
   return true;
@@ -776,7 +996,7 @@ bool MET_IsComplete(METAIO_STL::vector<MET_FieldRecordType *> * fields)
     {
     if((*fieldIter)->required && !(*fieldIter)->defined)
       {
-      METAIO_STREAM::cerr << (*fieldIter)->name << " required and not defined." 
+      METAIO_STREAM::cerr << (*fieldIter)->name << " required and not defined."
                 << METAIO_STREAM::endl;
       return false;
       }
@@ -785,7 +1005,8 @@ bool MET_IsComplete(METAIO_STL::vector<MET_FieldRecordType *> * fields)
   }
 
 //
-bool MET_Read(METAIO_STREAM::istream &fp, METAIO_STL::vector<MET_FieldRecordType *> * fields,
+bool MET_Read(METAIO_STREAM::istream &fp,
+              METAIO_STL::vector<MET_FieldRecordType *> * fields,
               char _MET_SeperatorChar, bool oneLine, bool display_warnings)
   {
 
@@ -793,11 +1014,11 @@ bool MET_Read(METAIO_STREAM::istream &fp, METAIO_STL::vector<MET_FieldRecordType
   int i, j;
 
   METAIO_STL::vector<MET_FieldRecordType *>::iterator fieldIter;
-  
+
   MET_SeperatorChar = _MET_SeperatorChar;
-  
+
   bool found;
-  
+
   unsigned char c;
   while(!fp.eof())
     {
@@ -819,7 +1040,7 @@ bool MET_Read(METAIO_STREAM::istream &fp, METAIO_STL::vector<MET_FieldRecordType
       }
     fp.putback(c);
     s[i] = '\0';
-    
+
     i--;
     while((s[i] == ' ' || s[i] == '\t') && i>0)
       {
@@ -834,8 +1055,10 @@ bool MET_Read(METAIO_STREAM::istream &fp, METAIO_STL::vector<MET_FieldRecordType
         if((*fieldIter)->dependsOn >= 0)
           if(!(*fields)[(*fieldIter)->dependsOn]->defined)
             {
-            METAIO_STREAM::cerr << (*fieldIter)->name << " defined prior to defining ";
-            METAIO_STREAM::cerr << (*fields)[(*fieldIter)->dependsOn]->name << METAIO_STREAM::endl;
+            METAIO_STREAM::cerr << (*fieldIter)->name
+                                << " defined prior to defining ";
+            METAIO_STREAM::cerr << (*fields)[(*fieldIter)->dependsOn]->name
+                                << METAIO_STREAM::endl;
             return false;
             }
         switch((*fieldIter)->type)
@@ -850,7 +1073,6 @@ bool MET_Read(METAIO_STREAM::istream &fp, METAIO_STL::vector<MET_FieldRecordType
               {
               break;
               }
-            MET_CHAR_TYPE c = fp.get();
             c = fp.get();
             (*fieldIter)->value[0] = (double)c;
             fp.getline( s, 500 );
@@ -918,7 +1140,7 @@ bool MET_Read(METAIO_STREAM::istream &fp, METAIO_STL::vector<MET_FieldRecordType
               {
               (*fieldIter)->length =
                     (int)((*fields)[(*fieldIter)->dependsOn]->value[0]);
-              for(j=0; j<(*fieldIter)->length; j++) 
+              for(j=0; j<(*fieldIter)->length; j++)
                 {
                 fp >> (*fieldIter)->value[j];
                 }
@@ -927,7 +1149,7 @@ bool MET_Read(METAIO_STREAM::istream &fp, METAIO_STL::vector<MET_FieldRecordType
               {
               if((*fieldIter)->length <= 0)
                 {
-                METAIO_STREAM::cerr << 
+                METAIO_STREAM::cerr <<
                   "Arrays must have dependency or pre-specified lengths"
                   << METAIO_STREAM::endl;
                 return false;
@@ -952,7 +1174,7 @@ bool MET_Read(METAIO_STREAM::istream &fp, METAIO_STL::vector<MET_FieldRecordType
               (*fieldIter)->length =
                     (int)((*fields)[(*fieldIter)->dependsOn]->value[0]);
               for(j=0; j<(*fieldIter)->length*(*fieldIter)->length;
-                  j++) 
+                  j++)
                 {
                 fp >> (*fieldIter)->value[j];
                 }
@@ -961,7 +1183,7 @@ bool MET_Read(METAIO_STREAM::istream &fp, METAIO_STL::vector<MET_FieldRecordType
               {
               if((*fieldIter)->length <= 0)
                 {
-                METAIO_STREAM::cerr << 
+                METAIO_STREAM::cerr <<
                   "Arrays must have dependency or pre-specified lengths"
                   << METAIO_STREAM::endl;
                 return false;
@@ -993,7 +1215,8 @@ bool MET_Read(METAIO_STREAM::istream &fp, METAIO_STL::vector<MET_FieldRecordType
       {
       if(display_warnings)
         {
-        METAIO_STREAM::cerr << "Skipping unrecognized field " << s << METAIO_STREAM::endl;
+        METAIO_STREAM::cerr << "Skipping unrecognized field "
+                            << s << METAIO_STREAM::endl;
         }
       fp.getline( s, 500 );
       }
@@ -1002,16 +1225,17 @@ bool MET_Read(METAIO_STREAM::istream &fp, METAIO_STL::vector<MET_FieldRecordType
       return MET_IsComplete(fields);
       }
     }
-    
+
   return MET_IsComplete(fields);
   }
-  
+
 //
-bool MET_Write(METAIO_STREAM::ostream &fp, METAIO_STL::vector<MET_FieldRecordType *> * fields,
+bool MET_Write(METAIO_STREAM::ostream &fp,
+               METAIO_STL::vector<MET_FieldRecordType *> * fields,
                char _MET_SeperatorChar)
   {
   MET_SeperatorChar = _MET_SeperatorChar;
-  
+
   int j;
   METAIO_STL::vector<MET_FieldRecordType *>::iterator fieldIter;
   for(fieldIter=fields->begin(); fieldIter!=fields->end(); fieldIter++)
@@ -1020,7 +1244,7 @@ bool MET_Write(METAIO_STREAM::ostream &fp, METAIO_STL::vector<MET_FieldRecordTyp
       {
       case MET_NONE:
         {
-        fp << (*fieldIter)->name << " " << MET_SeperatorChar << " " 
+        fp << (*fieldIter)->name << " " << MET_SeperatorChar << " "
            << METAIO_STREAM::endl;
         break;
         }
@@ -1041,15 +1265,18 @@ bool MET_Write(METAIO_STREAM::ostream &fp, METAIO_STL::vector<MET_FieldRecordTyp
         }
       case MET_LONG_LONG:
         {
-#if defined(_MSC_VER) // NOTE: you cannot use __int64 in an ostream in MSV6
-        fp << (double)((MET_LONG_LONG_TYPE)((*fieldIter)->value[0])) 
+#if defined(_MSC_VER) || defined(__HP_aCC)
+        // NOTE: you cannot use __int64 in an ostream in MSV6 or HPUX
+        fp << (double)((MET_LONG_LONG_TYPE)((*fieldIter)->value[0]))
            << METAIO_STREAM::endl;
-        METAIO_STREAM::cerr << "Programs compiled using MSV6 cannot write 64 bit ints"
-                  << METAIO_STREAM::endl;
-        METAIO_STREAM::cerr << "  Writing as double instead.  Loss of precision results."
-                  << METAIO_STREAM::endl;
+        METAIO_STREAM::cerr << "Programs compiled using MSV6 or HPUX cannot"
+                            << " write 64 bit ints" << METAIO_STREAM::endl;
+        METAIO_STREAM::cerr << "  Writing as double instead."
+                            << "  Loss of precision results."
+                            << METAIO_STREAM::endl;
 #else
-        fp << (MET_LONG_LONG_TYPE)((*fieldIter)->value[0]) << METAIO_STREAM::endl;
+        fp << (MET_LONG_LONG_TYPE)((*fieldIter)->value[0])
+           << METAIO_STREAM::endl;
 #endif
         break;
         }
@@ -1064,15 +1291,20 @@ bool MET_Write(METAIO_STREAM::ostream &fp, METAIO_STL::vector<MET_FieldRecordTyp
         }
       case MET_ULONG_LONG:
         {
-#if defined(_MSC_VER) // NOTE: you cannot use __int64 in an ostream in MSV6
-        fp << (double)((MET_LONG_LONG_TYPE)((MET_ULONG_LONG_TYPE)((*fieldIter)->value[0]))) 
+#if defined(_MSC_VER) || defined(__HP_aCC)
+        // NOTE: you cannot use __int64 in an ostream in MSV6 or HPUX
+        fp << (double)((MET_LONG_LONG_TYPE)((MET_ULONG_LONG_TYPE)
+                       ((*fieldIter)->value[0])))
            << METAIO_STREAM::endl;
-        METAIO_STREAM::cerr << "Programs compiled using MSV6 cannot write 64 bit ints"
-                  << METAIO_STREAM::endl;
-        METAIO_STREAM::cerr << "  Writing as double instead.  Loss of precision results."
-                  << METAIO_STREAM::endl;
+        METAIO_STREAM::cerr << "Programs compiled using MSV6 or HPUX"
+                            << " cannot write 64 bit ints"
+                            << METAIO_STREAM::endl;
+        METAIO_STREAM::cerr << "  Writing as double instead."
+                            << "  Loss of precision results."
+                            << METAIO_STREAM::endl;
 #else
-        fp << (MET_ULONG_LONG_TYPE)((*fieldIter)->value[0]) << METAIO_STREAM::endl;
+        fp << (MET_ULONG_LONG_TYPE)((*fieldIter)->value[0])
+           << METAIO_STREAM::endl;
 #endif
         break;
         }
@@ -1086,13 +1318,14 @@ bool MET_Write(METAIO_STREAM::ostream &fp, METAIO_STL::vector<MET_FieldRecordTyp
       case MET_STRING:
         {
         fp << (*fieldIter)->name << " " << MET_SeperatorChar << " ";
-        if((*fieldIter)->dependsOn >= 0) 
+        if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning:";
-            METAIO_STREAM::cerr << "length and dependsOn values not equal in write";
+            METAIO_STREAM::cerr << "length and dependsOn values not equal"
+                                << " in write";
             METAIO_STREAM::cerr << METAIO_STREAM::endl;
             }
           }
@@ -1108,11 +1341,12 @@ bool MET_Write(METAIO_STREAM::ostream &fp, METAIO_STL::vector<MET_FieldRecordTyp
         fp << (*fieldIter)->name << " " << MET_SeperatorChar;
         if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning: ";
-            METAIO_STREAM::cerr << "Length and dependsOn values not equal in write";
+            METAIO_STREAM::cerr << "Length and dependsOn values not equal"
+                                << " in write";
             METAIO_STREAM::cerr << METAIO_STREAM::endl;
             }
           }
@@ -1128,22 +1362,26 @@ bool MET_Write(METAIO_STREAM::ostream &fp, METAIO_STL::vector<MET_FieldRecordTyp
         fp << (*fieldIter)->name << " " << MET_SeperatorChar;
         if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning: ";
-            METAIO_STREAM::cerr << "Length and dependsOn values not equal in write";
+            METAIO_STREAM::cerr << "Length and dependsOn values not equal"
+                                << " in write";
             METAIO_STREAM::cerr << METAIO_STREAM::endl;
             }
           }
         for(j=0; j<(*fieldIter)->length; j++)
           {
-#if defined(_MSC_VER) // NOTE: you cannot use __int64 in an ostream in MSV6
+#if defined(_MSC_VER) || defined(__HP_aCC)
+          // NOTE: you cannot use __int64 in an ostream in MSV6 or HPUX
           fp << " " << (double)((MET_LONG_LONG_TYPE)((*fieldIter)->value[j]));
-          METAIO_STREAM::cerr << "Programs compiled using MSV6 cannot write 64 bit ints"
-                    << METAIO_STREAM::endl;
-          METAIO_STREAM::cerr << "  Writing as double instead. Loss of precision results."
-                    << METAIO_STREAM::endl;
+          METAIO_STREAM::cerr << "Programs compiled using MSV6 cannot"
+                              << " write 64 bit ints"
+                              << METAIO_STREAM::endl;
+          METAIO_STREAM::cerr << "  Writing as double instead."
+                              << " Loss of precision results."
+                              << METAIO_STREAM::endl;
 #else
           fp << " " << (MET_LONG_LONG_TYPE)((*fieldIter)->value[j]);
 #endif
@@ -1160,11 +1398,12 @@ bool MET_Write(METAIO_STREAM::ostream &fp, METAIO_STL::vector<MET_FieldRecordTyp
         fp << (*fieldIter)->name << " " << MET_SeperatorChar;
         if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning: ";
-            METAIO_STREAM::cerr << "Length and dependsOn values not equal in write";
+            METAIO_STREAM::cerr << "Length and dependsOn values not equal"
+                                << " in write";
             METAIO_STREAM::cerr << METAIO_STREAM::endl;
             }
           }
@@ -1180,22 +1419,27 @@ bool MET_Write(METAIO_STREAM::ostream &fp, METAIO_STL::vector<MET_FieldRecordTyp
         fp << (*fieldIter)->name << " " << MET_SeperatorChar;
         if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning: ";
-            METAIO_STREAM::cerr << "Length and dependsOn values not equal in write";
+            METAIO_STREAM::cerr << "Length and dependsOn values not equal"
+                                << " in write";
             METAIO_STREAM::cerr << METAIO_STREAM::endl;
             }
           }
         for(j=0; j<(*fieldIter)->length; j++)
           {
-#if defined(_MSC_VER) // NOTE: you cannot use __int64 in an ostream in MSV6
-          fp << " " << (double)((MET_LONG_LONG_TYPE)((MET_ULONG_LONG_TYPE)((*fieldIter)->value[j])));
-          METAIO_STREAM::cerr << "Programs compiled using MSV6 cannot write 64 bit ints"
-                    << METAIO_STREAM::endl;
-          METAIO_STREAM::cerr << "  Writing as double instead. Loss of precision results."
-                    << METAIO_STREAM::endl;
+#if defined(_MSC_VER) || defined(__HP_aCC)
+          // NOTE: you cannot use __int64 in an ostream in MSV6
+          fp << " " << (double)((MET_LONG_LONG_TYPE)((MET_ULONG_LONG_TYPE)
+                                ((*fieldIter)->value[j])));
+          METAIO_STREAM::cerr << "Programs compiled using MSV6 or HPUX"
+                              << " cannot write 64 bit ints"
+                              << METAIO_STREAM::endl;
+          METAIO_STREAM::cerr << " Writing as double instead."
+                              << " Loss of precision results."
+                              << METAIO_STREAM::endl;
 #else
           fp << " " << (MET_ULONG_LONG_TYPE)((*fieldIter)->value[j]);
 #endif
@@ -1210,7 +1454,7 @@ bool MET_Write(METAIO_STREAM::ostream &fp, METAIO_STL::vector<MET_FieldRecordTyp
         fp << (*fieldIter)->name << " " << MET_SeperatorChar;
         if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning: ";
@@ -1230,7 +1474,7 @@ bool MET_Write(METAIO_STREAM::ostream &fp, METAIO_STL::vector<MET_FieldRecordTyp
         fp << (*fieldIter)->name << " " << MET_SeperatorChar;
         if((*fieldIter)->dependsOn >= 0)
           {
-          if((*fieldIter)->length != 
+          if((*fieldIter)->length !=
              (*fields)[(*fieldIter)->dependsOn]->value[0])
             {
             METAIO_STREAM::cerr << "Warning: ";
@@ -1255,11 +1499,11 @@ bool MET_Write(METAIO_STREAM::ostream &fp, METAIO_STL::vector<MET_FieldRecordTyp
 }
 
 bool MET_WriteFieldToFile(METAIO_STREAM::ostream & _fp, const char *_fieldName,
-                          MET_ValueEnumType _pType, int _n, const void *_v)
+                          MET_ValueEnumType _pType, size_t _n, const void *_v)
   {
-  int i;
+  size_t i;
   MET_FieldRecordType f;
-  
+
   sprintf(f.name, "%s", _fieldName);
   f.defined = false;
   f.dependsOn = -1;
@@ -1336,8 +1580,10 @@ bool MET_WriteFieldToFile(METAIO_STREAM::ostream & _fp, const char *_fieldName,
     case MET_ULONG_LONG_ARRAY:
       for(i=0; i<_n; i++)
         {
-#if defined(_MSC_VER) // NOTE: you cannot use __int64 in an ostream in MSV6
-        f.value[i] = (double)((MET_LONG_LONG_TYPE)(((const MET_ULONG_LONG_TYPE *)_v)[i]));
+#if defined(_MSC_VER) || defined(__HP_aCC)
+        // NOTE: you cannot use __int64 in an ostream in MSV6 or HPUX
+        f.value[i] = (double)((MET_LONG_LONG_TYPE)
+                              (((const MET_ULONG_LONG_TYPE *)_v)[i]));
 #else
         f.value[i] = (double)(((const MET_ULONG_LONG_TYPE *)_v)[i]);
 #endif
@@ -1369,12 +1615,12 @@ bool MET_WriteFieldToFile(METAIO_STREAM::ostream & _fp, const char *_fieldName,
     default:
       break;
     }
-  
+
   METAIO_STL::vector<MET_FieldRecordType *> l;
   l.clear();
   l.push_back(&f);
   MET_Write(_fp, &l);
-  
+
   return true;
   }
 
@@ -1382,7 +1628,7 @@ bool MET_WriteFieldToFile(METAIO_STREAM::ostream & _fp, const char *_fieldName,
   MET_ValueEnumType _pType, double _v)
   {
   MET_FieldRecordType f;
-  
+
   sprintf(f.name, "%s", _fieldName);
   f.defined = false;
   f.dependsOn = -1;
@@ -1390,12 +1636,12 @@ bool MET_WriteFieldToFile(METAIO_STREAM::ostream & _fp, const char *_fieldName,
   f.required = false;
   f.type = _pType;
   f.value[0] = _v;
-  
+
   METAIO_STL::vector<MET_FieldRecordType *> l;
   l.clear();
   l.push_back(&f);
   MET_Write(_fp, &l);
-  
+
   return true;
   }
 
@@ -1430,14 +1676,14 @@ void MET_SwapByteIfSystemMSB(void* val, MET_ValueEnumType _type)
       {
       return;
       }
-  
+
     int eSize;
-    MET_SizeOfType(_type, &eSize);    
+    MET_SizeOfType(_type, &eSize);
     switch(eSize)
       {
       default:
       case 0:
-      case 1: 
+      case 1:
         {
         break;
         }
