@@ -3,8 +3,8 @@
   Program:   MetaIO
   Module:    $RCSfile: metaVesselTube.cxx,v $
   Language:  C++
-  Date:      $Date: 2006/10/27 12:25:53 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2008-04-09 01:44:27 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,6 +14,11 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
+#ifdef _MSC_VER
+#pragma warning(disable:4702)
+#pragma warning(disable:4284)
+#endif
+
 #include "metaVesselTube.h"
 
 #include <stdio.h>
@@ -25,13 +30,56 @@
 namespace METAIO_NAMESPACE {
 #endif
 
+VesselTubePnt::
+VesselTubePnt(int dim)
+{ 
+  m_Dim = dim;
+  m_X = new float[m_Dim];
+  m_T = new float[m_Dim];
+  m_V1= new float[m_Dim];
+  m_V2= new float[m_Dim];
+  for(unsigned int i=0;i<m_Dim;i++)
+    {
+    m_X[i] = 0;
+    m_V1[i]= 0;
+    m_V2[i]= 0;
+    m_T[i]= 0;
+    }
+  m_Alpha1=0;
+  m_Alpha2=0;
+  m_Alpha3=0;
+  m_R=0;
+  m_Medialness=0;
+  m_Ridgeness=0;
+  m_Branchness=0;
+  m_Mark=false;
+  
+  //Color is red by default
+  m_Color[0]=1.0;
+  m_Color[1]=0.0;
+  m_Color[2]=0.0;
+  m_Color[3]=1.0;
+  m_ID = -1;
+}
+
+VesselTubePnt::
+~VesselTubePnt()
+{
+  delete []m_X;
+  delete []m_V1;
+  delete []m_V2;
+  delete []m_T;
+}
 
 /** MetaVesselTube Constructors */
 MetaVesselTube::
 MetaVesselTube()
 :MetaObject()
 {
-  if(META_DEBUG) METAIO_STREAM::cout << "MetaVesselTube()" << METAIO_STREAM::endl;
+  if(META_DEBUG)
+    {
+    METAIO_STREAM::cout << "MetaVesselTube()" << METAIO_STREAM::endl;
+    }
   Clear();
 }
 
@@ -40,7 +88,10 @@ MetaVesselTube::
 MetaVesselTube(const char *_headerName)
 :MetaObject()
 {
-  if(META_DEBUG)  METAIO_STREAM::cout << "MetaVesselTube()" << METAIO_STREAM::endl;
+  if(META_DEBUG)
+    {
+    METAIO_STREAM::cout << "MetaVesselTube()" << METAIO_STREAM::endl;
+    }
   Clear();
   Read(_headerName);
 }
@@ -50,7 +101,10 @@ MetaVesselTube::
 MetaVesselTube(const MetaVesselTube *_VesselTube)
 :MetaObject()
 {
-  if(META_DEBUG)  METAIO_STREAM::cout << "MetaVesselTube()" << METAIO_STREAM::endl;
+  if(META_DEBUG)
+    {
+    METAIO_STREAM::cout << "MetaVesselTube()" << METAIO_STREAM::endl;
+    }
   Clear();
   CopyInfo(_VesselTube);
 }
@@ -60,7 +114,10 @@ MetaVesselTube::
 MetaVesselTube(unsigned int dim)
 :MetaObject(dim)
 {
-  if(META_DEBUG) METAIO_STREAM::cout << "MetaVesselTube()" << METAIO_STREAM::endl;
+  if(META_DEBUG)
+    {
+    METAIO_STREAM::cout << "MetaVesselTube()" << METAIO_STREAM::endl;
+    }
   Clear();
 }
 
@@ -71,11 +128,11 @@ MetaVesselTube::
   // Delete the list of pointers to VesselTubes.
   PointListType::iterator it = m_PointList.begin();
   while(it != m_PointList.end())
-  {
+    {
     VesselTubePnt* pnt = *it;
     it++;
     delete pnt;
-  }  
+    }  
   m_PointList.clear();
   M_Destroy();
 }
@@ -85,7 +142,8 @@ void MetaVesselTube::
 PrintInfo() const
 {
   MetaObject::PrintInfo();
-  METAIO_STREAM::cout << "ParentPoint = " << m_ParentPoint << METAIO_STREAM::endl;
+  METAIO_STREAM::cout << "ParentPoint = " << m_ParentPoint 
+                      << METAIO_STREAM::endl;
   if(m_Root)
     {
     METAIO_STREAM::cout << "Root = " << "True" << METAIO_STREAM::endl;
@@ -176,7 +234,10 @@ ParentPoint(void) const
 void MetaVesselTube::
 Clear(void)
 {
-  if(META_DEBUG) METAIO_STREAM::cout << "MetaVesselTube: Clear" << METAIO_STREAM::endl;
+  if(META_DEBUG)
+    {
+    METAIO_STREAM::cout << "MetaVesselTube: Clear" << METAIO_STREAM::endl;
+    }
   MetaObject::Clear();
   // Delete the list of pointers to VesselTubes.
   PointListType::iterator it = m_PointList.begin();
@@ -207,7 +268,11 @@ M_Destroy(void)
 void MetaVesselTube::
 M_SetupReadFields(void)
 {
-  if(META_DEBUG) METAIO_STREAM::cout << "MetaVesselTube: M_SetupReadFields" << METAIO_STREAM::endl;
+  if(META_DEBUG)
+    {
+    METAIO_STREAM::cout << "MetaVesselTube: M_SetupReadFields" 
+                        << METAIO_STREAM::endl;
+    }
 
   MetaObject::M_SetupReadFields();
 
@@ -292,7 +357,7 @@ M_SetupWriteFields(void)
     m_Fields.push_back(mF);
     }
 
-  m_NPoints = m_PointList.size();
+  m_NPoints = (int)m_PointList.size();
   mF = new MET_FieldRecordType;
   MET_InitWriteField(mF, "NPoints", MET_INT,m_NPoints);
   m_Fields.push_back(mF);
@@ -308,15 +373,24 @@ M_SetupWriteFields(void)
 bool MetaVesselTube::
 M_Read(void)
 {
-  if(META_DEBUG) METAIO_STREAM::cout << "MetaVesselTube: M_Read: Loading Header" << METAIO_STREAM::endl;
+  if(META_DEBUG)
+    {
+    METAIO_STREAM::cout << "MetaVesselTube: M_Read: Loading Header" 
+                        << METAIO_STREAM::endl;
+    }
 
   if(!MetaObject::M_Read())
-  {
-    METAIO_STREAM::cout << "MetaVesselTube: M_Read: Error parsing file" << METAIO_STREAM::endl;
+    {
+    METAIO_STREAM::cout << "MetaVesselTube: M_Read: Error parsing file" 
+                        << METAIO_STREAM::endl;
     return false;
-  }
+    }
 
-  if(META_DEBUG) METAIO_STREAM::cout << "MetaVesselTube: M_Read: Parsing Header" << METAIO_STREAM::endl;
+  if(META_DEBUG)
+    {
+    METAIO_STREAM::cout << "MetaVesselTube: M_Read: Parsing Header" 
+                        << METAIO_STREAM::endl;
+    }
  
   MET_FieldRecordType * mF;
  
@@ -404,7 +478,8 @@ M_Read(void)
  
   if(META_DEBUG)
     {
-    METAIO_STREAM::cout << "MetaVesselTube: Parsing point dim" << METAIO_STREAM::endl; 
+    METAIO_STREAM::cout << "MetaVesselTube: Parsing point dim" 
+                        << METAIO_STREAM::endl; 
     }
 
   int j;
@@ -557,7 +632,7 @@ M_Read(void)
     i=0;
     int d;
     unsigned int k;
-    for(j=0; j<m_NPoints; j++) 
+    for(j=0; j<(int)m_NPoints; j++) 
       {
       VesselTubePnt* pnt = new VesselTubePnt(m_NDims);
       
@@ -750,7 +825,7 @@ M_Read(void)
     }
   else
     {
-    for(j=0; j<m_NPoints; j++) 
+    for(j=0; j<(int)m_NPoints; j++) 
       {
       if(m_Event)
         {
@@ -904,7 +979,8 @@ M_Write(void)
 
   if(!MetaObject::M_Write())
     {
-    METAIO_STREAM::cout << "MetaVesselTube: M_Read: Error parsing file" << METAIO_STREAM::endl;
+    METAIO_STREAM::cout << "MetaVesselTube: M_Read: Error parsing file" 
+                        << METAIO_STREAM::endl;
     return false;
     }
 
@@ -912,13 +988,14 @@ M_Write(void)
   if(m_BinaryData)
     {
     PointListType::const_iterator it = m_PointList.begin();
+    PointListType::const_iterator itEnd = m_PointList.end();
     int elementSize;
     MET_SizeOfType(m_ElementType, &elementSize);
 
     char* data = new char[(m_NDims*(2+m_NDims)+10)*m_NPoints*elementSize];
     int i=0;
     int d;
-    while(it != m_PointList.end())
+    while(it != itEnd)
       {
       for(d = 0; d < m_NDims; d++)
         {
@@ -1004,9 +1081,10 @@ M_Write(void)
   else
     {
     PointListType::const_iterator it = m_PointList.begin();
+    PointListType::const_iterator itEnd = m_PointList.end();
   
     int d;
-    while(it != m_PointList.end())
+    while(it != itEnd)
       {
       for(d = 0; d < m_NDims; d++)
         {
