@@ -3,8 +3,8 @@
   Program:   gdcm
   Module:    $RCSfile: gdcmArgMgr.cxx,v $
   Language:  C++
-  Date:      $Date: 2007/01/04 16:46:32 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2007-04-29 12:11:37 $
+  Version:   $Revision: 1.5 $
   
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -752,7 +752,7 @@ char *ArgMgr::Majuscule (const char *chaine )
   char *ptr, *ptr2, *ptr3;
   ptr2 = (char *)malloc(strlen(chaine)*sizeof(char)+1);
   ptr3=ptr2;
-  for ( ptr = (char *)chaine ; *ptr!='\0' ; ptr ++ ) 
+  for ( ptr = const_cast<char *>(chaine) ; *ptr!='\0' ; ptr ++ ) 
    {  
        *ptr3 = toupper ( * ptr ); ptr3++; 
    }
@@ -788,7 +788,7 @@ int ArgMgr::FiltreLong ( const char *arg  )
 const char *ArgMgr::LoadedParam ( const char *param, FILE *fd )
 {
   int    carlu;
-  char  *car = (char *)param;
+  char  *car = const_cast<char *>(param);
   int    quote = false;
   int    nbcar = 0;
 
@@ -869,12 +869,12 @@ void ArgMgr::ArgStdArgs()
   char *logfile;
   FILE *fd;
 
-  if ( (ArgParamOut=ArgMgrValue((char*)ARG_LABEL_PARAMOUT))==0 )
+  if ( (ArgParamOut=ArgMgrValue(const_cast<char*>(ARG_LABEL_PARAMOUT)))==0 )
     ArgParamOut = ARG_DEFAULT_PARAMOUT;
-  if ( (logfile = ArgMgrValue((char*)ARG_LABEL_LOGFILE))!=0) 
+       if ( (logfile = ArgMgrValue(const_cast<char*>(ARG_LABEL_LOGFILE)))!=0) 
   {
     if ( *logfile == '\0' )
-       logfile = (char *)ARG_DEFAULT_LOGFILE;
+      logfile = const_cast<char *>(ARG_DEFAULT_LOGFILE);
     fd = fopen ( logfile, "a+" );
     if ( fd ) 
     {
