@@ -3,8 +3,8 @@
   Program:   gdcm
   Module:    $RCSfile: gdcmDocument.cxx,v $
   Language:  C++
-  Date:      $Date: 2007/02/22 00:16:19 $
-  Version:   $Revision: 1.27 $
+  Date:      $Date: 2007-12-05 15:18:07 $
+  Version:   $Revision: 1.28 $
                                                                                 
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -1913,7 +1913,7 @@ void Document::SkipDocEntry(DocEntry *entry)
 void Document::SkipToNextDocEntry(DocEntry *currentDocEntry) 
 {
    long l = currentDocEntry->GetReadLength();
-   if ( l == -1 ) // length = 0xffff shouldn't appear here ...
+   if ( (uint32_t)l == (uint32_t)-1 ) // length = 0xffff shouldn't appear here ...
                   // ... but PMS imagers happen !
       return;
    Fp->seekg((size_t)(currentDocEntry->GetOffset()), std::ios::beg); //FIXME :each DocEntry
