@@ -3,8 +3,8 @@
   Program:   gdcm
   Module:    $RCSfile: gdcmFile.cxx,v $
   Language:  C++
-  Date:      $Date: 2007/02/21 21:20:43 $
-  Version:   $Revision: 1.19 $
+  Date:      $Date: 2008-04-11 16:50:17 $
+  Version:   $Revision: 1.22 $
                                                                                 
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -16,6 +16,10 @@
                                                                                 
 =========================================================================*/
 
+#if defined(__BORLANDC__)
+#pragma warn -8004 /* assigned a value that is never used */
+#endif
+
 //
 // --------------  Remember ! ----------------------------------
 //
@@ -460,7 +464,7 @@ int File::GetZSize()
 //  ts["1.2.840.10008.5.1.4.1.1.4.1"] = "Enhanced MR Image Storage"; 
 bool File::GetSpacing(float &xspacing, float &yspacing, float &zspacing)
 {
-   xspacing = yspacing = zspacing = 2.0;
+   xspacing = yspacing = zspacing = 1.0;
    TS *ts = Global::GetTS();
    std::string sopclassuid_used;
    // D 0002|0002 [UI] [Media Storage SOP Class UID]
@@ -584,8 +588,9 @@ float File::GetXSpacing()
 
       if ( xspacing == 0.0 )
          xspacing = 1.0;
+
+      return xspacing;
    }
-   return xspacing;
 
    // to avoid troubles with David Clunie's-like images (at least one)
    if ( xspacing == 0.0 && yspacing == 0.0)
@@ -1414,7 +1419,7 @@ int File::GetNumberOfScalarComponents()
 
    std::string strPhotometricInterpretation = GetEntryValue(0x0028,0x0004);
 
-   if ( ( strPhotometricInterpretation == "PALETTE COLOR ") )
+   if ( Util::DicomStringEqual(strPhotometricInterpretation, "PALETTE COLOR") )
    {
       if ( HasLUT() )// PALETTE COLOR is NOT enough
       {
