@@ -4,8 +4,8 @@
   Module:    $RCSfile: gdcmFileHelper.cxx,v $
   Language:  C++
 
-  Date:      $Date: 2007/01/04 16:46:32 $
-  Version:   $Revision: 1.19 $
+  Date:      $Date: 2007-12-11 11:19:48 $
+  Version:   $Revision: 1.21 $
                                                                                 
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -847,6 +847,36 @@ bool FileHelper::CheckWriteIntegrity()
    return true;
 }
 
+size_t FileHelper::ComputeExpectedImageDataSize()
+{
+  int numberBitsAllocated = FileInternal->GetBitsAllocated();
+  if ( numberBitsAllocated == 0 || numberBitsAllocated == 12 )
+    {
+    gdcmWarningMacro( "numberBitsAllocated changed from " 
+      << numberBitsAllocated << " to 16 " 
+      << " for consistency purpose" );
+    numberBitsAllocated = 16;
+    }
+
+  size_t decSize = FileInternal->GetXSize()
+    * FileInternal->GetYSize() 
+    * FileInternal->GetZSize()
+    * FileInternal->GetSamplesPerPixel()
+    * ( numberBitsAllocated / 8 );
+  size_t rgbSize = decSize;
+  if ( FileInternal->HasLUT() )
+    rgbSize = decSize * 3;
+
+  switch(WriteMode)
+    {
+  case WMODE_RAW :
+    return decSize;
+  case WMODE_RGB :
+    return rgbSize;
+    }
+  return 0;
+}
+
 /**
  * \brief Updates the File to write RAW data (as opposed to RGB data)
  *       (modifies, when necessary, photochromatic interpretation, 
@@ -1434,7 +1464,7 @@ void FileHelper::CheckMandatoryElements()
       CopyMandatoryEntry(0x0002,0x0000,"0");
 
       BinEntry *e_0002_0001 = CopyBinEntry(0x0002,0x0001, "OB");
-      e_0002_0001->SetBinArea((uint8_t*)Util::GetFileMetaInformationVersion(),
+      e_0002_0001->SetBinArea(const_cast<uint8_t*>(Util::GetFileMetaInformationVersion()),
                                false);
       e_0002_0001->SetLength(2);
       Archive->Push(e_0002_0001);
